(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    470045,      12356]
NotebookOptionsPosition[    460585,      12082]
NotebookOutlinePosition[    461119,      12103]
CellTagsIndexPosition[    461076,      12100]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "The MCDist ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " package"
}], "Title",
 CellChangeTimes->{
  3.559289200697814*^9, {3.573277708963888*^9, 3.573277714511982*^9}, {
   3.573277948032852*^9, 3.5732779491123*^9}}],

Cell["\<\
On-the-fly exact computation of bisimilarity distances for Markov Chains\
\>", "Subtitle",
 CellChangeTimes->{{3.559301899440158*^9, 3.559301929064122*^9}, {
  3.5721698193402967`*^9, 3.572169819803095*^9}, {3.573277716723839*^9, 
  3.573277740861225*^9}}],

Cell["\<\
Authors: Giorgio Bacci, Giovanni Bacci, Kim G. Larsen, and Radu Mardare\
\>", "Subsubtitle",
 CellChangeTimes->{{3.559289239962391*^9, 3.559289248012012*^9}, {
  3.559289280494467*^9, 3.55928928427775*^9}}],

Cell[TextData[{
 "In this tutorial we present the main features of the MCDist package. This \
",
 StyleBox["Mathematica ",
  FontSlant->"Italic"],
 "package implements an on-the-fly method for computing the bisimilarity \
pseudometric of Desharnais et al. ",
 ButtonBox["[",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1016/j.tcs.2003.09.013"], None},
  ButtonNote->"http://dx.doi.org/10.1016/j.tcs.2003.09.013"],
 Cell[BoxData[
  FormBox[
   ButtonBox["1",
    BaseStyle->"Hyperlink",
    ButtonData->{
      URL["http://dx.doi.org/10.1016/j.tcs.2003.09.013"], None},
    ButtonNote->"http://dx.doi.org/10.1016/j.tcs.2003.09.013"], 
   TraditionalForm]]],
 ButtonBox["] ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1016/j.tcs.2003.09.013"], None},
  ButtonNote->"http://dx.doi.org/10.1016/j.tcs.2003.09.013"],
 "for Markov Chains. The algorithm implemented in this package is based on \
the technique recently proposed in [",
 ButtonBox["2",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1007/978-3-642-36742-7_1"], None},
  ButtonNote->"http://dx.doi.org/10.1007/978-3-642-36742-7_1"],
 "]."
}], "Text",
 CellChangeTimes->{{3.559289413890732*^9, 3.5592895519493093`*^9}, {
  3.559289584798902*^9, 3.55929005674139*^9}, {3.559295092006178*^9, 
  3.559295274248143*^9}, {3.559295347895853*^9, 3.559295420742426*^9}, {
  3.559301737272998*^9, 3.559301886671125*^9}, {3.559563724800871*^9, 
  3.5595638266156178`*^9}, {3.559563908420285*^9, 3.559563930779663*^9}, {
  3.572169872207636*^9, 3.572169939585024*^9}, {3.5721700084046183`*^9, 
  3.572170407163101*^9}, {3.572171967985834*^9, 3.572172154421157*^9}, {
  3.573275759111957*^9, 3.573275782101445*^9}, {3.573277849177054*^9, 
  3.573277918826508*^9}, {3.573277987735139*^9, 3.573278033559073*^9}, {
  3.573456329471491*^9, 3.573456389737645*^9}}],

Cell[CellGroupData[{

Cell["Preliminaries", "Subsection",
 CellChangeTimes->{{3.573464082558014*^9, 3.573464086556279*^9}}],

Cell[CellGroupData[{

Cell["\<\
Markov Chains and Probabilistic Bisimulations\
\>", "Subsubsection",
 CellChangeTimes->{{3.5734640908523893`*^9, 3.573464108235167*^9}}],

Cell[TextData[{
 StyleBox["Definition (Markov Chain).",
  FontWeight->"Bold"],
 " A (discrete-time) Markov chain (MC) is a tuple \[ScriptCapitalM] = (S, \
\[CapitalSigma], \[Pi], \[ScriptL]) consisting of a finite nonempty set S of ",
 StyleBox["states",
  FontSlant->"Italic"],
 ", a nonempty set A of ",
 StyleBox["labels",
  FontSlant->"Italic"],
 ", a ",
 StyleBox["transition probability function",
  FontSlant->"Italic"],
 " \[Pi] : S \[Times] S \[RightArrow] [0,1] such that, for arbitrary s \
\[Element] S, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     UnderscriptBox["\[Sum]", 
      RowBox[{" ", 
       RowBox[{"t", " ", "\[Element]", " ", "S"}]}]], 
     RowBox[{"\[Pi]", "(", 
      RowBox[{"s", ",", "t"}], ")"}]}], " ", "=", " ", "1"}], 
   TraditionalForm]]],
 ", and a ",
 StyleBox["labelling function",
  FontSlant->"Italic"],
 " \[ScriptL] : S \[RightArrow] \[CapitalSigma]."
}], "Text",
 CellChangeTimes->{{3.573464113754899*^9, 3.573464477506784*^9}, {
  3.5734648180248938`*^9, 3.5734648184403687`*^9}, {3.57389897223542*^9, 
  3.573899099327752*^9}, {3.5738991358403263`*^9, 3.573899150125955*^9}}],

Cell["\<\
From a theoretical point of view, it is irrelevant whether the transition \
probability function of a given MC has rational values or not, However, for \
algorithmic purposes, here we assume that for arbitrary s,t \[Element] S, \
\[Pi](s,t) \[Element] \[DoubleStruckCapitalQ] \[Intersection] [0,1].\
\>", "Text",
 CellChangeTimes->{{3.573464564721573*^9, 3.573464714749016*^9}, {
   3.573464748083099*^9, 3.573464775869809*^9}, 3.5738989445356817`*^9}],

Cell[TextData[{
 StyleBox["Definition (Probabilistic Bisimulation).",
  FontWeight->"Bold"],
 " Let \[ScriptCapitalM] = (S, \[CapitalSigma], \[Pi], \[ScriptL]) be an MC. \
An equivalence relation R \[SubsetEqual] S \[Times] S is a ",
 StyleBox["probabilistic bisimulation",
  FontSlant->"Italic"],
 " if whenever (s,t) \[Element] R, \[ScriptL](s) = \[ScriptL](t) and for each \
R-equivalence class C, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     UnderscriptBox["\[Sum]", 
      RowBox[{" ", 
       RowBox[{"c", " ", "\[Element]", " ", "C"}]}]], 
     RowBox[{"\[Pi]", "(", 
      RowBox[{"s", ",", "c"}], ")"}]}], " ", "=", " ", 
    RowBox[{
     UnderscriptBox["\[Sum]", 
      RowBox[{"  ", 
       RowBox[{"c", " ", "\[Element]", " ", "C"}]}]], 
     RowBox[{"\[Pi]", "(", 
      RowBox[{"t", ",", "c"}], ")"}]}]}], TraditionalForm]]],
 ".\nTwo states s,t \[Element] S are ",
 StyleBox["bisimilar",
  FontSlant->"Italic"],
 ", written s \[Tilde] t, if they are related by some probabilistic \
bisimulation. "
}], "Text",
 CellChangeTimes->{{3.5734647962990437`*^9, 3.573465079281179*^9}, {
  3.5734652692609577`*^9, 3.573465301998877*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bisimilarity Pseudometric", "Subsubsection",
 CellChangeTimes->{{3.573197378994329*^9, 3.5731974027498302`*^9}}],

Cell[TextData[{
 "The notion of equivalence can be relaxed by means of a pseudometric, which \
tells us how far apart from each other two elements are and whenever they are \
at zero distance they are equivalent. Desharnais et al. ",
 ButtonBox["[",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1016/j.tcs.2003.09.013"], None},
  ButtonNote->"http://dx.doi.org/10.1016/j.tcs.2003.09.013"],
 Cell[BoxData[
  FormBox[
   ButtonBox["1",
    BaseStyle->"Hyperlink",
    ButtonData->{
      URL["http://dx.doi.org/10.1016/j.tcs.2003.09.013"], None},
    ButtonNote->"http://dx.doi.org/10.1016/j.tcs.2003.09.013"], 
   TraditionalForm]]],
 ButtonBox["]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1016/j.tcs.2003.09.013"], None},
  ButtonNote->"http://dx.doi.org/10.1016/j.tcs.2003.09.013"],
 " defined a bisimilarity pseudometric that measures the behavioral \
similarity of two non-bisimilar MCs. In [",
 ButtonBox["3",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.lmcs-online.org/ojs/viewarticle.php?id=353&layout=\
abstract"], None},
  ButtonNote->
   "http://www.lmcs-online.org/ojs/viewarticle.php?id=353&layout=abstract"],
 "], van Breugel et al. characterized this pseudometric as the least fixed \
point of a operator on functions in S \[Times] S \[RightArrow] [0,1]. \n\
Consider an MC \[ScriptCapitalM] = (S, \[CapitalSigma], \[Pi], \[ScriptL]) \
and a discount factor \[Lambda] \[Element] (0,1]. The set S \[Times] S \
\[RightArrow] [0,1] of [0,1]-valued maps on S \[Times] S equipped with the \
point-wise partial order defined by d \[SquareSubsetEqual] \
d\[CloseCurlyQuote] \[DoubleLeftRightArrow] d(s,t) \[LessSlantEqual] d\
\[CloseCurlyQuote](s,t), for all s,t \[Element] S. \nWe define a fixed point \
operator ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[CapitalDelta]", "\[Lambda]"], " ", ":", " ", 
    RowBox[{
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"S", "\[Times]", "S"}], "\[RightArrow]", 
       RowBox[{"[", 
        RowBox[{"0", ",", "1"}], "]"}]}], " ", ")"}], " ", "\[RightArrow]", 
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"S", "\[Times]", "S"}], "\[RightArrow]", 
       RowBox[{"[", 
        RowBox[{"0", ",", "1"}], "]"}]}], " ", ")"}]}]}], TraditionalForm]]],
 ", for d : S \[Times] S \[RightArrow] [0,1] and s,t \[Element] S as "
}], "Text",
 CellChangeTimes->{{3.573197460795909*^9, 3.5731980924767733`*^9}, {
   3.57319932785832*^9, 3.573199327862383*^9}, 3.5734565323988132`*^9, {
   3.5738854892870493`*^9, 3.573885540633605*^9}, {3.5738855736967487`*^9, 
   3.573885612580497*^9}, {3.573886563888529*^9, 3.573886567231111*^9}, {
   3.573886665587881*^9, 3.5738867414892683`*^9}, {3.573886780827002*^9, 
   3.573886782577532*^9}, {3.573886867200577*^9, 3.573887020212491*^9}, 
   3.573899217689101*^9, 3.573899265299017*^9, {3.57389936753785*^9, 
   3.573899398399382*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[CapitalDelta]", "\[Lambda]"], "(", "d", ")"}], 
    RowBox[{"(", 
     RowBox[{"s", ",", "t"}], ")"}]}], " ", "=", " ", 
   TagBox[GridBox[{
      {"\[Piecewise]", GridBox[{
         {"1", 
          RowBox[{
           RowBox[{"if", " ", 
            RowBox[{"\[ScriptL]", "(", "s", ")"}]}], " ", "\[NotEqual]", " ", 
           
           RowBox[{"\[ScriptL]", "(", "t", ")"}]}]},
         {
          RowBox[{"\[Lambda]", " ", 
           RowBox[{
            SubscriptBox["\[ScriptCapitalT]", "d"], "(", 
            RowBox[{
             RowBox[{"\[Pi]", "(", 
              RowBox[{"s", ",", "\[CenterDot]"}], ")"}], ",", 
             RowBox[{"\[Pi]", "(", 
              RowBox[{"t", ",", "\[CenterDot]"}], ")"}]}], ")"}], " "}], 
          "otherwise"}
        },
        AllowedDimensions->{2, Automatic},
        Editable->True,
        GridBoxAlignment->{
         "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}},
           "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.84]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}},
        Selectable->True]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.35]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    "Piecewise",
    DeleteWithContents->True,
    Editable->False,
    SelectWithContents->True,
    Selectable->False]}], TraditionalForm]], "DisplayFormula",
 CellChangeTimes->{{3.573198129538149*^9, 3.573198150096148*^9}, {
  3.5731982049028263`*^9, 3.5731982832918262`*^9}, {3.573198317720042*^9, 
  3.573198352674038*^9}, {3.5738870326265297`*^9, 3.5738872392370987`*^9}}],

Cell[TextData[{
 "Where ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[ScriptCapitalT]", "d"], "(", 
    RowBox[{
     RowBox[{"\[Pi]", "(", 
      RowBox[{"s", ",", "\[CenterDot]"}], ")"}], ",", 
     RowBox[{"\[Pi]", "(", 
      RowBox[{"t", ",", "\[CenterDot]"}], ")"}]}], ")"}], TraditionalForm]],
  CellChangeTimes->{{3.573198129538149*^9, 3.573198150096148*^9}, {
   3.5731982049028263`*^9, 3.5731982832918262`*^9}, {3.573198317720042*^9, 
   3.573198352674038*^9}}],
 " denotes the optimal value of a Transportation Problem with marginals \
\[Pi](s,\[CenterDot]) and \[Pi](t,\[CenterDot]) and costs given by d"
}], "Text",
 CellChangeTimes->{{3.573198455370479*^9, 3.573198707983498*^9}, {
   3.573198830317322*^9, 3.57319883814186*^9}, {3.573455480126729*^9, 
   3.5734556037187023`*^9}, {3.573456180609993*^9, 3.573456196582041*^9}, {
   3.573887358981779*^9, 3.573887379395419*^9}, 3.573899451246689*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["\[ScriptCapitalT]", "d"], "(", 
    RowBox[{
     RowBox[{"\[Pi]", "(", 
      RowBox[{"s", ",", "\[CenterDot]"}], ")"}], ",", 
     RowBox[{"\[Pi]", "(", 
      RowBox[{"t", ",", "\[CenterDot]"}], ")"}]}], ")"}], " ", "=", " ", 
   RowBox[{"min", " ", 
    RowBox[{
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         UnderscriptBox["\[Sum]", 
          RowBox[{"u", ",", 
           RowBox[{"v", " ", "\[Element]", " ", "S", " "}]}]], 
         RowBox[{
          RowBox[{"d", "(", 
           RowBox[{"u", ",", "v"}], ")"}], " ", 
          RowBox[{"\[Omega]", "(", 
           RowBox[{"u", ",", "v"}], ")"}]}]}], "  ", "|", "  ", 
        RowBox[{
         UnderscriptBox["\[Sum]", 
          RowBox[{"u", " ", "\[Element]", " ", "S"}]], 
         RowBox[{"\[Omega]", "(", 
          RowBox[{"u", ",", "v"}], ")"}]}]}], " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Pi]", "(", 
          RowBox[{"s", ",", "v"}], ")"}], "   ", "\[And]", " ", 
         RowBox[{
          UnderscriptBox["\[Sum]", 
           RowBox[{"v", " ", "\[Element]", " ", "S"}]], 
          RowBox[{"\[Omega]", "(", 
           RowBox[{"u", ",", "v"}], ")"}]}]}], " ", "=", " ", 
        RowBox[{"\[Pi]", "(", 
         RowBox[{"t", ",", "u"}], ")"}]}]}], "}"}], " ", "."}]}]}], 
  TraditionalForm]], "DisplayFormula",
 CellChangeTimes->{{3.573198129538149*^9, 3.573198150096148*^9}, {
  3.5731982049028263`*^9, 3.5731982832918262`*^9}, {3.573198317720042*^9, 
  3.573198352674038*^9}, {3.573455722484456*^9, 3.5734559069141808`*^9}, {
  3.5734559608097773`*^9, 3.573456008949929*^9}, {3.573456075258862*^9, 
  3.573456080720895*^9}, {3.5734561150715723`*^9, 3.573456146309628*^9}, {
  3.5738873978560543`*^9, 3.573887435377667*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[CapitalDelta]", "\[Lambda]"], TraditionalForm]], 
  "DisplayFormula",
  CellChangeTimes->{{3.573198129538149*^9, 3.573198150096148*^9}, {
   3.5731982049028263`*^9, 3.5731982832918262`*^9}, {3.573198317720042*^9, 
   3.573198352674038*^9}}],
 " is monotonic, thus, by Tarski\[CloseCurlyQuote]s fixed point theorem, its \
admits a least fixed point. This fixed point is the bisimilarity pseudometric."
}], "Text",
 CellChangeTimes->{
  3.573455617415782*^9, {3.5738872631253157`*^9, 3.573887266031685*^9}}],

Cell[TextData[{
 StyleBox["Definition (Bisimilarity psudometric).",
  FontWeight->"Bold"],
 " Let \[ScriptCapitalM] = (S, \[CapitalSigma], \[Pi], \[ScriptL]) be an MC \
and \[Lambda] \[Element] (0,1] be a discount factor, then the \
\[Lambda]-discounted bisimilarity pseudometric for \[ScriptCapitalM], written \
",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Delta]", "\[Lambda]"], TraditionalForm]]],
 ", is the least fixed point of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[CapitalDelta]", "\[Lambda]"], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{
  3.573198845166564*^9, {3.5738872947661953`*^9, 3.5738873239859867`*^9}}],

Cell[TextData[{
 "The pseudometric ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Delta]", "\[Lambda]"], TraditionalForm]]],
 " enjoys the property that two states are at distance zero if and only if \
they are bisimilar."
}], "Text",
 CellChangeTimes->{{3.573198849060852*^9, 3.573198924857772*^9}, {
  3.57319937509787*^9, 3.573199375959075*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Getting started", "Subsection",
 CellChangeTimes->{{3.5732762115532627`*^9, 3.5732762192393208`*^9}}],

Cell["\<\
The package can be loaded by setting as current directory that of the MCDist \
package, then using the commad << (Get) as follows\
\>", "Text",
 CellChangeTimes->{{3.5732762277426653`*^9, 3.573276447384153*^9}, {
  3.5732764926541557`*^9, 3.57327660344797*^9}, {3.573276634864959*^9, 
  3.5732767398435163`*^9}, {3.573277801881002*^9, 3.573277811064501*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"<<", "MCDist`"}], ";"}]}], "Input",
 CellChangeTimes->{{3.57327674439852*^9, 3.573276798439444*^9}, {
  3.573276885083823*^9, 3.573276890069765*^9}, {3.573276928330451*^9, 
  3.573276934981387*^9}, {3.573277831472704*^9, 3.5732778324167013`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Encoding and manipulating Markov Chains", "Subsection",
 CellChangeTimes->{
  3.5592901588038397`*^9, {3.559290191101569*^9, 3.5592902100814962`*^9}, {
   3.559302025323431*^9, 3.559302031891165*^9}}],

Cell[TextData[{
 "An MC \[ScriptCapitalM] = (S, \[CapitalSigma], \[Pi], \[ScriptL]) with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"S", "=", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["s", "1"], ",", "...", ",", " ", 
      SubscriptBox["s", "n"]}], "}"}]}], TraditionalForm]]],
 " is represented by a term of the form ",
 StyleBox["MC[tm, lbl]", "Program"],
 " where \n- ",
 StyleBox["tm", "Program"],
 " is an n \[Times] n probability matrix such that ",
 StyleBox["tm\[LeftDoubleBracket]i,j\[RightDoubleBracket]", "Program"],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Pi]", "(", 
    RowBox[{
     SubscriptBox["s", "i"], ",", 
     SubscriptBox["s", "j"]}], ")"}], TraditionalForm]], "Item"],
 " for all 1 \[LessEqual] i,j \[LessEqual] n,\n- ",
 StyleBox["lbl", "Program"],
 " is a list of strings (or integers) such that ",
 StyleBox["lbl\[LeftDoubleBracket]i\[RightDoubleBracket]", "Program"],
 " = \[ScriptL](",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "i"], TraditionalForm]]],
 ") for all 1 \[LessEqual] i \[LessEqual] n.\nA state ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "i"], TraditionalForm]]],
 " is implicitly represented by its index 1 \[LessEqual] i \[LessEqual] n."
}], "Text",
 CellChangeTimes->{{3.5592902174659853`*^9, 3.559290361278048*^9}, {
  3.559290472992955*^9, 3.559290610316268*^9}, {3.55929065124218*^9, 
  3.559291092594887*^9}, {3.559295324822625*^9, 3.559295343087195*^9}, {
  3.559295464187489*^9, 3.559295465344006*^9}, {3.559295521594593*^9, 
  3.5592956210634403`*^9}, {3.559295686052862*^9, 3.559295698772468*^9}, {
  3.5721781562344103`*^9, 3.572178162524353*^9}, {3.5721785037793407`*^9, 
  3.572178608484971*^9}, {3.5734564587237988`*^9, 3.573456463888629*^9}, {
  3.573888250541217*^9, 3.573888458687852*^9}, {3.5738884938151073`*^9, 
  3.573888748021229*^9}, {3.573899618156705*^9, 3.5738996213472443`*^9}}],

Cell[TextData[{
 "For example we can encode an MC by defining ",
 StyleBox["tm", "Program"],
 " and ",
 StyleBox["lbl", "Program"],
 " as follows:"
}], "Text",
 CellChangeTimes->{{3.559291270048073*^9, 3.559291305511608*^9}, {
  3.5592914372439404`*^9, 3.5592915621462917`*^9}, {3.559291820864118*^9, 
  3.55929183689345*^9}, {3.559295648906727*^9, 3.5592956530425863`*^9}, {
  3.5592957590963306`*^9, 3.5592957676777487`*^9}, {3.5721786181807756`*^9, 
  3.57217861930867*^9}, {3.57388876534886*^9, 3.573888787467228*^9}, {
  3.573898699654695*^9, 3.5738987175324383`*^9}, {3.573899657281632*^9, 
  3.573899658697626*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"lbl", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "1", ",", "1", ",", "1", ",", "2", ",", "1"}],
     "}"}]}], ";", " ", 
  RowBox[{"tm", "=", 
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {"0", 
       FractionBox["1", "3"], 
       FractionBox["1", "3"], 
       FractionBox["1", "6"], "0", 
       FractionBox["1", "6"], "0"},
      {"0", "0", 
       FractionBox["2", "5"], 
       FractionBox["2", "5"], "0", 
       FractionBox["1", "5"], "0"},
      {"0", 
       FractionBox["1", "2"], 
       FractionBox["1", "2"], "0", "0", "0", "0"},
      {
       FractionBox["1", "3"], 
       FractionBox["1", "3"], 
       FractionBox["1", "3"], "0", "0", "0", "0"},
      {
       FractionBox["2", "5"], 
       FractionBox["2", "5"], 
       FractionBox["1", "5"], "0", "0", "0", "0"},
      {
       FractionBox["1", "2"], 
       FractionBox["1", "10"], "0", 
       FractionBox["1", "5"], "0", 
       FractionBox["1", "5"], "0"},
      {"0", 
       FractionBox["1", "5"], 
       FractionBox["1", "3"], "0", 
       FractionBox["1", "10"], 
       FractionBox["1", "5"], 
       FractionBox["1", "6"]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.559291106023691*^9, 3.559291123273951*^9}, {
  3.5592911985278*^9, 3.559291262790923*^9}, {3.559291310139451*^9, 
  3.55929131164038*^9}, {3.559291354846352*^9, 3.5592913753750687`*^9}, {
  3.559291420176618*^9, 3.559291426548358*^9}, {3.559291576586495*^9, 
  3.5592915784593973`*^9}, {3.573888771463768*^9, 3.5738887717354918`*^9}}],

Cell["\<\
Then, the MC can be displayed by means of its undelying graph. Labels are \
displayed using different colors.\
\>", "Text",
 CellChangeTimes->{{3.559291587218378*^9, 3.5592917846602783`*^9}, {
  3.559291874479889*^9, 3.5592918865437307`*^9}, {3.559292667567462*^9, 
  3.559292705895445*^9}, {3.5592957035881157`*^9, 3.559295737621191*^9}, {
  3.55929578875921*^9, 3.559295820255541*^9}, {3.5738887990424633`*^9, 
  3.573888799450368*^9}, {3.5738987269261312`*^9, 3.573898741573411*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlotMC", "[", 
  RowBox[{"MC", "[", 
   RowBox[{"tm", ",", "lbl"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5738887777330914`*^9, 3.573888778012912*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 6, 5, 
      7}, {{{1, 2}, {1, 3}, {1, 4}, {1, 5}, {2, 3}, {2, 4}, {2, 5}, {3, 2}, {
       3, 3}, {4, 1}, {4, 2}, {4, 3}, {6, 1}, {6, 2}, {6, 3}, {5, 1}, {5, 
       2}, {5, 4}, {5, 5}, {7, 2}, {7, 3}, {7, 6}, {7, 5}, {7, 7}}, Null}, {
      EdgeLabels -> {
        DirectedEdge[1, 4] -> Rational[1, 6], DirectedEdge[5, 2] -> 
         Rational[2, 5], DirectedEdge[5, 1] -> Rational[2, 5], 
         DirectedEdge[2, 4] -> Rational[2, 5], DirectedEdge[5, 3] -> 
         Rational[1, 5], DirectedEdge[3, 3] -> Rational[1, 2], 
         DirectedEdge[4, 2] -> Rational[1, 3], DirectedEdge[4, 1] -> 
         Rational[1, 3], DirectedEdge[2, 3] -> Rational[2, 5], 
         DirectedEdge[1, 6] -> Rational[1, 6], DirectedEdge[1, 3] -> 
         Rational[1, 3], DirectedEdge[7, 5] -> Rational[1, 10], 
         DirectedEdge[3, 2] -> Rational[1, 2], DirectedEdge[6, 4] -> 
         Rational[1, 5], DirectedEdge[2, 6] -> Rational[1, 5], 
         DirectedEdge[6, 2] -> Rational[1, 10], DirectedEdge[7, 2] -> 
         Rational[1, 5], DirectedEdge[7, 3] -> Rational[1, 3], 
         DirectedEdge[4, 3] -> Rational[1, 3], DirectedEdge[1, 2] -> 
         Rational[1, 3], DirectedEdge[7, 7] -> Rational[1, 6], 
         DirectedEdge[6, 1] -> Rational[1, 2], DirectedEdge[6, 6] -> 
         Rational[1, 5], DirectedEdge[7, 6] -> Rational[1, 5]}, 
       VertexLabels -> {"Name"}, VertexSize -> {0.1}, VertexStyle -> {2 -> Hue[
           Rational[1, 3]], 1 -> Hue[
           Rational[1, 2]], 7 -> Hue[
           Rational[1, 2]], 5 -> Hue[
           Rational[1, 2]], 6 -> Hue[
           Rational[1, 3]], 4 -> Hue[
           Rational[1, 2]], 3 -> Hue[
           Rational[1, 2]]}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Arrowheads[0.03409721592004708], 
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$1", Automatic, Center], 
           DynamicLocation["VertexID$2", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$1"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$1", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$1", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$2"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$2", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$1", Automatic, Center], {
            0.3768094930596234, 0.9631089573773981}, 
            DynamicLocation["VertexID$4", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$3"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$3", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$1", Automatic, Center], {
            0.6935635468266274, 0.5598565893921935}, 
            DynamicLocation["VertexID$5", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$4"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$4", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$2", Automatic, Center], {
            1.0236768310547613`, 0.900614583637093}, 
            DynamicLocation["VertexID$3", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$5"], 
        InsetBox[
         FormBox[
          FractionBox["2", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$5", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$2", Automatic, Center], {
            0.4225711879230117, 0.5486254135950104}, 
            DynamicLocation["VertexID$4", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$6"], 
        InsetBox[
         FormBox[
          FractionBox["2", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$6", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$2", Automatic, Center], {
            0.7393252416900157, 0.14537304560980555`}, 
            DynamicLocation["VertexID$5", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$7"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$7", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$3", Automatic, Center], {
            1.2505245510880303`, 0.8020077149691714}, 
            DynamicLocation["VertexID$2", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$8"], 
        InsetBox[
         FormBox[
          FractionBox["1", "2"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$8", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$3", Automatic, Center], {
            1.1194587481462863`, 1.3660226601590897`}, {1.1217839520455604`, 
            1.5637207846074421`}, {1.2073187801927667`, 1.666714145725991}, {
            1.5620134475669551`, 1.590247411629336}, {1.5975153035431404`, 
            1.4611603964693514`}, {1.518178390257234, 1.2800648162531734`}, 
            DynamicLocation["VertexID$3", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$9"], 
        InsetBox[
         FormBox[
          FractionBox["1", "2"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$9", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$4", Automatic, Center], {
            0.2832635908360529, 1.1681021892635426`}, 
            DynamicLocation["VertexID$1", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$10"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$10", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$4", Automatic, Center], {
            0.5557736766850955, 0.8524615805109228}, 
            DynamicLocation["VertexID$2", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$11"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$11", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$4", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$12"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$12", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$5", Automatic, Center], {
            0.31585461950197896`, 0.6563567176528975}, 
            DynamicLocation["VertexID$1", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$13"], 
        InsetBox[
         FormBox[
          FractionBox["1", "2"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$13", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$5", Automatic, Center], {
            0.5883647053510215, 0.340716108900278}, 
            DynamicLocation["VertexID$2", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$14"], 
        InsetBox[
         FormBox[
          FractionBox["1", "10"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$14", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$5", Automatic, Center], 
           DynamicLocation["VertexID$4", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$15"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$15", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$5", Automatic, Center], {
            0.4563515471075266, -0.18104295455882075`}, {
            0.3900662772639196, -0.3768475714428573}, {
            0.26940536877164023`, -0.44818655117138867`}, \
{-0.040705818710672914`, -0.2347804016271719}, {-0.017181175350125033`, \
-0.09659611879569688}, {0.14202118729931454`, 0.035266661086195694`}, 
            DynamicLocation["VertexID$5", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$16"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$16", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$6", Automatic, Center], 
           DynamicLocation["VertexID$1", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$17"], 
        InsetBox[
         FormBox[
          FractionBox["2", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$17", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$6", Automatic, Center], 
           DynamicLocation["VertexID$2", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$18"], 
        InsetBox[
         FormBox[
          FractionBox["2", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$18", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$6", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$19"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$19", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$7", Automatic, Center], 
           DynamicLocation["VertexID$2", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$20"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$20", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$7", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$21"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$21", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$7", Automatic, Center], 
           DynamicLocation["VertexID$5", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$22"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$22", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$7", Automatic, Center], 
           DynamicLocation["VertexID$6", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$23"], 
        InsetBox[
         FormBox[
          FractionBox["1", "10"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$23", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$7", Automatic, Center], {
            1.817673173883271, 0.03630905780239385}, {
            1.977051140776976, -0.09534142134665145}, {
            2.0007599341341455`, -0.23349422799362862`}, {
            1.6909334480662952`, -0.44731350167078576`}, {
            1.5701775667280253`, -0.3761354011825897}, {
            1.5036313889529034`, -0.1804193026754255}, 
            DynamicLocation["VertexID$7", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$24"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$24", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.6600730838956763, 1.216213307045091}, 
            0.03178917570437877], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.978344864608107, 0.4860891545100835}, 
            0.03178917570437877], 
           Hue[
            Rational[1, 3]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.2958565175346843`, 1.2165331440961806`}, 
            0.03178917570437877], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{0., 0.9149978395958496}, 0.03178917570437877], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{0.34934508243292994`, 0.}, 0.03178917570437877], 
           Hue[
            Rational[1, 3]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["6", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.9584992360127116`, 0.9164941420493009}, 
            0.03178917570437877], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.6103964660076184`, 0.000766108434419932}, 
            0.03178917570437877], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$7"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{3.7606933090100982`, 
       359.42675846962936`}, {-184.2393066909899, 179.2393066909899}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output",
 CellChangeTimes->{
  3.5592917887948503`*^9, 3.559300923004487*^9, 3.559368287629298*^9, 
   3.559563500751689*^9, {3.5721562242854223`*^9, 3.5721562339594793`*^9}, 
   3.5721646825727463`*^9, {3.5721684436605473`*^9, 3.5721684473207617`*^9}, {
   3.572168528073909*^9, 3.572168538663104*^9}, 3.5721685931208277`*^9, 
   3.572168704126997*^9, 3.572175154607194*^9, 3.5721754573658533`*^9, 
   3.572178653456588*^9, 3.572547456729067*^9, 3.573890421317492*^9, 
   3.573898812225092*^9, 3.573898872459243*^9, 3.576559381219046*^9}]
}, Open  ]],

Cell[TextData[{
 "Alternatively, one may use the functions ",
 StyleBox["MCtm", "Program"],
 " to construct the transition matrix, listing only the values different from \
zero. Given the list of rules ",
 StyleBox["tmRules", "Program"],
 " = { ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"i", ",", "j"}], "}"}], "\[Rule]", " ", 
      RowBox[{
       RowBox[{"\[Pi]", "(", 
        RowBox[{
         SubscriptBox["s", "i"], ",", 
         SubscriptBox["s", "j"]}], ")"}], ":", " ", 
       RowBox[{
        RowBox[{"\[Pi]", "(", 
         RowBox[{
          SubscriptBox["s", "i"], ",", 
          SubscriptBox["s", "j"]}], ")"}], " ", "\[NotEqual]", " ", "0"}]}]}],
      ",", " ", 
     RowBox[{"1", " ", "\[LessEqual]", " ", "i"}], ",", 
     RowBox[{"j", " ", "\[LessEqual]", "n"}]}], " ", "}"}], TraditionalForm]]],
 ", the probabilty transition matrix induced by the probability transition \
function \[Pi] may be constructed by calling ",
 StyleBox["MCtm[tmRules, n]", "Program"],
 "."
}], "Text",
 CellChangeTimes->{{3.5732183557821093`*^9, 3.5732185541642847`*^9}, {
   3.573221420509203*^9, 3.573221655032852*^9}, {3.573221694361526*^9, 
   3.573221993064777*^9}, {3.573459075932345*^9, 3.573459134486761*^9}, {
   3.573459169230999*^9, 3.573459173310443*^9}, {3.57345920764123*^9, 
   3.573459231552876*^9}, {3.573459266326976*^9, 3.573459305986116*^9}, {
   3.573459343315477*^9, 3.573459355034486*^9}, {3.5734594476651773`*^9, 
   3.5734595474914913`*^9}, {3.573459590298663*^9, 3.573459616088747*^9}, {
   3.573889157131212*^9, 3.573889260041176*^9}, 3.5738996993731213`*^9}],

Cell[TextData[{
 "The list of rules may be given explicitly or using patterns. For example, \
the matrix ",
 StyleBox["tm", "Program"],
 " defined above can be constructed as follows"
}], "Text",
 CellChangeTimes->{{3.5732185584691668`*^9, 3.573218775344339*^9}, 
   3.573221870313819*^9, {3.573222002024242*^9, 3.573222148536551*^9}, {
   3.573222180302464*^9, 3.573222210164556*^9}, {3.573459771157456*^9, 
   3.5734597827794743`*^9}, {3.573460912446989*^9, 3.573460941284193*^9}, {
   3.573889302351253*^9, 3.5738893080139914`*^9}, {3.573899718467134*^9, 
   3.5738997188511343`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tmRules", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{"2", "|", "3"}]}], "}"}], "\[Rule]", " ", 
      FractionBox["1", "3"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{"4", "|", "6"}]}], "}"}], "\[Rule]", 
      FractionBox["1", "6"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", 
        RowBox[{"3", "|", "4"}]}], "}"}], "\[Rule]", 
      FractionBox["2", "5"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "6"}], "}"}], "\[Rule]", 
      FractionBox["1", "5"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"3", ",", 
        RowBox[{"2", "|", "3"}]}], "}"}], "\[Rule]", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"4", ",", 
        RowBox[{"1", "|", "2", "|", "3"}]}], "}"}], "\[Rule]", 
      FractionBox["1", "3"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"5", ",", "3"}], "}"}], "\[Rule]", 
      FractionBox["1", "5"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"5", ",", 
        RowBox[{"1", "|", "2"}]}], "}"}], "\[Rule]", 
      FractionBox["2", "5"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"6", ",", "1"}], "}"}], "\[Rule]", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"6", ",", "2"}], "}"}], "\[Rule]", 
      FractionBox["1", "10"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"6", ",", 
        RowBox[{"4", "|", "6"}]}], "}"}], "\[Rule]", 
      FractionBox["1", "5"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"7", ",", "3"}], "}"}], "\[Rule]", 
      FractionBox["1", "3"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"7", ",", 
        RowBox[{"2", "|", "6"}]}], "}"}], "\[Rule]", 
      FractionBox["1", "5"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"7", ",", "5"}], "}"}], "\[Rule]", 
      FractionBox["1", "10"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"7", ",", "7"}], "}"}], "\[Rule]", 
      FractionBox["1", "6"]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.547971555364769*^9, 3.547971798684469*^9}, {
   3.547971852250057*^9, 3.54797186003193*^9}, {3.548731146234764*^9, 
   3.548731238070322*^9}, {3.549855487546175*^9, 3.549855683923971*^9}, {
   3.549855715896656*^9, 3.549855851553895*^9}, 3.5498559706441708`*^9, {
   3.549856116104793*^9, 3.549856118890915*^9}, {3.549856171892847*^9, 
   3.549856235937093*^9}, {3.549857188071733*^9, 3.5498571884785023`*^9}, {
   3.54985838583355*^9, 3.549858385936768*^9}, {3.557855184828906*^9, 
   3.557855207537613*^9}, {3.558794802480484*^9, 3.5587948464733143`*^9}, {
   3.559288040701201*^9, 3.559288102281488*^9}, {3.559290383643318*^9, 
   3.559290447420854*^9}, {3.559292010778562*^9, 3.559292037337121*^9}, {
   3.572155189592141*^9, 3.572155193449833*^9}, {3.572155260257164*^9, 
   3.572155276633171*^9}, {3.572155323573617*^9, 3.572155476966711*^9}, {
   3.572155831914188*^9, 3.572155834528801*^9}, {3.572155892377841*^9, 
   3.572155960336506*^9}, {3.573887964101301*^9, 3.573888028273761*^9}, {
   3.5738880758408546`*^9, 3.57388815366691*^9}, {3.573888208079338*^9, 
   3.573888215286756*^9}, {3.57388918866642*^9, 3.573889191835311*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MCtm", "[", 
   RowBox[{"tmRules", ",", "7"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.559292298103937*^9, 3.559292342091784*^9}, {
   3.5592963707610807`*^9, 3.559296381851776*^9}, {3.5721552423426123`*^9, 
   3.572155256654295*^9}, 3.573889583707469*^9, {3.573889638619137*^9, 
   3.573889641786908*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      FractionBox["1", "3"], 
      FractionBox["1", "3"], 
      FractionBox["1", "6"], "0", 
      FractionBox["1", "6"], "0"},
     {"0", "0", 
      FractionBox["2", "5"], 
      FractionBox["2", "5"], "0", 
      FractionBox["1", "5"], "0"},
     {"0", 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], "0", "0", "0", "0"},
     {
      FractionBox["1", "3"], 
      FractionBox["1", "3"], 
      FractionBox["1", "3"], "0", "0", "0", "0"},
     {
      FractionBox["2", "5"], 
      FractionBox["2", "5"], 
      FractionBox["1", "5"], "0", "0", "0", "0"},
     {
      FractionBox["1", "2"], 
      FractionBox["1", "10"], "0", 
      FractionBox["1", "5"], "0", 
      FractionBox["1", "5"], "0"},
     {"0", 
      FractionBox["1", "5"], 
      FractionBox["1", "3"], "0", 
      FractionBox["1", "10"], 
      FractionBox["1", "5"], 
      FractionBox["1", "6"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {7, 7}, 0, {
     1, {{0, 4, 7, 9, 12, 15, 19, 24}, {{4}, {3}, {2}, {6}, {6}, {4}, {3}, {
       2}, {3}, {2}, {1}, {3}, {1}, {2}, {3}, {1}, {4}, {6}, {2}, {5}, {3}, {
       6}, {2}, {7}}}, {
      Rational[1, 6], Rational[1, 3], Rational[1, 3], Rational[1, 6], 
       Rational[1, 5], Rational[2, 5], Rational[2, 5], Rational[1, 2], 
       Rational[1, 2], Rational[1, 3], Rational[1, 3], Rational[1, 3], 
       Rational[2, 5], Rational[2, 5], Rational[1, 5], Rational[1, 2], 
       Rational[1, 5], Rational[1, 5], Rational[1, 10], Rational[1, 10], 
       Rational[1, 3], Rational[1, 5], Rational[1, 5], Rational[
       1, 6]}}]]]]], "Output",
 CellChangeTimes->{{3.559292306484222*^9, 3.55929234285944*^9}, 
   3.559296384569816*^9, 3.559368287776456*^9, 3.559563500900271*^9, 
   3.572155975508606*^9, 3.572156245146085*^9, 3.572164688613504*^9, 
   3.572169092949054*^9, 3.572175154714837*^9, 3.572175457447937*^9, 
   3.573890427750614*^9, 3.5738988123141813`*^9, 3.57389887255514*^9, 
   3.576559381325589*^9}]
}, Open  ]],

Cell[TextData[{
 "One can check that \[ScriptCapitalM] is a well-formed MC by calling ",
 StyleBox["MCQ[", "Program"],
 "\[ScriptCapitalM]",
 StyleBox["]", "Program"]
}], "Text",
 CellChangeTimes->{{3.559292410492507*^9, 3.559292528005828*^9}, 
   3.559292596933975*^9, {3.572179097015059*^9, 3.572179118453451*^9}, {
   3.572179148795312*^9, 3.572179191369382*^9}, {3.573899778329019*^9, 
   3.573899805195805*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MCQ", "[", 
  RowBox[{"MC", "[", 
   RowBox[{"tm", ",", "lbl"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.559292599821102*^9, 3.559292615533887*^9}, 
   3.5721790970830307`*^9, 3.57389045464832*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.5592926187033663`*^9, 3.5593009331857023`*^9, 3.559368287831923*^9, 
   3.559563500961618*^9, 3.5721562519998283`*^9, 3.572175154752898*^9, 
   3.5721754574841747`*^9, {3.5738904327484922`*^9, 3.573890455620891*^9}, 
   3.573898812369635*^9, 3.573898872594611*^9, 3.576559381399735*^9}]
}, Open  ]],

Cell[TextData[{
 "Given a sequence of Markov chains ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[ScriptCapitalM]", "1"], ",", "...", ",", " ", 
    SubscriptBox["\[ScriptCapitalM]", "k"]}], TraditionalForm]]],
 ", one may construct their disjoint union using the function ",
 StyleBox["JoinMC", "Program"]
}], "Text",
 CellChangeTimes->{{3.559302047201599*^9, 3.559302257569882*^9}, {
  3.5721792296616077`*^9, 3.572179280457987*^9}, {3.573899830677786*^9, 
  3.57389984674855*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"M1", " ", "=", " ", 
   RowBox[{"MC", "[", 
    RowBox[{
     RowBox[{"MCtm", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", "1"}], ",", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
          FractionBox["1", "3"]}], ",", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", "2"}], "}"}], "\[Rule]", 
          FractionBox["2", "3"]}]}], "}"}], ",", "2"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"M2", " ", "=", 
   RowBox[{"MC", "[", 
    RowBox[{
     RowBox[{"MCtm", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{"1", "|", "2"}]}], "}"}], "\[Rule]", 
          FractionBox["1", "2"]}], ",", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
          FractionBox["1", "3"]}], ",", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", "2"}], "}"}], "\[Rule]", 
          FractionBox["2", "3"]}]}], "}"}], ",", "2"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"M3", "=", 
   RowBox[{"MC", "[", 
    RowBox[{
     RowBox[{"MCtm", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", 
          FractionBox["1", "4"]}], ",", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "2"}], "}"}], "\[Rule]", 
          FractionBox["3", "4"]}], ",", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
          FractionBox["1", "3"]}], ",", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", "2"}], "}"}], "\[Rule]", 
          FractionBox["2", "3"]}], ",", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"3", ",", "2"}], "}"}], "\[Rule]", 
          FractionBox["3", "5"]}], ",", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"3", ",", "1"}], "}"}], "\[Rule]", 
          FractionBox["2", "5"]}]}], "}"}], ",", "3"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"JoinMC", "[", 
   RowBox[{"M1", ",", "M2", ",", "M3"}], "]"}], "//", "PlotMC"}]}], "Input",
 CellChangeTimes->{{3.559302266820766*^9, 3.559302547093886*^9}, {
  3.559303249870447*^9, 3.559303291377852*^9}, {3.559303439943088*^9, 
  3.559303470265479*^9}, {3.5593035166011057`*^9, 3.559303601404265*^9}, {
  3.572156028182744*^9, 3.572156043364087*^9}, {3.572156137298748*^9, 
  3.5721561825146103`*^9}, {3.573889382088077*^9, 3.573889385981633*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 
      7}, {{{1, 1}, {2, 1}, {2, 2}, {3, 3}, {3, 4}, {4, 3}, {4, 4}, {5, 5}, {
       5, 6}, {6, 5}, {6, 6}, {7, 6}, {7, 5}}, Null}, {
      EdgeLabels -> {
        DirectedEdge[4, 4] -> Rational[2, 3], DirectedEdge[3, 3] -> 
         Rational[1, 2], DirectedEdge[6, 5] -> Rational[1, 3], 
         DirectedEdge[2, 1] -> Rational[1, 3], DirectedEdge[3, 4] -> 
         Rational[1, 2], DirectedEdge[7, 5] -> Rational[2, 5], 
         DirectedEdge[5, 6] -> Rational[3, 4], DirectedEdge[4, 3] -> 
         Rational[1, 3], DirectedEdge[1, 1] -> 1, DirectedEdge[6, 6] -> 
         Rational[2, 3], DirectedEdge[5, 5] -> Rational[1, 4], 
         DirectedEdge[7, 6] -> Rational[3, 5], DirectedEdge[2, 2] -> 
         Rational[2, 3]}, VertexLabels -> {"Name"}, VertexSize -> {0.1}, 
       VertexStyle -> {2 -> Hue[
           Rational[1, 3]], 1 -> Hue[
           Rational[1, 2]], 7 -> Hue[
           Rational[1, 2]], 5 -> Hue[
           Rational[1, 3]], 6 -> Hue[
           Rational[1, 3]], 4 -> Hue[
           Rational[1, 2]], 3 -> Hue[
           Rational[1, 3]]}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Arrowheads[0.024784227789982075`], 
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$1", Automatic, Center], {
            1.9787941033401228`, -3.344405930826432}, {
            2.1776725808777138`, -3.288009688365838}, {
            2.304843205352171, -3.346966767140711}, {
            2.3048432053521712`, -3.7234121592827574`}, {
            2.177672580877714, -3.7823692380576306`}, {
            1.9787941033401233`, -3.7259729955970364`}, 
            DynamicLocation["VertexID$1", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$1"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$1", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$2", Automatic, Center], 
           DynamicLocation["VertexID$1", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$2"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$2", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$2", Automatic, Center], {
            0.801835592404602, -3.725972995597037}, {
            0.6029571148670112, -3.782369238057631}, {
            0.47578649039255394`, -3.723412159282758}, {
            0.47578649039255394`, -3.3469667671407115`}, {
            0.6029571148670112, -3.2880096883658383`}, {
            0.801835592404602, -3.3444059308264324`}, 
            DynamicLocation["VertexID$2", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$3"], 
        InsetBox[
         FormBox[
          FractionBox["2", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$3", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$3", Automatic, Center], {
            4.759423799084848, -0.6995313154870602}, {
            4.9583022766224385`, -0.6431350730264658}, {
            5.085472901096896, -0.702092151801339}, {
            5.085472901096897, -1.0785375439433853`}, {
            4.958302276622439, -1.1374946227182585`}, {
            4.759423799084848, -1.0810983802576646`}, 
            DynamicLocation["VertexID$3", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$4"], 
        InsetBox[
         FormBox[
          FractionBox["1", "2"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$4", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$3", Automatic, Center], {
            4.170944543617089, -1.0455955560905326`}, 
            DynamicLocation["VertexID$4", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$5"], 
        InsetBox[
         FormBox[
          FractionBox["1", "2"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$5", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$4", Automatic, Center], {
            4.170944543617089, -0.7350341396541926}, 
            DynamicLocation["VertexID$3", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$6"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$6", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$4", Automatic, Center], {
            3.582465288149327, -1.0810983802576648`}, {
            3.3835868106117366`, -1.137494622718259}, {
            3.256416186137279, -1.0785375439433857`}, {
            3.256416186137279, -0.7020921518013394}, {
            3.3835868106117366`, -0.6431350730264662}, {
            3.582465288149327, -0.6995313154870603}, 
            DynamicLocation["VertexID$4", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$7"], 
        InsetBox[
         FormBox[
          FractionBox["2", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$7", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$5", Automatic, Center], {
            1.0807830576668722`, -1.8437157876519505`}, {
            1.1364728836153348`, -2.0427932305659433`}, {
            1.0770646934926986`, -2.1697537433769853`}, {
            0.7006216737202872, -2.1684172817775065`}, {
            0.6421164493915725, -2.041038148505464}, {
            0.69921839754283, -1.8423611430199893`}, 
            DynamicLocation["VertexID$5", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$8"], 
        InsetBox[
         FormBox[
          FractionBox["1", "4"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$8", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$5", Automatic, Center], {
            1.0076499993547776`, -1.244320019837125}, 
            DynamicLocation["VertexID$6", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$9"], 
        InsetBox[
         FormBox[
          FractionBox["3", "4"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$9", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$6", Automatic, Center], {
            1.2760511257320015`, -1.4005545955022476`}, 
            DynamicLocation["VertexID$5", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$10"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$10", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$6", Automatic, Center], {
            1.3753635332698664`, -0.6807865309835653}, {
            1.5199247308888553`, -0.5330189934988128}, {
            1.6595798543213207`, -0.5209877273163661}, {
            1.8466439816829885`, -0.8476651607570564}, {
            1.7655830380334607`, -0.962021744658195}, {
            1.5649727342089839`, -1.0119085263823673`}, 
            DynamicLocation["VertexID$6", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$11"], 
        InsetBox[
         FormBox[
          FractionBox["2", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$11", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$7", Automatic, Center], 
           DynamicLocation["VertexID$5", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$12"], 
        InsetBox[
         FormBox[
          FractionBox["2", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$12", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$7", Automatic, Center], 
           DynamicLocation["VertexID$6", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$13"], 
        InsetBox[
         FormBox[
          FractionBox["3", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$13", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.8903148478723626`, -3.5351894632117347`}, 
            0.04999999607885944], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.8903148478723626, -3.5351894632117347`}, 
            0.04999999607885944], 
           Hue[
            Rational[1, 3]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{4.670944543617088, -0.8903148478723626}, 
            0.04999999607885944], 
           Hue[
            Rational[1, 3]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.6709445436170878`, -0.8903148478723626}, 
            0.04999999607885944], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{0.8903148478723626, -1.7545597674670095`}, 
            0.04999999607885944], 
           Hue[
            Rational[1, 3]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.3933862772144165`, -0.8903148478723624}, 
            0.04999999607885944], 
           Hue[
            Rational[1, 3]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox["6", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.3933926444226531, -0.8867647646736834}, 
            0.04999999607885944], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$7"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{7.89209955901009, 
       548.2393066909899}, {-190.2393066909899, 185.2393066909899}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImageSize->{557.5703125, Automatic}]], "Output",
 CellChangeTimes->{{3.559303455323085*^9, 3.5593034711015*^9}, {
   3.559303533162944*^9, 3.55930355418781*^9}, {3.5593036032122173`*^9, 
   3.5593036069832077`*^9}, 3.559368287923834*^9, 3.5595635010614557`*^9, 
   3.572156192782827*^9, 3.572156255187663*^9, {3.572169098744081*^9, 
   3.572169101125059*^9}, 3.5721751547902822`*^9, 3.5721754575364*^9, 
   3.5738904601902027`*^9, 3.5738988124153023`*^9, 3.573898872639496*^9, 
   3.576559381455213*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Run the on-the-fly algorithm", "Subsection",
 CellChangeTimes->{{3.559292749537469*^9, 3.559292784161332*^9}}],

Cell[TextData[{
 "Given a MC \[ScriptCapitalM] = ",
 StyleBox["MC[\[Pi],\[ScriptL]]", "Program"],
 ", a discount factor \[Lambda] \[Element] (0,1], and a list of pairs of \
states Q, the bisimilarity distance between the pairs in Q is computed by \
calling the function ",
 StyleBox["BDistMC", "Program"],
 " as follows"
}], "Text",
 CellChangeTimes->{{3.55929279002621*^9, 3.559292975541119*^9}, {
   3.559293163747102*^9, 3.5592933072146997`*^9}, {3.559296536698812*^9, 
   3.5592965424339314`*^9}, {3.572179315023313*^9, 3.572179365227734*^9}, 
   3.572179416867509*^9, 3.573890000792625*^9, {3.5738998878704576`*^9, 
   3.573899903010824*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"M", "=", 
   RowBox[{"MC", "[", 
    RowBox[{"tm", ",", "lbl"}], "]"}]}], ";", " ", 
  RowBox[{"\[Lambda]", " ", "=", " ", "1"}], ";", " ", 
  RowBox[{"Q", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"BDistMC", "[", 
  RowBox[{"M", ",", "\[Lambda]", ",", "Q"}], "]"}]}], "Input",
 CellChangeTimes->{{3.559292979708026*^9, 3.559293010991379*^9}, {
   3.559293055529606*^9, 3.5592930865255623`*^9}, {3.55929314693382*^9, 
   3.55929314763829*^9}, {3.559293314376917*^9, 3.559293327355328*^9}, {
   3.572169321464039*^9, 3.572169340024008*^9}, 3.572174779804635*^9, 
   3.5738900006442213`*^9, {3.573890472413806*^9, 3.573890473814157*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
    FractionBox["1", "5"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "5"}], "}"}], "\[Rule]", 
    FractionBox["472", "4075"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}], "\[Rule]", "1"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.559293126854739*^9, 3.5592931486963673`*^9}, {
   3.559293320924827*^9, 3.559293328487162*^9}, 3.559296554852174*^9, 
   3.559300897462916*^9, 3.559300936340206*^9, 3.559368287995039*^9, 
   3.559563501169026*^9, 3.5721562611673527`*^9, {3.57216929973177*^9, 
   3.57216934639235*^9}, 3.5721751548732977`*^9, 3.5721754576084023`*^9, 
   3.572179370536498*^9, {3.573890467955414*^9, 3.573890477090995*^9}, 
   3.5738905433646603`*^9, 3.573898812525775*^9, 3.5738988727365923`*^9, 
   3.576559381542789*^9}]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["Verbose", "Program"],
 " option may be used to trace the computation steps"
}], "Text",
 CellChangeTimes->{{3.559293356367012*^9, 3.559293415423354*^9}, {
   3.559296578666943*^9, 3.55929657901906*^9}, 3.5721794085530167`*^9, {
   3.5721794512313337`*^9, 3.572179529867896*^9}, {3.5738971787198343`*^9, 
   3.573897217417821*^9}, {3.5738999189774427`*^9, 3.573899920409656*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BDistMC", "[", 
  RowBox[{"M", ",", "\[Lambda]", ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "}"}], ",", 
   RowBox[{"Verbose", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.559293448300482*^9, 3.559293472436658*^9}, {
   3.559293601615106*^9, 3.559293603181941*^9}, 3.572174779839336*^9, 
   3.573890000673893*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Pairs to compute: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "}"}]}],
  SequenceForm["Pairs to compute: ", {{1, 4}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.5738905858861027`*^9, 3.573898812564992*^9, 
  3.573898872794509*^9, 3.5765593815946693`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Picked pair: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "}"}]}],
  SequenceForm["Picked pair: ", {{1, 4}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.5738905858861027`*^9, 3.573898812564992*^9, 
  3.573898872794509*^9, 3.5765593816349363`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{1, 4}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{3.5738905858861027`*^9, 3.573898812564992*^9, 
  3.573898872794509*^9, 3.576559381636797*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"1", "2", "3"}}]]]}]], "Print",
 CellChangeTimes->{3.5738905858861027`*^9, 3.573898812564992*^9, 
  3.573898872794509*^9, 3.576559381639737*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"2", "3"}, {"1", "2", "3"}}]]]}]], "Print",\

 CellChangeTimes->{3.5738905858861027`*^9, 3.573898812564992*^9, 
  3.573898872794509*^9, 3.576559381707741*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.5738905858861027`*^9, 3.573898812564992*^9, 
  3.573898872794509*^9, 3.5765593817093477`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", 
        RowBox[{"-", 
         FractionBox["1", "6"]}]},
       {"0", "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {2, 2}, 0, {
       1, {{0, 2, 3}, {{1}, {2}, {2}}}, {1, Rational[-1, 6], 1}}]]]], 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["5", "6"]},
        {
         FractionBox["1", "2"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {2}, 0, {1, {{0, 2}, {{1}, {2}}}, {
         Rational[5, 6], 
         Rational[1, 2]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["11", "12"]},
        {
         FractionBox["1", "2"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[
    Automatic, {2, 2}, 0, {
     1, {{0, 2, 3}, {{1}, {2}, {2}}}, {1, Rational[-1, 6], 1}}]], 
   MatrixForm[{"d(1,4)", "d(3,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {2}, 0, {1, {{0, 2}, {{1}, {2}}}, {
       Rational[5, 6], 
       Rational[1, 2]}}]], ";  Solution:", 
   MatrixForm[{"d(1,4)", "d(3,4)"}], "=", 
   MatrixForm[{
     Rational[11, 12], 
     Rational[1, 2]}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.5738905858861027`*^9, 3.573898812564992*^9, 
  3.573898872794509*^9, 3.5765593817118673`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Non optimal schedule for: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4"}], "}"}], 
   "\[InvisibleSpace]", "\<\" reduced cost: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "2"}], "\[InvisibleSpace]", "\<\" for introducing \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], "\[InvisibleSpace]", "\<\" as basic\"\>"}],
  SequenceForm[
  "Non optimal schedule for: ", {1, 4}, " reduced cost: ", -2, 
   " for introducing ", {4, 1}, " as basic"],
  Editable->False]], "Print",
 CellChangeTimes->{3.5738905858861027`*^9, 3.573898812564992*^9, 
  3.573898872794509*^9, 3.5765593817160387`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{1, 4}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{3.5738905858861027`*^9, 3.573898812564992*^9, 
  3.573898872794509*^9, 3.576559381717845*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"1", "2", "3"}}]]]}]], "Print",
 CellChangeTimes->{3.5738905858861027`*^9, 3.573898812564992*^9, 
  3.573898872794509*^9, 3.576559381719697*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.5738905858861027`*^9, 3.573898812564992*^9, 
  3.573898872794509*^9, 3.576559381721285*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        FractionBox["5", "6"]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {1, 1}, 0, {1, {{0, 1}, {{1}}}, {Rational[5, 6]}}]]]], 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["1", "6"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {1}, 0, {1, {{0, 1}, {{1}}}, {
         Rational[1, 6]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["1", "5"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[Automatic, {1, 1}, 0, {1, {{0, 1}, {{1}}}, {Rational[5, 6]}}]], 
   MatrixForm[{"d(1,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {1}, 0, {1, {{0, 1}, {{1}}}, {
       Rational[1, 6]}}]], ";  Solution:", 
   MatrixForm[{"d(1,4)"}], "=", 
   MatrixForm[{
     Rational[1, 5]}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.5738905858861027`*^9, 3.573898812564992*^9, 
  3.573898872794509*^9, 3.5765593817234364`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Non optimal schedule for: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4"}], "}"}], 
   "\[InvisibleSpace]", "\<\" reduced cost: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["3", "10"]}], 
   "\[InvisibleSpace]", "\<\" for introducing \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], "\[InvisibleSpace]", "\<\" as basic\"\>"}],
  SequenceForm["Non optimal schedule for: ", {1, 4}, " reduced cost: ", 
   Rational[-3, 10], " for introducing ", {1, 3}, " as basic"],
  Editable->False]], "Print",
 CellChangeTimes->{3.5738905858861027`*^9, 3.573898812564992*^9, 
  3.573898872794509*^9, 3.576559381725165*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{1, 4}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{3.5738905858861027`*^9, 3.573898812564992*^9, 
  3.573898872794509*^9, 3.57655938172672*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0"},
      {
       TagBox["\<\"6\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"1", "2", "3"}}]]]}]], "Print",
 CellChangeTimes->{3.5738905858861027`*^9, 3.573898812564992*^9, 
  3.573898872794509*^9, 3.5765593817285423`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.5738905858861027`*^9, 3.573898812564992*^9, 
  3.573898872794509*^9, 3.5765593817301607`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        FractionBox["5", "6"]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {1, 1}, 0, {1, {{0, 1}, {{1}}}, {Rational[5, 6]}}]]]], 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["1", "6"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {1}, 0, {1, {{0, 1}, {{1}}}, {
         Rational[1, 6]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["1", "5"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[Automatic, {1, 1}, 0, {1, {{0, 1}, {{1}}}, {Rational[5, 6]}}]], 
   MatrixForm[{"d(1,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {1}, 0, {1, {{0, 1}, {{1}}}, {
       Rational[1, 6]}}]], ";  Solution:", 
   MatrixForm[{"d(1,4)"}], "=", 
   MatrixForm[{
     Rational[1, 5]}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.5738905858861027`*^9, 3.573898812564992*^9, 
  3.573898872794509*^9, 3.576559381732267*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total solved TPs: \"\>", "\[InvisibleSpace]", "2"}],
  SequenceForm["Total solved TPs: ", 2],
  Editable->False]], "Print",
 CellChangeTimes->{3.5738905858861027`*^9, 3.573898812564992*^9, 
  3.573898872794509*^9, 3.576559381733919*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Execution Time: \"\>", "\[InvisibleSpace]", 
   "0.0296629999999999983961718186264988617`4.492814985041415", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm[
  "Execution Time: ", 
   0.0296629999999999983961718186264988617`4.492814985041415, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.5738905858861027`*^9, 3.573898812564992*^9, 
  3.573898872794509*^9, 3.576559381735836*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
   FractionBox["1", "5"]}], "}"}]], "Output",
 CellChangeTimes->{3.573890585934311*^9, 3.573898812627742*^9, 
  3.573898872839658*^9, 3.5765593817378607`*^9}]
}, Open  ]],

Cell[TextData[{
 "For computing the distance between all pair of states one can use as query \
list the alias ",
 StyleBox["All", "Program"]
}], "Text",
 CellChangeTimes->{{3.5593007248752117`*^9, 3.5593008502717876`*^9}, {
  3.572179546274996*^9, 3.5721796846416683`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BDistMC", "[", 
  RowBox[{"M", ",", "\[Lambda]", ",", "All"}], "]"}]], "Input",
 CellChangeTimes->{{3.559293448300482*^9, 3.559293472436658*^9}, {
   3.559293601615106*^9, 3.559293603181941*^9}, {3.55930071342197*^9, 
   3.559300719870195*^9}, {3.5593009588707333`*^9, 3.559301007199597*^9}, {
   3.5593010551482897`*^9, 3.5593010571385117`*^9}, 3.5721747798758507`*^9, 
   3.573890000709416*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "3"}], "}"}], "\[Rule]", 
    FractionBox["43", "815"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
    FractionBox["1", "5"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "5"}], "}"}], "\[Rule]", 
    FractionBox["1831", "12225"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "6"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "7"}], "}"}], "\[Rule]", 
    FractionBox["217381", "1813375"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "2"}], "}"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "3"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "4"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "5"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "6"}], "}"}], "\[Rule]", 
    FractionBox["23", "163"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "7"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "1"}], "}"}], "\[Rule]", 
    FractionBox["43", "815"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "2"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "3"}], "}"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
    FractionBox["143", "815"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "5"}], "}"}], "\[Rule]", 
    FractionBox["472", "4075"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "6"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "7"}], "}"}], "\[Rule]", 
    FractionBox["17091", "114100"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "1"}], "}"}], "\[Rule]", 
    FractionBox["1", "5"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "2"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "3"}], "}"}], "\[Rule]", 
    FractionBox["143", "815"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "4"}], "}"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "5"}], "}"}], "\[Rule]", 
    FractionBox["286", "4075"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "6"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "7"}], "}"}], "\[Rule]", 
    FractionBox["44362", "362675"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "1"}], "}"}], "\[Rule]", 
    FractionBox["1831", "12225"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "2"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "3"}], "}"}], "\[Rule]", 
    FractionBox["472", "4075"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "4"}], "}"}], "\[Rule]", 
    FractionBox["286", "4075"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "5"}], "}"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "6"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "7"}], "}"}], "\[Rule]", 
    FractionBox["15688", "217605"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "1"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "2"}], "}"}], "\[Rule]", 
    FractionBox["23", "163"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "3"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "4"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "5"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "6"}], "}"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "7"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7", ",", "1"}], "}"}], "\[Rule]", 
    FractionBox["217381", "1813375"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7", ",", "2"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7", ",", "3"}], "}"}], "\[Rule]", 
    FractionBox["17091", "114100"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7", ",", "4"}], "}"}], "\[Rule]", 
    FractionBox["44362", "362675"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7", ",", "5"}], "}"}], "\[Rule]", 
    FractionBox["15688", "217605"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7", ",", "6"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7", ",", "7"}], "}"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.559300941754623*^9, {3.559300983464848*^9, 3.559301008042636*^9}, 
   3.559301059337799*^9, 3.559368288254915*^9, 3.559563501429984*^9, 
   3.5721562758764477`*^9, 3.572175155155941*^9, 3.572175457802253*^9, {
   3.5738905980309973`*^9, 3.573890609146356*^9}, 3.5738988127940893`*^9, 
   3.573898872992074*^9, 3.576559381895117*^9}]
}, Open  ]],

Cell["\<\
The output is returned as a set of ArrayRules, so that one can easily \
transform it into a matrix using the function SparseArray\
\>", "Text",
 CellChangeTimes->{{3.559301069792654*^9, 3.5593011708574257`*^9}, {
  3.559301251398644*^9, 3.559301257484355*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SparseArray", "[", 
   RowBox[{
    RowBox[{"BDistMC", "[", 
     RowBox[{"M", ",", "\[Lambda]", ",", "All"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"7", ",", "7"}], "}"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.55930117525793*^9, 3.559301216110014*^9}, {
   3.5593012782632217`*^9, 3.5593012851194983`*^9}, 3.572174779892565*^9, {
   3.572179720232394*^9, 3.572179735444812*^9}, 3.5738900007288237`*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "1", 
      FractionBox["43", "815"], 
      FractionBox["1", "5"], 
      FractionBox["1831", "12225"], "1", 
      FractionBox["89081", "713125"]},
     {"1", "0", "1", "1", "1", 
      FractionBox["23", "163"], "1"},
     {
      FractionBox["43", "815"], "1", "0", 
      FractionBox["143", "815"], 
      FractionBox["472", "4075"], "1", 
      FractionBox["17091", "114100"]},
     {
      FractionBox["1", "5"], "1", 
      FractionBox["143", "815"], "0", 
      FractionBox["286", "4075"], "1", 
      FractionBox["86486", "713125"]},
     {
      FractionBox["1831", "12225"], "1", 
      FractionBox["472", "4075"], 
      FractionBox["286", "4075"], "0", "1", 
      FractionBox["152008", "2139375"]},
     {"1", 
      FractionBox["23", "163"], "1", "1", "1", "0", "1"},
     {
      FractionBox["89081", "713125"], "1", 
      FractionBox["17091", "114100"], 
      FractionBox["86486", "713125"], 
      FractionBox["152008", "2139375"], "1", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {7, 7}, 0, {
     1, {{0, 6, 12, 18, 24, 30, 36, 42}, {{2}, {3}, {4}, {5}, {6}, {7}, {1}, {
       3}, {4}, {5}, {6}, {7}, {1}, {2}, {4}, {5}, {6}, {7}, {1}, {2}, {3}, {
       5}, {6}, {7}, {1}, {2}, {3}, {4}, {6}, {7}, {1}, {2}, {3}, {4}, {5}, {
       7}, {1}, {2}, {3}, {4}, {5}, {6}}}, {
      1, Rational[43, 815], Rational[1, 5], Rational[1831, 12225], 1, 
       Rational[89081, 713125], 1, 1, 1, 1, Rational[23, 163], 1, Rational[
       43, 815], 1, Rational[143, 815], Rational[472, 4075], 1, Rational[
       17091, 114100], Rational[1, 5], 1, Rational[143, 815], Rational[
       286, 4075], 1, Rational[86486, 713125], Rational[1831, 12225], 1, 
       Rational[472, 4075], Rational[286, 4075], 1, Rational[152008, 2139375],
        1, Rational[23, 163], 1, 1, 1, 1, Rational[89081, 713125], 1, 
       Rational[17091, 114100], Rational[86486, 713125], Rational[
       152008, 2139375], 1}}]]]]], "Output",
 CellChangeTimes->{{3.559301200512209*^9, 3.559301216983152*^9}, {
   3.5593012801260033`*^9, 3.559301285657709*^9}, 3.559368288452284*^9, 
   3.55956350161639*^9, 3.5721563061108837`*^9, 3.572175155389079*^9, 
   3.572175458019465*^9, {3.572179725461748*^9, 3.572179736614107*^9}, {
   3.573890613658456*^9, 3.573890616039681*^9}, 3.57389881295166*^9, 
   3.573898873197015*^9, 3.5765593820354147`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bisimilarity Distance and Bisimilarity Quotient", "Subsection",
 CellChangeTimes->{{3.5578543051840076`*^9, 3.557854310966935*^9}, {
  3.559368474196784*^9, 3.559368474912208*^9}, {3.559368530169324*^9, 
  3.5593685783471603`*^9}, {3.559563479821954*^9, 3.559563482677684*^9}}],

Cell[TextData[{
 "Due to the fact that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Delta]", "\[Lambda]"], TraditionalForm]]],
 "(s,t) equals zero if and only if the states s and t are bisimilar, the \
algorithm for computing ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Delta]", "\[Lambda]"], TraditionalForm]]],
 " can be used to compute the bisimilarity classes and the bisimilarity \
quotient for an MC."
}], "Text",
 CellChangeTimes->{{3.573297892113584*^9, 3.573297910206666*^9}, {
  3.5732979476179256`*^9, 3.573298071769981*^9}, {3.5734568895504923`*^9, 
  3.573456914237727*^9}, {3.573461842194907*^9, 3.573461919789302*^9}, {
  3.573898363290029*^9, 3.5738983634965*^9}, {3.573899974529872*^9, 
  3.5738999893845987`*^9}}],

Cell["\<\
Let \[ScriptCapitalM] = (S, \[CapitalSigma], \[Pi], \[ScriptL]) be a \
(psedo-randomly generated) Markov chain with 50 states and outer-degree 2\
\>", "Text",
 CellChangeTimes->{{3.559368691084111*^9, 3.559368746400116*^9}, {
   3.559368786593587*^9, 3.559368822042343*^9}, {3.559370344410762*^9, 
   3.5593703445281143`*^9}, 3.573898432006102*^9, {3.573900003327763*^9, 
   3.573900014678843*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"numStates", "=", "50"}], ";", 
  RowBox[{"outerDegree", "=", "2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mc", "=", 
   RowBox[{"RandomMC", "[", 
    RowBox[{"numStates", ",", "outerDegree"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"PlotMC", "@", "mc"}]}], "Input",
 CellChangeTimes->{{3.557854348409972*^9, 3.557854390563903*^9}, {
   3.557854817576297*^9, 3.557854818758997*^9}, {3.557854979732957*^9, 
   3.55785498203126*^9}, {3.557855117057027*^9, 3.5578551240410633`*^9}, {
   3.557855287685052*^9, 3.557855314685761*^9}, {3.557855427026854*^9, 
   3.557855447872963*^9}, {3.557855479723105*^9, 3.5578554798427067`*^9}, {
   3.5578556451605797`*^9, 3.5578556452953997`*^9}, {3.5578557153231916`*^9, 
   3.557855715450189*^9}, {3.5580621564486556`*^9, 3.558062156573456*^9}, {
   3.559303765859511*^9, 3.559303766145413*^9}, {3.5593143695437813`*^9, 
   3.5593143698771067`*^9}, {3.559314456250338*^9, 3.559314460351667*^9}, {
   3.559368752540123*^9, 3.559368775476655*^9}, {3.5593689659966183`*^9, 
   3.559368966077454*^9}, 3.559563551909025*^9, 3.5721754233757477`*^9, {
   3.5725480823797913`*^9, 3.5725480824788723`*^9}, {3.5725481653463287`*^9, 
   3.57254816539602*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 48, 50, 2, 45, 3, 49, 4, 5, 6, 7, 8, 9, 27, 47, 10, 11, 35, 12,
       13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 36, 28, 29, 30,
       31, 32, 37, 33, 39, 34, 38, 40, 42, 41, 43, 44, 
      46}, {{{1, 2}, {1, 3}, {4, 5}, {4, 3}, {6, 7}, {8, 3}, {9, 7}, {10, 
       7}, {10, 3}, {11, 3}, {12, 3}, {13, 14}, {13, 15}, {16, 2}, {16, 3}, {
       17, 18}, {17, 3}, {19, 15}, {19, 2}, {20, 3}, {21, 3}, {22, 1}, {22, 
       11}, {23, 15}, {23, 3}, {24, 3}, {25, 7}, {26, 2}, {26, 3}, {27, 5}, {
       28, 7}, {29, 3}, {30, 7}, {30, 3}, {31, 15}, {32, 18}, {32, 7}, {33, 
       3}, {14, 34}, {14, 3}, {35, 7}, {35, 3}, {36, 1}, {36, 33}, {37, 7}, {
       37, 3}, {38, 3}, {39, 40}, {39, 3}, {41, 42}, {43, 43}, {43, 2}, {18, 
       2}, {18, 3}, {34, 15}, {34, 3}, {40, 3}, {44, 7}, {44, 3}, {42, 7}, {
       42, 3}, {45, 46}, {47, 39}, {47, 7}, {46, 42}, {48, 38}, {48, 3}, {49, 
       33}, {49, 3}, {5, 7}, {5, 3}, {50, 7}, {50, 3}, {15, 5}, {15, 3}, {2, 
       2}, {2, 3}, {7, 3}, {3, 3}}, Null}, {
      EdgeLabels -> {
        DirectedEdge[45, 50] -> Rational[9, 29], DirectedEdge[6, 49] -> 
         Rational[48, 59], DirectedEdge[49, 50] -> 1, DirectedEdge[39, 50] -> 
         Rational[65, 137], DirectedEdge[5, 49] -> 1, DirectedEdge[28, 50] -> 
         Rational[21, 43], DirectedEdge[43, 50] -> Rational[360, 403], 
         DirectedEdge[17, 50] -> 1, DirectedEdge[45, 49] -> Rational[20, 29], 
         DirectedEdge[9, 47] -> Rational[21, 40], DirectedEdge[4, 50] -> 1, 
         DirectedEdge[12, 47] -> Rational[8, 11], DirectedEdge[11, 50] -> 
         Rational[299, 719], DirectedEdge[18, 49] -> 1, DirectedEdge[25, 35] -> 
         Rational[46, 71], DirectedEdge[16, 47] -> Rational[11, 26], 
         DirectedEdge[26, 50] -> 1, DirectedEdge[19, 48] -> Rational[27, 68], 
         DirectedEdge[19, 50] -> Rational[41, 68], DirectedEdge[7, 50] -> 1, 
         DirectedEdge[40, 42] -> 1, DirectedEdge[39, 49] -> Rational[72, 137],
          DirectedEdge[46, 50] -> Rational[245, 333], DirectedEdge[25, 49] -> 
         Rational[25, 71], DirectedEdge[31, 50] -> 1, DirectedEdge[27, 36] -> 
         Rational[4, 11], DirectedEdge[10, 48] -> Rational[1, 2], 
         DirectedEdge[36, 47] -> Rational[3, 7], DirectedEdge[6, 50] -> 
         Rational[11, 59], DirectedEdge[28, 49] -> Rational[22, 43], 
         DirectedEdge[34, 48] -> Rational[112, 223], DirectedEdge[10, 50] -> 
         Rational[1, 2], DirectedEdge[37, 50] -> 1, DirectedEdge[29, 1] -> 
         Rational[85, 421], DirectedEdge[12, 48] -> Rational[3, 11], 
         DirectedEdge[2, 50] -> Rational[19, 51], DirectedEdge[33, 39] -> 1, 
         DirectedEdge[36, 50] -> Rational[4, 7], DirectedEdge[35, 50] -> 
         Rational[156, 275], DirectedEdge[32, 37] -> Rational[1, 11], 
         DirectedEdge[16, 50] -> Rational[15, 26], DirectedEdge[14, 50] -> 1, 
         DirectedEdge[23, 50] -> Rational[3, 14], DirectedEdge[22, 50] -> 1, 
         DirectedEdge[11, 35] -> Rational[420, 719], DirectedEdge[20, 45] -> 
         1, DirectedEdge[43, 31] -> Rational[43, 403], DirectedEdge[38, 50] -> 
         Rational[8, 15], DirectedEdge[44, 50] -> Rational[28, 57], 
         DirectedEdge[41, 49] -> Rational[112, 151], DirectedEdge[1, 50] -> 
         Rational[141, 232], DirectedEdge[1, 48] -> Rational[91, 232], 
         DirectedEdge[21, 49] -> 1, DirectedEdge[27, 50] -> Rational[7, 11], 
         DirectedEdge[30, 50] -> Rational[32, 51], DirectedEdge[32, 50] -> 
         Rational[10, 11], DirectedEdge[29, 26] -> Rational[336, 421], 
         DirectedEdge[44, 26] -> Rational[29, 57], DirectedEdge[30, 49] -> 
         Rational[19, 51], DirectedEdge[48, 50] -> Rational[141, 305], 
         DirectedEdge[24, 47] -> 1, DirectedEdge[15, 7] -> Rational[1, 2], 
         DirectedEdge[2, 45] -> Rational[32, 51], DirectedEdge[34, 34] -> 
         Rational[111, 223], DirectedEdge[42, 39] -> 1, DirectedEdge[48, 48] -> 
         Rational[164, 305], DirectedEdge[13, 50] -> 1, DirectedEdge[46, 49] -> 
         Rational[88, 333], DirectedEdge[9, 27] -> Rational[19, 40], 
         DirectedEdge[3, 49] -> 1, DirectedEdge[8, 50] -> 1, 
         DirectedEdge[50, 50] -> 1, DirectedEdge[47, 45] -> Rational[5, 12], 
         DirectedEdge[41, 32] -> Rational[39, 151], DirectedEdge[35, 48] -> 
         Rational[119, 275], DirectedEdge[15, 1] -> Rational[1, 2], 
         DirectedEdge[47, 50] -> Rational[7, 12], DirectedEdge[23, 49] -> 
         Rational[11, 14], DirectedEdge[38, 49] -> Rational[7, 15]}, 
       VertexLabels -> {"Name"}, VertexSize -> {0.1}, 
       VertexStyle -> {22 -> Hue[
           Rational[1, 2]], 38 -> Hue[
           Rational[1, 2]], 18 -> Hue[
           Rational[1, 2]], 47 -> Hue[1], 19 -> Hue[
           Rational[1, 2]], 50 -> Hue[
           Rational[1, 2]], 1 -> Hue[1], 33 -> Hue[1], 46 -> Hue[1], 11 -> 
         Hue[1], 31 -> Hue[1], 35 -> Hue[1], 5 -> Hue[
           Rational[1, 2]], 17 -> Hue[
           Rational[1, 2]], 42 -> Hue[
           Rational[1, 2]], 16 -> Hue[
           Rational[1, 2]], 23 -> Hue[1], 37 -> Hue[
           Rational[1, 2]], 13 -> Hue[
           Rational[1, 2]], 8 -> Hue[
           Rational[1, 2]], 30 -> Hue[1], 36 -> Hue[
           Rational[1, 2]], 12 -> Hue[
           Rational[1, 2]], 28 -> Hue[
           Rational[1, 2]], 20 -> Hue[1], 9 -> Hue[1], 3 -> Hue[1], 21 -> 
         Hue[
           Rational[1, 2]], 45 -> Hue[
           Rational[1, 2]], 39 -> Hue[1], 49 -> Hue[
           Rational[1, 2]], 48 -> Hue[
           Rational[1, 2]], 32 -> Hue[
           Rational[1, 2]], 15 -> Hue[1], 43 -> Hue[1], 24 -> Hue[1], 29 -> 
         Hue[1], 10 -> Hue[1], 44 -> Hue[1], 7 -> Hue[
           Rational[1, 2]], 6 -> Hue[1], 4 -> Hue[1], 40 -> Hue[1], 26 -> 
         Hue[1], 41 -> Hue[1], 14 -> Hue[1], 34 -> Hue[1], 25 -> Hue[
           Rational[1, 2]], 27 -> Hue[1], 2 -> Hue[
           Rational[1, 2]]}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Arrowheads[0.020194847765882474`], 
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$1", Automatic, Center], 
           DynamicLocation["VertexID$2", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$1"], 
        InsetBox[
         FormBox[
          FractionBox["91", "232"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$1", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$1", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$2"], 
        InsetBox[
         FormBox[
          FractionBox["141", "232"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$2", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$2", Automatic, Center], {
            5.560455775251289, 1.9913591481758504`}, {5.650699990432491, 
            2.04837721455419}, {5.722287967425931, 2.053239259710653}, {
            5.87503770041242, 1.9178371526250286`}, {5.878799276038368, 
            1.8461829239854917`}, {5.833019748194778, 1.7497499778642942`}, 
            DynamicLocation["VertexID$2", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$3"], 
        InsetBox[
         FormBox[
          FractionBox["164", "305"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$3", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$2", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$4"], 
        InsetBox[
         FormBox[
          FractionBox["141", "305"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$4", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$3", Automatic, Center], {
            3.901406487289333, 1.7499816911537707`}, {3.901543227370932, 
            1.7880608558079856`}, {3.9115795152592434`, 
            1.8115275434498965`}, {3.9755586953811526`, 
            1.8486519655254585`}, {4.000912595680497, 1.8457207127095117`}, {
            4.034040594471348, 1.8269436742122913`}, 
            DynamicLocation["VertexID$3", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$5"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$5", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$4", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$6"], 
        InsetBox[
         FormBox[
          FractionBox["19", "51"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$6", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$4", Automatic, Center], 
           DynamicLocation["VertexID$5", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$7"], 
        InsetBox[
         FormBox[
          FractionBox["32", "51"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$7", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$5", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$8"], 
        InsetBox[
         FormBox[
          FractionBox["9", "29"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$8", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$5", Automatic, Center], 
           DynamicLocation["VertexID$7", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$9"], 
        InsetBox[
         FormBox[
          FractionBox["20", "29"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$9", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$6", Automatic, Center], 
           DynamicLocation["VertexID$7", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$10"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$10", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$7", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$11"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$11", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$8", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$12"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$12", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$9", Automatic, Center], 
           DynamicLocation["VertexID$7", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$13"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$13", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$10", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$14"], 
        InsetBox[
         FormBox[
          FractionBox["11", "59"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$14", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$10", Automatic, Center], 
           DynamicLocation["VertexID$7", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$15"], 
        InsetBox[
         FormBox[
          FractionBox["48", "59"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$15", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$11", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$16"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$16", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$12", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$17"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$17", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$13", Automatic, Center], 
           DynamicLocation["VertexID$14", Automatic, Center]}], "DynamicName",
          BoxID -> "EdgeLabelID$18"], 
        InsetBox[
         FormBox[
          FractionBox["19", "40"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$18", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$13", Automatic, Center], 
           DynamicLocation["VertexID$15", Automatic, Center]}], "DynamicName",
          BoxID -> "EdgeLabelID$19"], 
        InsetBox[
         FormBox[
          FractionBox["21", "40"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$19", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$14", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$20"], 
        InsetBox[
         FormBox[
          FractionBox["7", "11"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$20", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$14", Automatic, Center], 
           DynamicLocation["VertexID$34", Automatic, Center]}], "DynamicName",
          BoxID -> "EdgeLabelID$21"], 
        InsetBox[
         FormBox[
          FractionBox["4", "11"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$21", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$15", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$22"], 
        InsetBox[
         FormBox[
          FractionBox["7", "12"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$22", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$15", Automatic, Center], 
           DynamicLocation["VertexID$5", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$23"], 
        InsetBox[
         FormBox[
          FractionBox["5", "12"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$23", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$16", Automatic, Center], 
           DynamicLocation["VertexID$2", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$24"], 
        InsetBox[
         FormBox[
          FractionBox["1", "2"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$24", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$16", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$25"], 
        InsetBox[
         FormBox[
          FractionBox["1", "2"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$25", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$17", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$26"], 
        InsetBox[
         FormBox[
          FractionBox["299", "719"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$26", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$17", Automatic, Center], 
           DynamicLocation["VertexID$18", Automatic, Center]}], "DynamicName",
          BoxID -> "EdgeLabelID$27"], 
        InsetBox[
         FormBox[
          FractionBox["420", "719"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$27", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$18", Automatic, Center], 
           DynamicLocation["VertexID$2", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$28"], 
        InsetBox[
         FormBox[
          FractionBox["119", "275"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$28", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$18", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$29"], 
        InsetBox[
         FormBox[
          FractionBox["156", "275"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$29", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$19", Automatic, Center], 
           DynamicLocation["VertexID$2", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$30"], 
        InsetBox[
         FormBox[
          FractionBox["3", "11"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$30", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$19", Automatic, Center], 
           DynamicLocation["VertexID$15", Automatic, Center]}], "DynamicName",
          BoxID -> "EdgeLabelID$31"], 
        InsetBox[
         FormBox[
          FractionBox["8", "11"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$31", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$20", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$32"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$32", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$21", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$33"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$33", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$22", Automatic, Center], 
           DynamicLocation["VertexID$1", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$34"], 
        InsetBox[
         FormBox[
          FractionBox["1", "2"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$34", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$22", Automatic, Center], 
           DynamicLocation["VertexID$11", Automatic, Center]}], "DynamicName",
          BoxID -> "EdgeLabelID$35"], 
        InsetBox[
         FormBox[
          FractionBox["1", "2"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$35", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$23", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$36"], 
        InsetBox[
         FormBox[
          FractionBox["15", "26"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$36", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$23", Automatic, Center], 
           DynamicLocation["VertexID$15", Automatic, Center]}], "DynamicName",
          BoxID -> "EdgeLabelID$37"], 
        InsetBox[
         FormBox[
          FractionBox["11", "26"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$37", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$24", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$38"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$38", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$25", Automatic, Center], 
           DynamicLocation["VertexID$7", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$39"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$39", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$26", Automatic, Center], 
           DynamicLocation["VertexID$2", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$40"], 
        InsetBox[
         FormBox[
          FractionBox["27", "68"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$40", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$26", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$41"], 
        InsetBox[
         FormBox[
          FractionBox["41", "68"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$41", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$27", Automatic, Center], 
           DynamicLocation["VertexID$5", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$42"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$42", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$28", Automatic, Center], 
           DynamicLocation["VertexID$7", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$43"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$43", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$29", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$44"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$44", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$30", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$45"], 
        InsetBox[
         FormBox[
          FractionBox["3", "14"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$45", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$30", Automatic, Center], 
           DynamicLocation["VertexID$7", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$46"], 
        InsetBox[
         FormBox[
          FractionBox["11", "14"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$46", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$31", Automatic, Center], 
           DynamicLocation["VertexID$15", Automatic, Center]}], "DynamicName",
          BoxID -> "EdgeLabelID$47"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$47", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$32", Automatic, Center], 
           DynamicLocation["VertexID$7", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$48"], 
        InsetBox[
         FormBox[
          FractionBox["25", "71"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$48", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$32", Automatic, Center], 
           DynamicLocation["VertexID$18", Automatic, Center]}], "DynamicName",
          BoxID -> "EdgeLabelID$49"], 
        InsetBox[
         FormBox[
          FractionBox["46", "71"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$49", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$33", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$50"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$50", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$34", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$51"], 
        InsetBox[
         FormBox[
          FractionBox["4", "7"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$51", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$34", Automatic, Center], 
           DynamicLocation["VertexID$15", Automatic, Center]}], "DynamicName",
          BoxID -> "EdgeLabelID$52"], 
        InsetBox[
         FormBox[
          FractionBox["3", "7"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$52", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$35", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$53"], 
        InsetBox[
         FormBox[
          FractionBox["21", "43"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$53", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$35", Automatic, Center], 
           DynamicLocation["VertexID$7", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$54"], 
        InsetBox[
         FormBox[
          FractionBox["22", "43"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$54", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$36", Automatic, Center], 
           DynamicLocation["VertexID$1", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$55"], 
        InsetBox[
         FormBox[
          FractionBox["85", "421"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$55", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$36", Automatic, Center], 
           DynamicLocation["VertexID$33", Automatic, Center]}], "DynamicName",
          BoxID -> "EdgeLabelID$56"], 
        InsetBox[
         FormBox[
          FractionBox["336", "421"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$56", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$37", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$57"], 
        InsetBox[
         FormBox[
          FractionBox["32", "51"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$57", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$37", Automatic, Center], 
           DynamicLocation["VertexID$7", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$58"], 
        InsetBox[
         FormBox[
          FractionBox["19", "51"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$58", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$38", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$59"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$59", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$39", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$60"], 
        InsetBox[
         FormBox[
          FractionBox["10", "11"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$60", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$39", Automatic, Center], 
           DynamicLocation["VertexID$40", Automatic, Center]}], "DynamicName",
          BoxID -> "EdgeLabelID$61"], 
        InsetBox[
         FormBox[
          FractionBox["1", "11"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$61", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$40", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$62"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$62", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$41", Automatic, Center], 
           DynamicLocation["VertexID$42", Automatic, Center]}], "DynamicName",
          BoxID -> "EdgeLabelID$63"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$63", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$42", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$64"], 
        InsetBox[
         FormBox[
          FractionBox["65", "137"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$64", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$42", Automatic, Center], 
           DynamicLocation["VertexID$7", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$65"], 
        InsetBox[
         FormBox[
          FractionBox["72", "137"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$65", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$43", Automatic, Center], 
           DynamicLocation["VertexID$2", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$66"], 
        InsetBox[
         FormBox[
          FractionBox["112", "223"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$66", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$43", Automatic, Center], {
            6.696854260538812, 1.926580629246232}, {6.890386420122573, 
            1.99923383425599}, {7.021997892932181, 1.9509976953995731`}, {
            7.05313554542599, 1.5758422877854035`}, {6.9312773333509385`, 
            1.5065683315192728`}, {6.728415551801546, 1.5463210996989982`}, 
            DynamicLocation["VertexID$43", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$67"], 
        InsetBox[
         FormBox[
          FractionBox["111", "223"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$67", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$44", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$68"], 
        InsetBox[
         FormBox[
          FractionBox["8", "15"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$68", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$44", Automatic, Center], 
           DynamicLocation["VertexID$7", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$69"], 
        InsetBox[
         FormBox[
          FractionBox["7", "15"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$69", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$45", Automatic, Center], 
           DynamicLocation["VertexID$46", Automatic, Center]}], "DynamicName",
          BoxID -> "EdgeLabelID$70"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$70", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$46", Automatic, Center], 
           DynamicLocation["VertexID$42", Automatic, Center]}], "DynamicName",
          BoxID -> "EdgeLabelID$71"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$71", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$47", Automatic, Center], 
           DynamicLocation["VertexID$7", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$72"], 
        InsetBox[
         FormBox[
          FractionBox["112", "151"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$72", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$47", Automatic, Center], 
           DynamicLocation["VertexID$39", Automatic, Center]}], "DynamicName",
          BoxID -> "EdgeLabelID$73"], 
        InsetBox[
         FormBox[
          FractionBox["39", "151"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$73", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$48", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$74"], 
        InsetBox[
         FormBox[
          FractionBox["360", "403"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$74", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$48", Automatic, Center], 
           DynamicLocation["VertexID$38", Automatic, Center]}], "DynamicName",
          BoxID -> "EdgeLabelID$75"], 
        InsetBox[
         FormBox[
          FractionBox["43", "403"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$75", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$49", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$76"], 
        InsetBox[
         FormBox[
          FractionBox["28", "57"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$76", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$49", Automatic, Center], 
           DynamicLocation["VertexID$33", Automatic, Center]}], "DynamicName",
          BoxID -> "EdgeLabelID$77"], 
        InsetBox[
         FormBox[
          FractionBox["29", "57"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$77", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$50", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$78"], 
        InsetBox[
         FormBox[
          FractionBox["245", "333"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$78", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$50", Automatic, Center], 
           DynamicLocation["VertexID$7", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$79"], 
        InsetBox[
         FormBox[
          FractionBox["88", "333"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$79", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{5.463708371223236, 2.2762937095376143`}, 
            0.010544848597403648`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{5.4877450151195415`, 1.6347858078144464`}, 
            0.010544848597403648`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["48", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{4.189962620304571, 1.4054621321648328`}, 
            0.010544848597403648`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["50", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.9015105000841386`, 1.1888775270263545`}, 
            0.010544848597403648`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{4.085434901899202, 1.8004483686015869`}, 
            0.010544848597403648`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["45", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.20264380699446, 2.882585832825944}, 
            0.010544848597403648`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.8019473954217604`, 1.9504860322537136`}, 
            0.010544848597403648`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$7"], 
         InsetBox[
          FormBox["49", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.920421218658895, 2.3212313864401146`}, 
            0.010544848597403648`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$8"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$8", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$8"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.759294574375486, 2.340075935967527}, 
            0.010544848597403648`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$9"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$9", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$9"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.4554910919771347`, 2.1700610061513474`}, 
            0.010544848597403648`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$10"], 
         InsetBox[
          FormBox["6", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$10", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$10"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{5.085700197134839, 2.551721728798492}, 
            0.010544848597403648`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$11"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$11", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$11"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{4.570676862897672, 2.5259322894489973`}, 
            0.010544848597403648`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$12"], 
         InsetBox[
          FormBox["8", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$12", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$12"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{5.697060858577471, 0.}, 0.010544848597403648`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$13"], 
         InsetBox[
          FormBox["9", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$13", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$13"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{5.073658501218702, 0.3419644977558953}, 
            0.010544848597403648`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$14"], 
         InsetBox[
          FormBox["27", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$14", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$14"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{5.252782476894492, 0.8394412884340557}, 
            0.010544848597403648`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$15"], 
         InsetBox[
          FormBox["47", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$15", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$15"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{5.035680970298758, 1.417002891729769}, 
            0.010544848597403648`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$16"], 
         InsetBox[
          FormBox["10", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$16", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$16"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{4.690420319922172, 1.9324437532167307`}, 
            0.010544848597403648`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$17"], 
         InsetBox[
          FormBox["11", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$17", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$17"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{4.476774135592224, 2.168384192173902}, 
            0.010544848597403648`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$18"], 
         InsetBox[
          FormBox["35", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$18", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$18"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{6.113582643155172, 1.0359200862164557`}, 
            0.010544848597403648`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$19"], 
         InsetBox[
          FormBox["12", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$19", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$19"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{4.190499118788594, 2.541447579694946}, 
            0.010544848597403648`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$20"], 
         InsetBox[
          FormBox["13", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$20", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$20"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{4.2824693885120855`, 0.14078732457721554`}, 
            0.010544848597403648`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$21"], 
         InsetBox[
          FormBox["14", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$21", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$21"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{5.774235018742334, 3.0553699701056654`}, 
            0.010544848597403648`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$22"], 
         InsetBox[
          FormBox["15", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$22", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$22"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{4.836320551877072, 0.8867009797211199}, 
            0.010544848597403648`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$23"], 
         InsetBox[
          FormBox["16", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$23", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$23"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{4.125611452515074, 0.5531603117186177}, 
            0.010544848597403648`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$24"], 
         InsetBox[
          FormBox["17", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$24", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$24"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.9251848102016957`, 2.6441742196858984`}, 
            0.010544848597403648`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$25"], 
         InsetBox[
          FormBox["18", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$25", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$25"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{5.2806088061461045`, 1.2164013833885345`}, 
            0.010544848597403648`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$26"], 
         InsetBox[
          FormBox["19", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$26", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$26"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{4.079198469256518, 3.0505146165552524`}, 
            0.010544848597403648`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$27"], 
         InsetBox[
          FormBox["20", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$27", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$27"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.7229990624420304`, 1.9858144945406315`}, 
            0.010544848597403648`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$28"], 
         InsetBox[
          FormBox["21", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$28", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$28"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{4.520233708178805, 0.3587541235497842}, 
            0.010544848597403648`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$29"], 
         InsetBox[
          FormBox["22", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$29", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$29"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.325735479446802, 1.4537325297877002`}, 
            0.010544848597403648`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$30"], 
         InsetBox[
          FormBox["23", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$30", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$30"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{6.224835635218984, 0.21719426950824716`}, 
            0.010544848597403648`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$31"], 
         InsetBox[
          FormBox["24", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$31", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$31"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.4410178224980665`, 2.6957288205451713`}, 
            0.010544848597403648`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$32"], 
         InsetBox[
          FormBox["25", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$32", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$32"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{5.4436548057078555`, 1.9901306708780073`}, 
            0.010544848597403648`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$33"], 
         InsetBox[
          FormBox["26", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$33", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$33"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{4.873739627777934, 0.5778642281237353}, 
            0.010544848597403648`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$34"], 
         InsetBox[
          FormBox["36", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$34", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$34"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.1049390371850194`, 1.6371083248667497`}, 
            0.010544848597403648`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$35"], 
         InsetBox[
          FormBox["28", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$35", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$35"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{6.186067425240266, 2.5019868351196832`}, 
            0.010544848597403648`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$36"], 
         InsetBox[
          FormBox["29", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$36", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$36"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.07994133069193, 1.2979292544485137`}, 
            0.010544848597403648`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$37"], 
         InsetBox[
          FormBox["30", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$37", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$37"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.684227541896386, 0.3637815569406402}, 
            0.010544848597403648`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$38"], 
         InsetBox[
          FormBox["31", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$38", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$38"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.1212268525039035`, 0.7888185987626536}, 
            0.010544848597403648`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$39"], 
         InsetBox[
          FormBox["32", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$39", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$39"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.4556003618298896`, 0.6197664781581348}, 
            0.010544848597403648`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$40"], 
         InsetBox[
          FormBox["37", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$40", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$40"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.4276806162414792`, 0.6332292497862718}, 
            0.010544848597403648`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$41"], 
         InsetBox[
          FormBox["33", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$41", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$41"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.2888550632614297`, 1.1782521672944202`}, 
            0.010544848597403648`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$42"], 
         InsetBox[
          FormBox["39", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$42", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$42"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{6.624458847056987, 1.7291323094652358`}, 
            0.010544848597403648`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$43"], 
         InsetBox[
          FormBox["34", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$43", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$43"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.4274840894252576`, 1.8115127922246383`}, 
            0.010544848597403648`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$44"], 
         InsetBox[
          FormBox["38", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$44", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$44"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{0., 0.6061498046100267}, 0.010544848597403648`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$45"], 
         InsetBox[
          FormBox["40", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$45", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$45"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.924301812480687, 0.8512966457711248}, 
            0.010544848597403648`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$46"], 
         InsetBox[
          FormBox["42", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$46", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$46"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.422280921683198, 1.014927113854109}, 
            0.010544848597403648`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$47"], 
         InsetBox[
          FormBox["41", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$47", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$47"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.9213605334079937`, 0.22566692308903757`}, 
            0.010544848597403648`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$48"], 
         InsetBox[
          FormBox["43", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$48", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$48"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{5.067206451310288, 1.8176519510701512`}, 
            0.010544848597403648`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$49"], 
         InsetBox[
          FormBox["44", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$49", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$49"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.2149396704569835`, 2.0564183574991404`}, 
            0.010544848597403648`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$50"], 
         InsetBox[
          FormBox["46", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$50", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$50"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{3.9406933090100944`, 
       359.03363701644116`}, {-93.90292351612361, 80.8771100335393}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output",
 CellChangeTimes->{
  3.572175428940483*^9, 3.5721754599335623`*^9, 3.5725477651382093`*^9, 
   3.572547820018742*^9, {3.572548073158993*^9, 3.572548083334465*^9}, 
   3.57254816619018*^9, 3.5738988131967154`*^9, {3.573898873351012*^9, 
   3.573898887357711*^9}, 3.576559382290635*^9}]
}, Open  ]],

Cell[TextData[{
 "The function ",
 StyleBox["BisimClassesMC[", "Program"],
 "\[ScriptCapitalM]",
 StyleBox["]", "Program"],
 " returns the set of bisimilarity classes of \[ScriptCapitalM], that is S/\
\[Tilde]."
}], "Text",
 CellChangeTimes->{{3.573298087185957*^9, 3.573298216473055*^9}, {
  3.573461937398999*^9, 3.573461941885407*^9}, {3.5734619794434357`*^9, 
  3.573461996871677*^9}, {3.573898406454379*^9, 3.5738984071969967`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BisimClassesMC", "[", "mc", "]"}]], "Input",
 CellChangeTimes->{{3.559364588622055*^9, 3.559364598948433*^9}, 
   3.559364880760984*^9, {3.559366404142303*^9, 3.559366404251511*^9}, {
   3.5593670672079487`*^9, 3.559367077440153*^9}, {3.559367681804838*^9, 
   3.5593676883066597`*^9}, {3.559368340873324*^9, 3.55936834095751*^9}, 
   3.572174904971375*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "1", ",", "3", ",", "4", ",", "6", ",", "10", ",", "14", ",", "20", ",", 
     "23", ",", "26", ",", "30", ",", "31", ",", "35", ",", "39", ",", "41", 
     ",", "46", ",", "47"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "2", ",", "5", ",", "7", ",", "8", ",", "13", ",", "17", ",", "18", ",", 
     "19", ",", "21", ",", "22", ",", "28", ",", "32", ",", "37", ",", "38", 
     ",", "45", ",", "48", ",", "49", ",", "50"}], "}"}], ",", 
   RowBox[{"{", "9", "}"}], ",", 
   RowBox[{"{", "11", "}"}], ",", 
   RowBox[{"{", "12", "}"}], ",", 
   RowBox[{"{", "15", "}"}], ",", 
   RowBox[{"{", "16", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"24", ",", "29", ",", "33"}], "}"}], ",", 
   RowBox[{"{", "25", "}"}], ",", 
   RowBox[{"{", "27", "}"}], ",", 
   RowBox[{"{", "34", "}"}], ",", 
   RowBox[{"{", "36", "}"}], ",", 
   RowBox[{"{", "40", "}"}], ",", 
   RowBox[{"{", "42", "}"}], ",", 
   RowBox[{"{", "43", "}"}], ",", 
   RowBox[{"{", "44", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.572175429108094*^9, 3.572175463455906*^9, 3.57254819302739*^9, 
   3.5738988164876537`*^9, {3.5738988762124*^9, 3.57389889410507*^9}, 
   3.576559384834346*^9}]
}, Open  ]],

Cell["\<\
so that this can be used to construct an MC \[ScriptCapitalM]\
\[CloseCurlyQuote] bisimilar to \[ScriptCapitalM] with all the states that \
are bisimilar in \[ScriptCapitalM] lumped together. \[ScriptCapitalM]\
\[CloseCurlyQuote] is also known as the bisimilar quotient of \
\[ScriptCapitalM].\
\>", "Text",
 CellChangeTimes->{{3.559369514578313*^9, 3.559369714919273*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mcquotient", "=", 
   RowBox[{"BisimQuotientMC", "[", "mc", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"PlotMC", "[", "mcquotient", "]"}]}], "Input",
 CellChangeTimes->{{3.559367701452523*^9, 3.559367763756866*^9}, {
   3.5593683634098177`*^9, 3.5593683871031218`*^9}, {3.5721749133568287`*^9, 
   3.572174913705205*^9}, 3.5725481061028957`*^9, {3.572548148251295*^9, 
   3.572548154029613*^9}, {3.572548220440166*^9, 3.5725483137469893`*^9}, {
   3.5738984886568623`*^9, 3.573898489149633*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 10, 4, 5, 6, 7, 8, 9, 12, 11, 13, 14, 15, 
      16}, {{{1, 2}, {2, 2}, {3, 1}, {3, 4}, {5, 1}, {5, 2}, {6, 1}, {6, 2}, {
       7, 1}, {7, 2}, {8, 1}, {8, 2}, {9, 1}, {10, 1}, {10, 2}, {4, 2}, {4, 
       11}, {12, 2}, {12, 12}, {11, 1}, {11, 2}, {13, 14}, {14, 1}, {15, 1}, {
       15, 2}, {16, 1}, {16, 2}}, Null}, {
      EdgeLabels -> {
        DirectedEdge[14, 1] -> 1, DirectedEdge[9, 1] -> Rational[46, 71], 
         DirectedEdge[10, 2] -> Rational[7, 11], DirectedEdge[10, 12] -> 
         Rational[4, 11], DirectedEdge[16, 2] -> Rational[28, 57], 
         DirectedEdge[7, 2] -> Rational[15, 26], DirectedEdge[15, 1] -> 
         Rational[43, 403], DirectedEdge[2, 2] -> 1, DirectedEdge[6, 2] -> 
         Rational[1, 2], DirectedEdge[4, 2] -> Rational[299, 719], 
         DirectedEdge[5, 2] -> Rational[3, 11], DirectedEdge[3, 10] -> 
         Rational[19, 40], DirectedEdge[12, 2] -> Rational[4, 7], 
         DirectedEdge[12, 1] -> Rational[3, 7], DirectedEdge[15, 2] -> 
         Rational[360, 403], DirectedEdge[8, 1] -> 1, DirectedEdge[6, 1] -> 
         Rational[1, 2], DirectedEdge[7, 1] -> Rational[11, 26], 
         DirectedEdge[1, 2] -> 1, DirectedEdge[9, 2] -> Rational[25, 71], 
         DirectedEdge[11, 11] -> Rational[111, 223], DirectedEdge[5, 1] -> 
         Rational[8, 11], DirectedEdge[13, 14] -> 1, DirectedEdge[16, 1] -> 
         Rational[29, 57], DirectedEdge[4, 1] -> Rational[420, 719], 
         DirectedEdge[11, 2] -> Rational[112, 223], DirectedEdge[3, 1] -> 
         Rational[21, 40]}, VertexLabels -> {"Name"}, VertexSize -> {0.1}, 
       VertexStyle -> {10 -> Hue[1], 2 -> Hue[
           Rational[1, 2]], 4 -> Hue[1], 1 -> Hue[1], 12 -> Hue[
           Rational[1, 2]], 15 -> Hue[1], 9 -> Hue[
           Rational[1, 2]], 3 -> Hue[1], 8 -> Hue[1], 7 -> Hue[
           Rational[1, 2]], 13 -> Hue[1], 16 -> Hue[1], 11 -> Hue[1], 5 -> Hue[
           Rational[1, 2]], 14 -> Hue[
           Rational[1, 2]], 6 -> Hue[1]}}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Arrowheads[0.01662309542902967], 
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$1", Automatic, Center], 
           DynamicLocation["VertexID$2", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$1"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$1", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$2", Automatic, Center], {
            0.5847555480067821, -0.31705537341997087`}, {
            0.6925460430858442, -0.8678017631696833}, {
            0.5153321467738504, -1.203907205330022}, {-0.5153321467738502, \
-1.2039072053300217`}, {-0.6925460430858438, -0.8678017631696833}, \
{-0.5847555480067816, -0.31705537341997087`}, 
            DynamicLocation["VertexID$2", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$2"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$2", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$3", Automatic, Center], {
            3.5450892345707716`, 3.886272308642693}, {3.2431174444509043`, 
            3.8107793611127265`}, {2.891468049394199, 3.7228670123485497`}, {
            2.4901410494006586`, 3.6225352623501648`}, {2.039136444470281, 
            3.509784111117571}, {1.538454234603068, 3.384613558650767}, {
            0.9880944197990188, 3.2470236049497547`}, {0.38805700005813276`, 
            3.0970142500145332`}, {0.30661293831753694`, 
            3.0717149629744456`}, {0.2347505308993643, 3.0389345463050876`}, {
            0.17246977780361458`, 2.9986730000064594`}, {0.1197706790302879, 
            2.95093032407856}, {0.07665323457938424, 2.895706518521389}, {
            0.043117444450903646`, 2.8330015833349482`}, {0.01916330864484606,
             2.7628155185192362`}, {0.00479082716121152, 
            2.6851483240742535`}, {0., 2.4000000000000004`}, {0., 
            2.311111111111112}, {0., 2.222222222222222}, {0., 
            2.1333333333333337`}, {0., 2.0444444444444447`}, {0., 
            1.9555555555555557`}, {0., 1.8666666666666667`}, {0., 
            1.777777777777778}, {0., 1.688888888888889}, {0., 1.6}, {0., 
            1.5135802469135802`}, {0., 1.4320987654320987`}, {0., 
            1.3555555555555558`}, {0., 1.2839506172839508`}, {0., 
            1.217283950617284}, {0., 1.1555555555555554`}, {0., 
            1.0987654320987654`}, 
            DynamicLocation["VertexID$1", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$3"], 
        InsetBox[
         FormBox[
          FractionBox["21", "40"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$3", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$3", Automatic, Center], 
           DynamicLocation["VertexID$4", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$4"], 
        InsetBox[
         FormBox[
          FractionBox["19", "40"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$4", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$4", Automatic, Center], {
            4.104550977161747, 2.8954490228382532`}, {4.168573031947265, 
            2.8314269680527357`}, {4.240426130869211, 2.759573869130789}, {
            4.320110273927587, 2.679889726072413}, {4.407625461122391, 
            2.5923745388776087`}, {4.502971692453626, 2.4970283075463744`}, {
            4.606148967921289, 2.3938510320787114`}, {4.7171572875253815`, 
            2.282842712474619}, {4.776519338291658, 2.2185423901034023`}, {
            4.828897618379552, 2.151349295200695}, {4.874292127789059, 
            2.0812634277664976`}, {4.9127028665201795`, 
            2.0082847878008083`}, {4.944129834572914, 1.9324133753036286`}, {
            4.968573031947265, 1.853649190274958}, {4.986032458643229, 
            1.771992232714796}, {4.9965081146608075`, 1.6874425026231437`}, {
            5., 1.4}, {4.995157626292884, 1.315080907974626}, {
            4.980630505171537, 1.2381014096762826`}, {4.95641863663596, 
            1.1690615051049698`}, {4.9225220206861495`, 
            1.1079611942606866`}, {4.878940657322109, 1.054800477143434}, {
            4.825674546543836, 1.0095793537532116`}, {4.762723688351333, 
            0.9722978240900197}, {4.690088082744598, 0.9429558881538579}, {
            4.607767729723632, 0.9215535459447264}, {3.838236230892746, 
            0.7676472461785491}, {3.1330940587217033`, 0.6266188117443406}, {
            2.4923412132105036`, 0.49846824264210066`}, {1.9159776943591453`, 
            0.3831955388718291}, {1.4040035021676307`, 0.2808007004335261}, {
            0.956418636635959, 0.19128372732719184`}, {0.5732230977641298, 
            0.11464461955282597`}, 
            DynamicLocation["VertexID$2", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$5"], 
        InsetBox[
         FormBox[
          FractionBox["7", "11"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$5", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$4", Automatic, Center], 
           DynamicLocation["VertexID$11", Automatic, Center]}], "DynamicName",
          BoxID -> "EdgeLabelID$6"], 
        InsetBox[
         FormBox[
          FractionBox["4", "11"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$6", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$5", Automatic, Center], 
           DynamicLocation["VertexID$1", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$7"], 
        InsetBox[
         FormBox[
          FractionBox["420", "719"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$7", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation[
            "VertexID$5", Automatic, Center], {-5.80246913580247, 
            1.9012345679012346`}, {-5.688888888888889, 
            1.8444444444444446`}, {-5.565432098765433, 
            1.7827160493827163`}, {-5.432098765432099, 
            1.7160493827160495`}, {-5.28888888888889, 
            1.6444444444444444`}, {-5.135802469135804, 
            1.567901234567901}, {-4.97283950617284, 
            1.4864197530864198`}, {-4.800000000000001, 
            1.4}, {-4.621386150231179, 
            1.3133712289158188`}, {-4.441100156480265, 
            1.2312626934410538`}, {-4.259142018747265, 
            1.153674393575705}, {-4.075511737032173, 
            1.0806063293197716`}, {-3.8902093113349925`, 
            1.0120585006732543`}, {-3.7032347416557228`, 
            0.9480309076361528}, {-3.514588027994363, 
            0.8885235502084672}, {-3.3242691703509144`, 
            0.8335364283901977}, {-3.1322781687253753`, 
            0.7830695421813438}, {-2.6329111456595555`, 
            0.6582277864148889}, {-2.171378151451153, 
            0.5428445378627883}, {-1.7476791861001673`, 
            0.4369197965250418}, {-1.3618142496065975`, 
            0.34045356240164937`}, {-1.0137833419704443`, 
            0.25344583549261107`}, {-0.7035864631917084, 
            0.1758966157979271}, {-0.43122361327038883`, 
            0.10780590331759721`}, 
            DynamicLocation["VertexID$2", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$8"], 
        InsetBox[
         FormBox[
          FractionBox["299", "719"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$8", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$6", Automatic, Center], 
           DynamicLocation["VertexID$1", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$9"], 
        InsetBox[
         FormBox[
          FractionBox["8", "11"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$9", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation[
            "VertexID$6", Automatic, Center], {-4.802469135802469, 
            1.9012345679012346`}, {-4.68888888888889, 
            1.8444444444444446`}, {-4.565432098765432, 
            1.7827160493827163`}, {-4.432098765432099, 
            1.7160493827160495`}, {-4.288888888888889, 
            1.6444444444444444`}, {-4.135802469135802, 
            1.567901234567901}, {-3.9728395061728397`, 
            1.4864197530864198`}, {-3.8, 1.4}, {-3.62162310941452, 
            1.3125574973768561`}, {-3.4420479932136367`, 
            1.2280077672852039`}, {-3.2612746513973496`, 
            1.1463508097250426`}, {-3.079303083965658, 
            1.0675866246963714`}, {-2.896133290918563, 
            0.9917152121991917}, {-2.7117652722560637`, 
            0.9187365722335026}, {-2.5261990279781603`, 
            0.8486507047993046}, {-2.3394345580848537`, 
            0.7814576098965974}, {-2.151471862576143, 
            0.717157287525381}, {-1.8184469037638658`, 
            0.6061489679212886}, {-1.5089150773608766`, 
            0.5029716924536255}, {-1.2228763833671747`, 
            0.4076254611223916}, {-0.9603308217827601, 
            0.32011027392758673`}, {-0.721278392607633, 
            0.24042613086921102`}, {-0.5057190958417938, 
            0.16857303194726456`}, {-0.3136529314852416, 
            0.10455097716174719`}, 
            DynamicLocation["VertexID$2", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$10"], 
        InsetBox[
         FormBox[
          FractionBox["3", "11"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$10", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$7", Automatic, Center], 
           DynamicLocation["VertexID$1", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$11"], 
        InsetBox[
         FormBox[
          FractionBox["1", "2"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$11", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation[
            "VertexID$7", Automatic, Center], {-3.802469135802469, 
            1.9012345679012346`}, {-3.688888888888889, 
            1.8444444444444446`}, {-3.5654320987654327`, 
            1.7827160493827163`}, {-3.432098765432099, 
            1.7160493827160495`}, {-3.2888888888888888`, 
            1.6444444444444444`}, {-3.135802469135802, 
            1.567901234567901}, {-2.9728395061728397`, 
            1.4864197530864198`}, {-2.8, 1.4}, {-2.6222222222222213`, 
            1.3111111111111107`}, {-2.444444444444444, 
            1.222222222222222}, {-2.266666666666667, 
            1.1333333333333335`}, {-2.088888888888889, 
            1.0444444444444445`}, {-1.9111111111111112`, 
            0.9555555555555556}, {-1.7333333333333334`, 
            0.8666666666666667}, {-1.5555555555555556`, 
            0.7777777777777778}, {-1.3777777777777778`, 
            0.6888888888888889}, {-1.2, 0.6}, {-1.0271604938271603`, 
            0.5135802469135802}, {-0.8641975308641976, 
            0.4320987654320988}, {-0.7111111111111111, 
            0.35555555555555557`}, {-0.5679012345679012, 
            0.2839506172839506}, {-0.4345679012345678, 
            0.2172839506172839}, {-0.3111111111111111, 
            0.15555555555555556`}, {-0.19753086419753085`, 
            0.09876543209876543}, 
            DynamicLocation["VertexID$2", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$12"], 
        InsetBox[
         FormBox[
          FractionBox["1", "2"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$12", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$8", Automatic, Center], 
           DynamicLocation["VertexID$1", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$13"], 
        InsetBox[
         FormBox[
          FractionBox["11", "26"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$13", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation[
            "VertexID$8", Automatic, Center], {-2.787948860524787, 
            1.8939744302623935`}, {-2.6562182695141052`, 
            1.8281091347570524`}, {-2.5073509976547044`, 
            1.7536754988273524`}, {-2.341347044946587, 
            1.6706735224732934`}, {-2.1582064113897514`, 
            1.5791032056948757`}, {-1.957929096984199, 
            1.4789645484920992`}, {-1.7405151017299287`, 
            1.3702575508649641`}, {-1.5059644256269407`, 
            1.2529822128134702`}, {-1.3948360893842493`, 
            1.1949489088896552`}, {-1.2863241587125938`, 
            1.1332855361464202`}, {-1.180428633611974, 
            1.0679920945837647`}, {-1.077149514082389, 
            0.9990685842016883}, {-0.9764868001238401, 
            0.9265150050001917}, {-0.8784404917363269, 
            0.8503313569792745}, {-0.7830105889198489, 
            0.7705176401389369}, {-0.6901970916744067, 
            0.6870738544791787}, {-0.6, 0.6}, {-0.5135802469135802, 
            0.5135802469135802}, {-0.4320987654320988, 
            0.4320987654320988}, {-0.35555555555555557`, 
            0.35555555555555557`}, {-0.2839506172839506, 
            0.2839506172839506}, {-0.2172839506172839, 
            0.2172839506172839}, {-0.15555555555555556`, 
            0.15555555555555556`}, {-0.09876543209876543, 
            0.09876543209876543}, 
            DynamicLocation["VertexID$2", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$14"], 
        InsetBox[
         FormBox[
          FractionBox["15", "26"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$14", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$9", Automatic, Center], 
           DynamicLocation["VertexID$1", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$15"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$15", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$10", Automatic, Center], 
           DynamicLocation["VertexID$1", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$16"], 
        InsetBox[
         FormBox[
          FractionBox["46", "71"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$16", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$10", Automatic, Center], {1., 
            1.9012345679012346`}, {1.0000000000000002`, 
            1.8444444444444446`}, {1., 1.7827160493827163`}, {1., 
            1.7160493827160495`}, {1., 1.6444444444444444`}, {1., 
            1.567901234567901}, {1., 1.4864197530864198`}, {1., 1.4}, {
            0.9965081146608071, 1.3125574973768561`}, {0.9860324586432287, 
            1.2280077672852039`}, {0.9685730319472647, 1.1463508097250426`}, {
            0.9441298345729148, 1.0675866246963714`}, {0.9127028665201793, 
            0.9917152121991917}, {0.8742921277890583, 0.9187365722335026}, {
            0.8288976183795514, 0.8486507047993046}, {0.7765193382916591, 
            0.7814576098965974}, {0.717157287525381, 0.717157287525381}, {
            0.6061489679212886, 0.6061489679212886}, {0.5029716924536255, 
            0.5029716924536255}, {0.4076254611223916, 0.4076254611223916}, {
            0.32011027392758673`, 0.32011027392758673`}, {
            0.24042613086921102`, 0.24042613086921102`}, {
            0.16857303194726456`, 0.16857303194726456`}, {
            0.10455097716174719`, 0.10455097716174719`}, 
            DynamicLocation["VertexID$2", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$17"], 
        InsetBox[
         FormBox[
          FractionBox["25", "71"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$17", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$11", Automatic, Center], 
           DynamicLocation["VertexID$1", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$18"], 
        InsetBox[
         FormBox[
          FractionBox["3", "7"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$18", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$11", Automatic, Center], {4., 
            1.9012345679012346`}, {4.000000000000001, 1.8444444444444446`}, {
            4., 1.7827160493827163`}, {4., 1.7160493827160495`}, {4., 
            1.6444444444444444`}, {4., 1.567901234567901}, {4., 
            1.4864197530864198`}, {4., 1.4}, {3.995209172838788, 
            1.3148516759257463`}, {3.9808366913551545`, 
            1.2371844814807635`}, {3.956882555549097, 1.166998416665052}, {
            3.923346765420616, 1.1042934814786107`}, {3.880229320969712, 
            1.0490696759214404`}, {3.827530222196385, 1.0013269999935408`}, {
            3.7652494691006355`, 0.9610654536949119}, {3.693387061682463, 
            0.928285037025554}, {3.611942999941867, 0.9029857499854668}, {
            3.011905580200981, 0.7529763950502453}, {2.461545765396932, 
            0.615386441349233}, {1.9608635555297191`, 0.4902158888824298}, {
            1.5098589505993418`, 0.37746473764983546`}, {1.1085319506058007`, 
            0.27713298765145017`}, {0.7568825555490963, 
            0.18922063888727408`}, {0.4549107654292279, 0.11372769135730698`}, 
            DynamicLocation["VertexID$2", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$19"], 
        InsetBox[
         FormBox[
          FractionBox["4", "7"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$19", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$12", Automatic, Center], 
           DynamicLocation["VertexID$2", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$20"], 
        InsetBox[
         FormBox[
          FractionBox["112", "223"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$20", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation[
            "VertexID$12", Automatic, Center], {-5.354114549043028, 
            0.5158564555552229}, {-5.941925764427724, 
            0.46936878132398907`}, {-6.264641441784911, 
            0.7054110003470917}, {-6.054057869473414, 
            1.7583288619045736`}, {-5.665381006134818, 
            1.8520925727885196`}, {-5.140665912791727, 1.583099636811728}, 
            DynamicLocation["VertexID$12", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$21"], 
        InsetBox[
         FormBox[
          FractionBox["111", "223"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$21", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$13", Automatic, Center], 
           DynamicLocation["VertexID$14", Automatic, Center]}], "DynamicName",
          BoxID -> "EdgeLabelID$22"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$22", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$14", Automatic, Center], 
           DynamicLocation["VertexID$1", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$23"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$23", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$15", Automatic, Center], 
           DynamicLocation["VertexID$1", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$24"], 
        InsetBox[
         FormBox[
          FractionBox["43", "403"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$24", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$15", Automatic, Center], {2., 
            1.9012345679012346`}, {2.0000000000000004`, 
            1.8444444444444446`}, {2., 1.7827160493827163`}, {2., 
            1.7160493827160495`}, {2., 1.6444444444444444`}, {2., 
            1.567901234567901}, {2., 1.4864197530864198`}, {2., 1.4}, {
            1.9955830756000004`, 1.3138409205160493`}, {1.982332302400002, 
            1.2331414598419759`}, {1.9602476804000042`, 1.15790161797778}, {
            1.9293292096000068`, 1.08812139492346}, {1.8895768900000105`, 
            1.0238007906790176`}, {1.840990721600015, 0.9649398052444519}, {
            1.7835707044000204`, 0.9115384386197634}, {1.7173168384000266`, 
            0.8635966908049516}, {1.6422291236000337`, 0.8211145618000169}, {
            1.3765760976592856`, 0.6882880488296428}, {1.1317188525481685`, 
            0.5658594262740843}, {0.9076573882666819, 0.4538286941333409}, {
            0.7043917048148252, 0.3521958524074126}, {0.5219218021925992, 
            0.2609609010962996}, {0.36024768040000377`, 
            0.18012384020000188`}, {0.21936933943703865`, 
            0.10968466971851933`}, 
            DynamicLocation["VertexID$2", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$25"], 
        InsetBox[
         FormBox[
          FractionBox["360", "403"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$25", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$16", Automatic, Center], 
           DynamicLocation["VertexID$1", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$26"], 
        InsetBox[
         FormBox[
          FractionBox["29", "57"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$26", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$16", Automatic, Center], {3., 
            1.9012345679012346`}, {3.0000000000000004`, 
            1.8444444444444446`}, {3., 1.7827160493827163`}, {3., 
            1.7160493827160495`}, {3., 1.6444444444444444`}, {3., 
            1.567901234567901}, {3., 1.4864197530864198`}, {3., 1.4}, {
            2.9953151442071575`, 1.314487764118435}, {2.981260576828632, 
            1.2357288342515191`}, {2.957836297864422, 1.1637232103992519`}, {
            2.925042307314527, 1.0984708925616327`}, {2.882878605178949, 
            1.039971880738662}, {2.831345191457687, 0.9882261749303399}, {
            2.77044206615074, 0.9432337751366664}, {2.700169229258109, 
            0.9049946813576415}, {2.6205266807797947`, 0.8735088935932649}, {
            2.189058118146998, 0.7296860393823327}, {1.7926642883729622`, 
            0.5975547627909874}, {1.431345191457687, 0.47711506381922897`}, {
            1.105100827401171, 0.36836694246705703`}, {0.8139311962034161, 
            0.27131039873447205`}, {0.5578362978644217, 
            0.18594543262147387`}, {0.33681613238418734`, 
            0.11227204412806246`}, 
            DynamicLocation["VertexID$2", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$27"], 
        InsetBox[
         FormBox[
          FractionBox["28", "57"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$27", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{0., 1.}, 0.05], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{0., 0.}, 0.05], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{4., 4.}, 0.05], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{4., 3.}, 0.05], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["10", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{-6., 2.}, 0.05], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{-5., 2.}, 0.05], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{-4., 2.}, 0.05], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$7"], 
         InsetBox[
          FormBox["6", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{-3., 2.}, 0.05], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$8"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$8", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$8"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{-2., 2.}, 0.05], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$9"], 
         InsetBox[
          FormBox["8", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$9", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$9"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{1., 2.}, 0.05], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$10"], 
         InsetBox[
          FormBox["9", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$10", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$10"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{4., 2.}, 0.05], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$11"], 
         InsetBox[
          FormBox["12", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$11", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$11"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{-5., 1.}, 0.05], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$12"], 
         InsetBox[
          FormBox["11", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$12", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$12"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{-1., 3.}, 0.05], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$13"], 
         InsetBox[
          FormBox["13", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$13", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$13"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{-1., 2.}, 0.05], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$14"], 
         InsetBox[
          FormBox["14", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$14", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$14"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{2., 2.}, 0.05], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$15"], 
         InsetBox[
          FormBox["15", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$15", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$15"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{3., 2.}, 0.05], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$16"], 
         InsetBox[
          FormBox["16", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$16", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$16"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{5.760693309010094, 
       484.2393066909899}, {-127.9076173612113, 111.2393066909899}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImageSize->{491.94140625, Automatic}]], "Output",
 CellChangeTimes->{
  3.572175429191246*^9, 3.572175468763404*^9, {3.572547810209888*^9, 
   3.572547827103615*^9}, {3.572548068422269*^9, 3.5725481116533947`*^9}, {
   3.5725481606626797`*^9, 3.5725481720681477`*^9}, 3.57254831768519*^9, 
   3.573898819563076*^9, {3.573898878968968*^9, 3.573898903747291*^9}, 
   3.576559387327433*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Section",
 CellChangeTimes->{{3.5487310498981857`*^9, 3.5487310576573887`*^9}, {
  3.558792322659335*^9, 3.558792324619794*^9}}],

Cell[CellGroupData[{

Cell["Example 1", "Subsection",
 CellChangeTimes->{{3.54797203051853*^9, 3.5479720358404837`*^9}, {
  3.549855483188773*^9, 3.549855483282074*^9}, {3.558684424569099*^9, 
  3.558684425854336*^9}, {3.559288001610284*^9, 3.55928801079865*^9}, {
  3.559296625949349*^9, 3.559296636171339*^9}, {3.5593037031601877`*^9, 
  3.559303722477625*^9}, {3.5595633316739407`*^9, 3.5595633327132807`*^9}, {
  3.5725474902230473`*^9, 3.572547493767708*^9}, {3.573897446211834*^9, 
  3.573897489271779*^9}}],

Cell[TextData[{
 "Here we present an example taken from [",
 ButtonBox["2",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1007/978-3-642-36742-7_1"], None},
  ButtonNote->"http://dx.doi.org/10.1007/978-3-642-36742-7_1"],
 "], which shows most of the features of the on-the-fly algorithm.\nConsider \
the following MC:"
}], "Text",
 CellChangeTimes->{{3.559563234524556*^9, 3.559563415900241*^9}, {
  3.573897514650876*^9, 3.573897527133296*^9}, {3.5739000471784697`*^9, 
  3.573900148000017*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tmPaper", "=", 
   RowBox[{"MCtm", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", 
          RowBox[{"2", "|", "3"}]}], "}"}], "\[Rule]", 
        FractionBox["1", "3"]}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", 
          RowBox[{"4", "|", "6"}]}], "}"}], "\[Rule]", 
        FractionBox["1", "6"]}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"3", "|", "4"}]}], "}"}], "\[Rule]", 
        FractionBox["2", "5"]}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", "6"}], "}"}], "\[Rule]", 
        FractionBox["1", "5"]}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"2", "|", "3"}]}], "}"}], "\[Rule]", 
        FractionBox["1", "2"]}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"4", ",", 
          RowBox[{"1", "|", "2", "|", "3"}]}], "}"}], "\[Rule]", 
        FractionBox["1", "3"]}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"5", ",", "3"}], "}"}], "\[Rule]", 
        FractionBox["1", "5"]}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"5", ",", 
          RowBox[{"1", "|", "2"}]}], "}"}], "\[Rule]", 
        FractionBox["2", "5"]}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"6", ",", "1"}], "}"}], "\[Rule]", 
        FractionBox["1", "2"]}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"6", ",", "2"}], "}"}], "\[Rule]", 
        FractionBox["1", "10"]}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"6", ",", 
          RowBox[{"4", "|", "6"}]}], "}"}], "\[Rule]", 
        FractionBox["1", "5"]}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"7", ",", "3"}], "}"}], "\[Rule]", 
        FractionBox["1", "3"]}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"7", ",", "2"}], "}"}], "\[Rule]", 
        FractionBox["1", "5"]}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"7", ",", "5"}], "}"}], "\[Rule]", 
        FractionBox["1", "10"]}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"7", ",", "6"}], "}"}], "\[Rule]", 
        FractionBox["1", "5"]}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"7", ",", "7"}], "}"}], "\[Rule]", 
        FractionBox["1", "6"]}]}], "}"}], ",", "7"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lblPaper", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "1", ",", "1", ",", "1", ",", "2", ",", "1"}],
     "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mcPaper", "=", 
   RowBox[{"MC", "[", 
    RowBox[{"tmPaper", ",", "lblPaper"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"PlotMC", "[", "mcPaper", "]"}]}], "Input",
 CellChangeTimes->{{3.547971555364769*^9, 3.547971798684469*^9}, {
   3.547971852250057*^9, 3.54797186003193*^9}, {3.548731146234764*^9, 
   3.548731238070322*^9}, {3.549855487546175*^9, 3.549855683923971*^9}, {
   3.549855715896656*^9, 3.549855851553895*^9}, 3.5498559706441708`*^9, {
   3.549856116104793*^9, 3.549856118890915*^9}, {3.549856171892847*^9, 
   3.549856235937093*^9}, {3.549857188071733*^9, 3.5498571884785023`*^9}, {
   3.54985838583355*^9, 3.549858385936768*^9}, {3.557855184828906*^9, 
   3.557855207537613*^9}, {3.558794802480484*^9, 3.5587948464733143`*^9}, {
   3.559288040701201*^9, 3.559288102281488*^9}, {3.55929665937422*^9, 
   3.559296680582912*^9}, {3.5721564539205847`*^9, 3.572156472900051*^9}, {
   3.573897547987389*^9, 3.573897745550457*^9}, 3.573898860559877*^9}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 6, 3, 4, 5, 
      7}, {{{1, 2}, {1, 3}, {1, 4}, {1, 5}, {2, 3}, {2, 5}, {2, 4}, {4, 4}, {
       4, 2}, {5, 2}, {5, 4}, {5, 1}, {6, 2}, {6, 1}, {6, 4}, {3, 3}, {3, 
       5}, {3, 1}, {3, 2}, {7, 3}, {7, 2}, {7, 7}, {7, 6}, {7, 4}}, Null}, {
      EdgeLabels -> {
        DirectedEdge[1, 4] -> Rational[1, 6], DirectedEdge[5, 1] -> 
         Rational[2, 5], DirectedEdge[5, 2] -> Rational[2, 5], 
         DirectedEdge[2, 4] -> Rational[2, 5], DirectedEdge[5, 3] -> 
         Rational[1, 5], DirectedEdge[3, 3] -> Rational[1, 2], 
         DirectedEdge[4, 2] -> Rational[1, 3], DirectedEdge[4, 1] -> 
         Rational[1, 3], DirectedEdge[2, 3] -> Rational[2, 5], 
         DirectedEdge[1, 6] -> Rational[1, 6], DirectedEdge[1, 3] -> 
         Rational[1, 3], DirectedEdge[7, 5] -> Rational[1, 10], 
         DirectedEdge[3, 2] -> Rational[1, 2], DirectedEdge[6, 4] -> 
         Rational[1, 5], DirectedEdge[2, 6] -> Rational[1, 5], 
         DirectedEdge[6, 2] -> Rational[1, 10], DirectedEdge[7, 2] -> 
         Rational[1, 5], DirectedEdge[7, 3] -> Rational[1, 3], 
         DirectedEdge[4, 3] -> Rational[1, 3], DirectedEdge[1, 2] -> 
         Rational[1, 3], DirectedEdge[7, 7] -> Rational[1, 6], 
         DirectedEdge[6, 1] -> Rational[1, 2], DirectedEdge[6, 6] -> 
         Rational[1, 5], DirectedEdge[7, 6] -> Rational[1, 5]}, 
       VertexLabels -> {"Name"}, VertexSize -> {0.1}, VertexStyle -> {2 -> Hue[
           Rational[1, 3]], 1 -> Hue[
           Rational[1, 2]], 7 -> Hue[
           Rational[1, 2]], 5 -> Hue[
           Rational[1, 2]], 6 -> Hue[
           Rational[1, 3]], 4 -> Hue[
           Rational[1, 2]], 3 -> Hue[
           Rational[1, 2]]}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Arrowheads[0.03409407491657311], 
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$1", Automatic, Center], 
           DynamicLocation["VertexID$2", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$1"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$1", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$1", Automatic, Center], {
            1.2656579071764846`, 0.6570247371918105}, 
            DynamicLocation["VertexID$3", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$2"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$2", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$1", Automatic, Center], 
           DynamicLocation["VertexID$4", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$3"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$3", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$1", Automatic, Center], {
            1.58125245420896, 0.2524692642859984}, 
            DynamicLocation["VertexID$5", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$4"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$4", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$2", Automatic, Center], {
            1.221875476290815, 1.0708500381410349`}, 
            DynamicLocation["VertexID$3", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$5"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$5", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$2", Automatic, Center], {
            0.9348562769148654, 0.31563926841828016`}, 
            DynamicLocation["VertexID$4", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$6"], 
        InsetBox[
         FormBox[
          FractionBox["2", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$6", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$2", Automatic, Center], {
            1.5374700233232903`, 0.666294565235223}, 
            DynamicLocation["VertexID$5", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$7"], 
        InsetBox[
         FormBox[
          FractionBox["2", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$7", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$3", Automatic, Center], {
            1.6432615034056541`, 0.5588494063580607}, 
            DynamicLocation["VertexID$1", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$8"], 
        InsetBox[
         FormBox[
          FractionBox["1", "2"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$8", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$3", Automatic, Center], {
            1.3727553575628315`, 0.8750688017487237}, 
            DynamicLocation["VertexID$2", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$9"], 
        InsetBox[
         FormBox[
          FractionBox["1", "10"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$9", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$3", Automatic, Center], {
            1.5059752563589561`, 1.397188760358865}, {1.5727584820836054`, 
            1.5928240990713654`}, {1.693600502254624, 1.6638558597695003`}, {
            2.0031677334276425`, 1.4496614092138194`}, {1.9792915947117495`, 
            1.311537425536438}, {1.8197542591400042`, 1.1800801185884695`}, 
            DynamicLocation["VertexID$3", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$10"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$10", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$3", Automatic, Center], 
           DynamicLocation["VertexID$5", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$11"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$11", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$4", Automatic, Center], {
            0.7084146409071111, 0.4153137150895222}, 
            DynamicLocation["VertexID$2", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$12"], 
        InsetBox[
         FormBox[
          FractionBox["1", "2"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$12", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$4", Automatic, Center], {
            0.8370341354006801, -0.14895021752846027`}, {
            0.8341960607735279, -0.34671786197793814`}, {
            0.7483376808500797, -0.4495107260019362}, {
            0.3937719342481926, -0.3718922739872975}, {
            0.3587132045995254, -0.24262928712424772`}, {
            0.4387621655834368, -0.061763978941388714`}, 
            DynamicLocation["VertexID$4", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$13"], 
        InsetBox[
         FormBox[
          FractionBox["1", "2"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$13", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$5", Automatic, Center], {
            1.6741588250043773`, 0.046686927946469975`}, 
            DynamicLocation["VertexID$1", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$14"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$14", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$5", Automatic, Center], {
            1.4036526791615542`, 0.36290632333713296`}, 
            DynamicLocation["VertexID$2", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$15"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$15", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$5", Automatic, Center], 
           DynamicLocation["VertexID$4", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$16"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$16", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$6", Automatic, Center], 
           DynamicLocation["VertexID$1", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$17"], 
        InsetBox[
         FormBox[
          FractionBox["2", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$17", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$6", Automatic, Center], 
           DynamicLocation["VertexID$2", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$18"], 
        InsetBox[
         FormBox[
          FractionBox["2", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$18", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$6", Automatic, Center], 
           DynamicLocation["VertexID$4", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$19"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$19", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$7", Automatic, Center], 
           DynamicLocation["VertexID$2", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$20"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$20", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$7", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$21"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$21", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$7", Automatic, Center], 
           DynamicLocation["VertexID$4", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$22"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$22", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$7", Automatic, Center], 
           DynamicLocation["VertexID$6", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$23"], 
        InsetBox[
         FormBox[
          FractionBox["1", "10"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$23", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$7", Automatic, Center], {
            0.14566311181324781`, 
            1.1825164584822634`}, {-0.013233894901922172`, 
            1.314747038335425}, {-0.03643892674217189, 1.4529853519976765`}, {
            0.2741649293760618, 1.6656738045038308`}, {0.3946605451639149, 
            1.5940559893821995`}, {0.460492843188324, 1.3980986125673178`}, 
            DynamicLocation["VertexID$7", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$24"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$24", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{1.296398649348736, 0.}, 0.03176192267492186], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.9821100726202437, 0.7300446963398874}, 
            0.03176192267492186], 
           Hue[
            Rational[1, 3]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.6125207612334025`, 1.215874143549871}, 
            0.03176192267492186], 
           Hue[
            Rational[1, 3]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["6", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.6611608452017326, 0.0009082871679146898}, 
            0.03176192267492186], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.959012629864601, 0.29915619223246837`}, 
            0.03176192267492186], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{0., 0.30380527089768966`}, 0.03176192267492186], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.35306800611357814`, 1.217303592566746}, 
            0.03176192267492186], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$7"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{3.7606933090100982`, 
       359.1003533241038}, {-184.2393066909899, 180.2393066909899}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output",
 CellChangeTimes->{
  3.559282901652236*^9, 3.559288107048532*^9, 3.559290102268177*^9, 
   3.5592966889186773`*^9, 3.559299854555287*^9, 3.559300571040485*^9, 
   3.5593682887098722`*^9, 3.559561288442525*^9, 3.559563501867509*^9, 
   3.572156483996854*^9, 3.572169370402898*^9, 3.572175155430382*^9, 
   3.5721754581540623`*^9, 3.572547537126556*^9, 3.573898819983773*^9, {
   3.573898862843315*^9, 3.573898879135092*^9}, 3.576559387495638*^9}]
}, Open  ]],

Cell[TextData[{
 "Let us compute the undiscouted distance between the state ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "1"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "4"], TraditionalForm]]],
 ", namely ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Delta]", "1"], "(", 
    RowBox[{
     SubscriptBox["s", "1"], ",", 
     SubscriptBox["s", "4"]}], ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Text",
 CellChangeTimes->{{3.55930472457067*^9, 3.5593047657638893`*^9}, {
  3.573897761375869*^9, 3.5738978225793343`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BDistMC", "[", 
  RowBox[{"mcPaper", ",", "1", ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "}"}], ",", " ", 
   RowBox[{"Verbose", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.559280648876001*^9, 3.559280666970271*^9}, {
   3.559281485366975*^9, 3.5592814854943*^9}, {3.559281705565312*^9, 
   3.559281708090787*^9}, {3.559288114041607*^9, 3.559288127092181*^9}, {
   3.5592881703589563`*^9, 3.559288173912812*^9}, 3.559288794513839*^9, {
   3.559288827768854*^9, 3.559288834289609*^9}, {3.55929669614686*^9, 
   3.559296696259295*^9}, {3.559297128972578*^9, 3.559297129408716*^9}, {
   3.559306122098216*^9, 3.559306122406487*^9}, {3.559311462052354*^9, 
   3.559311463033885*^9}, {3.5593117152654667`*^9, 3.559311716121128*^9}, {
   3.559314252974621*^9, 3.559314253730104*^9}, {3.5595613007723427`*^9, 
   3.559561371547716*^9}, 3.57217477991364*^9, 3.573890000738346*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Pairs to compute: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "}"}]}],
  SequenceForm["Pairs to compute: ", {{1, 4}}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.573898868656115*^9, 3.573898879201503*^9}, 
   3.576559387575384*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Picked pair: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "}"}]}],
  SequenceForm["Picked pair: ", {{1, 4}}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.573898868656115*^9, 3.573898879201503*^9}, 
   3.576559387577944*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{1, 4}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.573898868656115*^9, 3.573898879201503*^9}, 
   3.57655938757981*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"1", "2", "3"}}]]]}]], "Print",
 CellChangeTimes->{{3.573898868656115*^9, 3.573898879201503*^9}, 
   3.576559387582896*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"2", "3"}, {"1", "2", "3"}}]]]}]], "Print",\

 CellChangeTimes->{{3.573898868656115*^9, 3.573898879201503*^9}, 
   3.576559387585659*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.573898868656115*^9, 3.573898879201503*^9}, 
   3.5765593875875587`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", 
        RowBox[{"-", 
         FractionBox["1", "6"]}]},
       {"0", "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {2, 2}, 0, {
       1, {{0, 2, 3}, {{1}, {2}, {2}}}, {1, Rational[-1, 6], 1}}]]]], 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["5", "6"]},
        {
         FractionBox["1", "2"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {2}, 0, {1, {{0, 2}, {{1}, {2}}}, {
         Rational[5, 6], 
         Rational[1, 2]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["11", "12"]},
        {
         FractionBox["1", "2"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[
    Automatic, {2, 2}, 0, {
     1, {{0, 2, 3}, {{1}, {2}, {2}}}, {1, Rational[-1, 6], 1}}]], 
   MatrixForm[{"d(1,4)", "d(3,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {2}, 0, {1, {{0, 2}, {{1}, {2}}}, {
       Rational[5, 6], 
       Rational[1, 2]}}]], ";  Solution:", 
   MatrixForm[{"d(1,4)", "d(3,4)"}], "=", 
   MatrixForm[{
     Rational[11, 12], 
     Rational[1, 2]}]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.573898868656115*^9, 3.573898879201503*^9}, 
   3.576559387590073*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Non optimal schedule for: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4"}], "}"}], 
   "\[InvisibleSpace]", "\<\" reduced cost: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "2"}], "\[InvisibleSpace]", "\<\" for introducing \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], "\[InvisibleSpace]", "\<\" as basic\"\>"}],
  SequenceForm[
  "Non optimal schedule for: ", {1, 4}, " reduced cost: ", -2, 
   " for introducing ", {4, 1}, " as basic"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.573898868656115*^9, 3.573898879201503*^9}, 
   3.576559387592197*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{1, 4}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.573898868656115*^9, 3.573898879201503*^9}, 
   3.576559387594081*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"1", "2", "3"}}]]]}]], "Print",
 CellChangeTimes->{{3.573898868656115*^9, 3.573898879201503*^9}, 
   3.5765593875962677`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.573898868656115*^9, 3.573898879201503*^9}, 
   3.576559387599025*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        FractionBox["5", "6"]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {1, 1}, 0, {1, {{0, 1}, {{1}}}, {Rational[5, 6]}}]]]], 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["1", "6"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {1}, 0, {1, {{0, 1}, {{1}}}, {
         Rational[1, 6]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["1", "5"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[Automatic, {1, 1}, 0, {1, {{0, 1}, {{1}}}, {Rational[5, 6]}}]], 
   MatrixForm[{"d(1,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {1}, 0, {1, {{0, 1}, {{1}}}, {
       Rational[1, 6]}}]], ";  Solution:", 
   MatrixForm[{"d(1,4)"}], "=", 
   MatrixForm[{
     Rational[1, 5]}]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.573898868656115*^9, 3.573898879201503*^9}, 
   3.576559387601602*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Non optimal schedule for: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4"}], "}"}], 
   "\[InvisibleSpace]", "\<\" reduced cost: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["3", "10"]}], 
   "\[InvisibleSpace]", "\<\" for introducing \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], "\[InvisibleSpace]", "\<\" as basic\"\>"}],
  SequenceForm["Non optimal schedule for: ", {1, 4}, " reduced cost: ", 
   Rational[-3, 10], " for introducing ", {1, 3}, " as basic"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.573898868656115*^9, 3.573898879201503*^9}, 
   3.576559387603857*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{1, 4}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.573898868656115*^9, 3.573898879201503*^9}, 
   3.5765593876067266`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0"},
      {
       TagBox["\<\"6\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"1", "2", "3"}}]]]}]], "Print",
 CellChangeTimes->{{3.573898868656115*^9, 3.573898879201503*^9}, 
   3.576559387608941*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.573898868656115*^9, 3.573898879201503*^9}, 
   3.576559387611164*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        FractionBox["5", "6"]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {1, 1}, 0, {1, {{0, 1}, {{1}}}, {Rational[5, 6]}}]]]], 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["1", "6"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {1}, 0, {1, {{0, 1}, {{1}}}, {
         Rational[1, 6]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["1", "5"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[Automatic, {1, 1}, 0, {1, {{0, 1}, {{1}}}, {Rational[5, 6]}}]], 
   MatrixForm[{"d(1,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {1}, 0, {1, {{0, 1}, {{1}}}, {
       Rational[1, 6]}}]], ";  Solution:", 
   MatrixForm[{"d(1,4)"}], "=", 
   MatrixForm[{
     Rational[1, 5]}]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.573898868656115*^9, 3.573898879201503*^9}, 
   3.5765593876141987`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total solved TPs: \"\>", "\[InvisibleSpace]", "2"}],
  SequenceForm["Total solved TPs: ", 2],
  Editable->False]], "Print",
 CellChangeTimes->{{3.573898868656115*^9, 3.573898879201503*^9}, 
   3.5765593876161757`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Execution Time: \"\>", "\[InvisibleSpace]", 
   "0.06940499999999999447553022946522105485`4.861990671835202", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm[
  "Execution Time: ", 
   0.06940499999999999447553022946522105485`4.861990671835202, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.573898868656115*^9, 3.573898879201503*^9}, 
   3.576559387617923*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
   FractionBox["1", "5"]}], "}"}]], "Output",
 CellChangeTimes->{
  3.559283062260519*^9, 3.559283141481842*^9, 3.559283429519863*^9, 
   3.559287899080534*^9, 3.559288127938177*^9, 3.559288174828513*^9, 
   3.559288645745462*^9, 3.559288761246047*^9, {3.5592887951671*^9, 
   3.559288834995525*^9}, 3.559290105497293*^9, 3.559296697919303*^9, {
   3.559297120179008*^9, 3.5592971300608263`*^9}, 3.559299854710971*^9, 
   3.559300574782845*^9, 3.55930612328936*^9, 3.559311463753718*^9, 
   3.559311717208878*^9, 3.559314254623217*^9, 3.559368288886137*^9, 
   3.5595612917670527`*^9, {3.559561325748827*^9, 3.559561372289369*^9}, 
   3.5595635020160027`*^9, 3.5721564933941097`*^9, 3.572175155507663*^9, 
   3.57217545823853*^9, 3.5725475436831017`*^9, 3.573898820123952*^9, {
   3.5738988686968184`*^9, 3.573898879240378*^9}, 3.5765593876199207`*^9}]
}, Open  ]],

Cell["\<\
Looking at the execution trace we see that during the computation of d(1,4) \
an over-approximation for the distance d(3,4) is computed. 
This happens because we encountered a coupling that demands d(3,4) for \
computing an over-approximation of d(1,4). 
However, the first improvement of the current coupling makes the computation \
of d(3,4) no more demanded for d(1,4), so that no further improvement on \
(3,4) is made.\
\>", "Text",
 CellChangeTimes->{{3.5593038027299967`*^9, 3.559304305686409*^9}, {
  3.559304573166234*^9, 3.559304682875122*^9}, {3.573897857670253*^9, 
  3.573897858390033*^9}, {3.5739001795660353`*^9, 3.573900179726037*^9}}],

Cell[TextData[{
 "The following execution trace shows that the exact computation of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Delta]", "1"], "(", 
    RowBox[{
     SubscriptBox["s", "3"], ",", 
     SubscriptBox["s", "4"]}], ")"}], TraditionalForm]]],
 " demands an exact computation of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Delta]", "1"], "(", 
    RowBox[{
     SubscriptBox["s", "1"], ",", 
     SubscriptBox["s", "3"]}], ")"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Delta]", "1"], "(", 
    RowBox[{
     SubscriptBox["s", "1"], ",", 
     SubscriptBox["s", "4"]}], ")"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Delta]", "1"], "(", 
    RowBox[{
     SubscriptBox["s", "2"], ",", 
     SubscriptBox["s", "6"]}], ")"}], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.55930468716146*^9, 3.559304697434*^9}, {
  3.5593047727723007`*^9, 3.559304869775578*^9}, {3.5593050081153173`*^9, 
  3.5593050109707203`*^9}, {3.5593051195620403`*^9, 3.55930515393615*^9}, {
  3.5738978976314993`*^9, 3.573897947423192*^9}, {3.5739002753036213`*^9, 
  3.573900359666327*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BDistMC", "[", 
  RowBox[{"mcPaper", ",", "1", ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "}"}], ",", " ", 
   RowBox[{"Verbose", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5593048838664207`*^9, 3.559304883928726*^9}, {
   3.559306130529502*^9, 3.559306130847048*^9}, {3.559311451716378*^9, 
   3.559311452465706*^9}, {3.559311487245051*^9, 3.5593114880664673`*^9}, {
   3.5593117029367933`*^9, 3.559311735169549*^9}, {3.559314266587071*^9, 
   3.559314273234703*^9}, {3.5595614134557047`*^9, 3.559561441574979*^9}, {
   3.559561495687004*^9, 3.5595615995856657`*^9}, {3.559562352908433*^9, 
   3.559562377344582*^9}, 3.572174779914897*^9, {3.572547570021254*^9, 
   3.5725475758079357`*^9}, 3.573890000739403*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Pairs to compute: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "}"}]}],
  SequenceForm["Pairs to compute: ", {{3, 4}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.5765593877291403`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Picked pair: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "}"}]}],
  SequenceForm["Picked pair: ", {{3, 4}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.576559387730438*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{3, 4}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.5765593877329397`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"2", "3"}, {"1", "2", "3"}}]]]}]], "Print",\

 CellChangeTimes->{3.573898879296093*^9, 3.576559387734996*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.576559387736772*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[Automatic, {1, 1}, 0, {1, {{0, 1}, {{1}}}, {1}}]]]], 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["1", "2"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {1}, 0, {1, {{0, 1}, {{1}}}, {
         Rational[1, 2]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["1", "2"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[SparseArray[Automatic, {1, 1}, 0, {1, {{0, 1}, {{1}}}, {1}}]], 
   MatrixForm[{"d(3,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {1}, 0, {1, {{0, 1}, {{1}}}, {
       Rational[1, 2]}}]], ";  Solution:", 
   MatrixForm[{"d(3,4)"}], "=", 
   MatrixForm[{
     Rational[1, 2]}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.576559387739575*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Non optimal schedule for: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], 
   "\[InvisibleSpace]", "\<\" reduced cost: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "1"}], "\[InvisibleSpace]", "\<\" for introducing \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "1"}], "}"}], "\[InvisibleSpace]", "\<\" as basic\"\>"}],
  SequenceForm[
  "Non optimal schedule for: ", {3, 4}, " reduced cost: ", -1, 
   " for introducing ", {2, 1}, " as basic"],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.57655938774277*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{3, 4}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.576559387745625*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "3"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"2", "3"}}]]]}]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.576559387748494*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"2", "3"}, {"1", "2", "3"}}]]]}]], "Print",\

 CellChangeTimes->{3.573898879296093*^9, 3.576559387750937*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.57655938775277*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", 
        RowBox[{"-", 
         FractionBox["1", "6"]}]},
       {
        RowBox[{"-", 
         FractionBox["1", "6"]}], "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {2, 2}, 0, {
       1, {{0, 2, 4}, {{1}, {2}, {1}, {2}}}, {
        1, Rational[-1, 6], Rational[-1, 6], 1}}]]]], "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["1", "3"]},
        {
         FractionBox["1", "6"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {2}, 0, {1, {{0, 2}, {{1}, {2}}}, {
         Rational[1, 3], 
         Rational[1, 6]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["13", "35"]},
        {
         FractionBox["8", "35"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[
    Automatic, {2, 2}, 0, {
     1, {{0, 2, 4}, {{1}, {2}, {1}, {2}}}, {
      1, Rational[-1, 6], Rational[-1, 6], 1}}]], 
   MatrixForm[{"d(1,3)", "d(3,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {2}, 0, {1, {{0, 2}, {{1}, {2}}}, {
       Rational[1, 3], 
       Rational[1, 6]}}]], ";  Solution:", 
   MatrixForm[{"d(1,3)", "d(3,4)"}], "=", 
   MatrixForm[{
     Rational[13, 35], 
     Rational[8, 35]}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.5765593877554903`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Non optimal schedule for: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], 
   "\[InvisibleSpace]", "\<\" reduced cost: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "1"}], "\[InvisibleSpace]", "\<\" for introducing \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], "\[InvisibleSpace]", "\<\" as basic\"\>"}],
  SequenceForm[
  "Non optimal schedule for: ", {1, 3}, " reduced cost: ", -1, 
   " for introducing ", {4, 1}, " as basic"],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.576559387758374*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{3, 4}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.576559387760439*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "3"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"2", "3"}}]]]}]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.576559387762926*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"1", "2", "3"}}]]]}]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.576559387765924*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"2", ",", "6"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"4\"\>",
        HoldForm], 
       TagBox["\<\"6\"\>",
        HoldForm]},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["2", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0", "0"},
      {
       TagBox["\<\"4\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "10"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "10"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], "0", "0", "0", 
       StyleBox[
        FractionBox["1", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"3", "4", "6"}, {"1", "2", "4", "6"}}]]]}]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.576559387768141*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"2", "3"}, {"1", "2", "3"}}]]]}]], "Print",\

 CellChangeTimes->{3.573898879296093*^9, 3.57655938777124*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.5765593877733192`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", "0", 
        RowBox[{"-", 
         FractionBox["1", "6"]}], 
        RowBox[{"-", 
         FractionBox["1", "6"]}]},
       {"0", "1", "0", 
        RowBox[{"-", 
         FractionBox["1", "6"]}]},
       {
        RowBox[{"-", 
         FractionBox["2", "5"]}], 
        RowBox[{"-", 
         FractionBox["1", "10"]}], "1", "0"},
       {
        RowBox[{"-", 
         FractionBox["1", "6"]}], "0", "0", "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {4, 4}, 0, {
       1, {{0, 3, 5, 8, 10}, {{1}, {3}, {4}, {2}, {4}, {3}, {1}, {2}, {1}, {
         4}}}, {1, Rational[-1, 6], Rational[-1, 6], 1, Rational[-1, 6], 1, 
         Rational[-2, 5], Rational[-1, 10], Rational[-1, 6], 1}}]]]], 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(2,6)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"0"},
        {
         FractionBox["5", "6"]},
        {
         FractionBox["1", "10"]},
        {
         FractionBox["1", "6"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {4}, 0, {1, {{0, 4}, {{1}, {2}, {3}, {4}}}, {0, 
         Rational[5, 6], 
         Rational[1, 10], 
         Rational[1, 6]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(2,6)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["127", "1955"]},
        {
         FractionBox["1687", "1955"]},
        {
         FractionBox["83", "391"]},
        {
         FractionBox["347", "1955"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {
     1, {{0, 3, 5, 8, 10}, {{1}, {3}, {4}, {2}, {4}, {3}, {1}, {2}, {1}, {
       4}}}, {1, Rational[-1, 6], Rational[-1, 6], 1, Rational[-1, 6], 1, 
       Rational[-2, 5], Rational[-1, 10], Rational[-1, 6], 1}}]], 
   MatrixForm[{"d(1,3)", "d(1,4)", "d(2,6)", "d(3,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {4}, 0, {1, {{0, 4}, {{1}, {2}, {3}, {4}}}, {0, 
       Rational[5, 6], 
       Rational[1, 10], 
       Rational[1, 6]}}]], ";  Solution:", 
   MatrixForm[{"d(1,3)", "d(1,4)", "d(2,6)", "d(3,4)"}], "=", 
   MatrixForm[{
     Rational[127, 1955], 
     Rational[1687, 1955], 
     Rational[83, 391], 
     Rational[347, 1955]}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.576559387775982*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Non optimal schedule for: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4"}], "}"}], 
   "\[InvisibleSpace]", "\<\" reduced cost: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "2"}], "\[InvisibleSpace]", "\<\" for introducing \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], "\[InvisibleSpace]", "\<\" as basic\"\>"}],
  SequenceForm[
  "Non optimal schedule for: ", {1, 4}, " reduced cost: ", -2, 
   " for introducing ", {4, 1}, " as basic"],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.576559387779657*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{3, 4}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.576559387781619*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "3"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"2", "3"}}]]]}]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.57655938778421*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"1", "2", "3"}}]]]}]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.576559387786468*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"2", ",", "6"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"4\"\>",
        HoldForm], 
       TagBox["\<\"6\"\>",
        HoldForm]},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["2", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0", "0"},
      {
       TagBox["\<\"4\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "10"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "10"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], "0", "0", "0", 
       StyleBox[
        FractionBox["1", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"3", "4", "6"}, {"1", "2", "4", "6"}}]]]}]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.5765593877894983`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"2", "3"}, {"1", "2", "3"}}]]]}]], "Print",\

 CellChangeTimes->{3.573898879296093*^9, 3.576559387792351*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.576559387795735*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", "0", 
        RowBox[{"-", 
         FractionBox["1", "6"]}], 
        RowBox[{"-", 
         FractionBox["1", "6"]}]},
       {
        RowBox[{"-", 
         FractionBox["1", "6"]}], "1", "0", 
        RowBox[{"-", 
         FractionBox["1", "6"]}]},
       {
        RowBox[{"-", 
         FractionBox["2", "5"]}], 
        RowBox[{"-", 
         FractionBox["1", "10"]}], "1", "0"},
       {
        RowBox[{"-", 
         FractionBox["1", "6"]}], "0", "0", "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {4, 4}, 0, {
       1, {{0, 3, 6, 9, 11}, {{1}, {3}, {4}, {2}, {1}, {4}, {3}, {1}, {2}, {
         1}, {4}}}, {
        1, Rational[-1, 6], Rational[-1, 6], 1, Rational[-1, 6], 
         Rational[-1, 6], 1, Rational[-2, 5], Rational[-1, 10], 
         Rational[-1, 6], 1}}]]]], "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(2,6)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"0"},
        {
         FractionBox["1", "6"]},
        {
         FractionBox["1", "10"]},
        {
         FractionBox["1", "6"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {4}, 0, {1, {{0, 4}, {{1}, {2}, {3}, {4}}}, {0, 
         Rational[1, 6], 
         Rational[1, 10], 
         Rational[1, 6]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(2,6)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["103", "1949"]},
        {
         FractionBox["399", "1949"]},
        {
         FractionBox["276", "1949"]},
        {
         FractionBox["342", "1949"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {
     1, {{0, 3, 6, 9, 11}, {{1}, {3}, {4}, {2}, {1}, {4}, {3}, {1}, {2}, {
       1}, {4}}}, {
      1, Rational[-1, 6], Rational[-1, 6], 1, Rational[-1, 6], 
       Rational[-1, 6], 1, Rational[-2, 5], Rational[-1, 10], Rational[-1, 6],
        1}}]], 
   MatrixForm[{"d(1,3)", "d(1,4)", "d(2,6)", "d(3,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {4}, 0, {1, {{0, 4}, {{1}, {2}, {3}, {4}}}, {0, 
       Rational[1, 6], 
       Rational[1, 10], 
       Rational[1, 6]}}]], ";  Solution:", 
   MatrixForm[{"d(1,3)", "d(1,4)", "d(2,6)", "d(3,4)"}], "=", 
   MatrixForm[{
     Rational[103, 1949], 
     Rational[399, 1949], 
     Rational[276, 1949], 
     Rational[342, 1949]}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.57655938779895*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Non optimal schedule for: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4"}], "}"}], 
   "\[InvisibleSpace]", "\<\" reduced cost: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["46", "1949"]}], 
   "\[InvisibleSpace]", "\<\" for introducing \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], "\[InvisibleSpace]", "\<\" as basic\"\>"}],
  SequenceForm["Non optimal schedule for: ", {1, 4}, " reduced cost: ", 
   Rational[-46, 1949], " for introducing ", {3, 1}, " as basic"],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.576559387801426*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{3, 4}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.5765593878038397`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "3"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"2", "3"}}]]]}]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.576559387805913*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"1", "2", "3"}}]]]}]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.576559387808214*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"2", ",", "6"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"4\"\>",
        HoldForm], 
       TagBox["\<\"6\"\>",
        HoldForm]},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["2", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0", "0"},
      {
       TagBox["\<\"4\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "10"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "10"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], "0", "0", "0", 
       StyleBox[
        FractionBox["1", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"3", "4", "6"}, {"1", "2", "4", "6"}}]]]}]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.5765593878105097`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"2", "3"}, {"1", "2", "3"}}]]]}]], "Print",\

 CellChangeTimes->{3.573898879296093*^9, 3.57655938781422*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.576559387816741*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", "0", 
        RowBox[{"-", 
         FractionBox["1", "6"]}], 
        RowBox[{"-", 
         FractionBox["1", "6"]}]},
       {"0", 
        FractionBox["5", "6"], "0", "0"},
       {
        RowBox[{"-", 
         FractionBox["2", "5"]}], 
        RowBox[{"-", 
         FractionBox["1", "10"]}], "1", "0"},
       {
        RowBox[{"-", 
         FractionBox["1", "6"]}], "0", "0", "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {4, 4}, 0, {
       1, {{0, 3, 4, 7, 9}, {{1}, {3}, {4}, {2}, {3}, {1}, {2}, {1}, {4}}}, {
        1, Rational[-1, 6], Rational[-1, 6], Rational[5, 6], 1, 
         Rational[-2, 5], Rational[-1, 10], Rational[-1, 6], 1}}]]]], 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(2,6)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"0"},
        {
         FractionBox["1", "6"]},
        {
         FractionBox["1", "10"]},
        {
         FractionBox["1", "6"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {4}, 0, {1, {{0, 4}, {{1}, {2}, {3}, {4}}}, {0, 
         Rational[1, 6], 
         Rational[1, 10], 
         Rational[1, 6]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(2,6)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["43", "815"]},
        {
         FractionBox["1", "5"]},
        {
         FractionBox["23", "163"]},
        {
         FractionBox["143", "815"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {
     1, {{0, 3, 4, 7, 9}, {{1}, {3}, {4}, {2}, {3}, {1}, {2}, {1}, {4}}}, {
      1, Rational[-1, 6], Rational[-1, 6], Rational[5, 6], 1, Rational[-2, 5],
        Rational[-1, 10], Rational[-1, 6], 1}}]], 
   MatrixForm[{"d(1,3)", "d(1,4)", "d(2,6)", "d(3,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {4}, 0, {1, {{0, 4}, {{1}, {2}, {3}, {4}}}, {0, 
       Rational[1, 6], 
       Rational[1, 10], 
       Rational[1, 6]}}]], ";  Solution:", 
   MatrixForm[{"d(1,3)", "d(1,4)", "d(2,6)", "d(3,4)"}], "=", 
   MatrixForm[{
     Rational[43, 815], 
     Rational[1, 5], 
     Rational[23, 163], 
     Rational[143, 815]}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.5765593878197117`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total solved TPs: \"\>", "\[InvisibleSpace]", "4"}],
  SequenceForm["Total solved TPs: ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.576559387822295*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Execution Time: \"\>", "\[InvisibleSpace]", 
   "0.09121200000000000140953915206409874372`4.980651891859673", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm[
  "Execution Time: ", 
   0.09121200000000000140953915206409874372`4.980651891859673, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879296093*^9, 3.576559387823977*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
   FractionBox["143", "815"]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5593048848353577`*^9, 3.5593061317541723`*^9, 3.5593114534218616`*^9, 
   3.559311489113224*^9, {3.559311708850245*^9, 3.559311736016592*^9}, {
   3.559314268629867*^9, 3.559314274024948*^9}, 3.5593682890544643`*^9, 
   3.559561385052425*^9, 3.559561446807169*^9, {3.5595614983477097`*^9, 
   3.55956160035608*^9}, {3.55956235465364*^9, 3.559562379143865*^9}, 
   3.5595635021886587`*^9, 3.572156502727154*^9, 3.5721751556222963`*^9, 
   3.572175458340364*^9, {3.572547558250217*^9, 3.572547576500692*^9}, 
   3.573898820243042*^9, 3.573898879378471*^9, 3.576559387825658*^9}]
}, Open  ]],

Cell["\<\
One would claim that if we ask for the exact computation of d(3,4), d(1,4) \
and d(2,6) the computation will do the same steps made for d(3,4). However, \
the exact computation of d(1,4) does not need an exact computation of the \
remaining pairs.
Thus, considering the pair (1,4) before (3,4) will allow us to reduce the \
size of the linear equation systems computed for d(3,4).\
\>", "Text",
 CellChangeTimes->{{3.559305199635118*^9, 3.559305914445759*^9}, {
   3.572179781434353*^9, 3.572179792761908*^9}, {3.5738979938882113`*^9, 
   3.573898000304524*^9}, 3.5738980345896597`*^9, {3.5739004149287786`*^9, 
   3.57390044153823*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BDistMC", "[", 
  RowBox[{"mcPaper", ",", "1", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}]}], "}"}], ",", " ", 
   RowBox[{"Verbose", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.55930493318233*^9, 3.559304955828421*^9}, {
   3.559306150154635*^9, 3.559306150728084*^9}, {3.559308153723977*^9, 
   3.559308153865499*^9}, {3.5593108394498*^9, 3.5593108457740793`*^9}, {
   3.559310918747622*^9, 3.5593109219236403`*^9}, {3.559311447060152*^9, 
   3.5593114478821373`*^9}, {3.559314307526905*^9, 3.559314308236081*^9}, 
   3.572174779916296*^9, {3.572548393255465*^9, 3.572548396693399*^9}, 
   3.573890000740396*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
    FractionBox["1", "5"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "6"}], "}"}], "\[Rule]", 
    FractionBox["23", "163"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
    FractionBox["143", "815"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.559304961854267*^9, {3.5593050507744904`*^9, 3.559305055766686*^9}, 
   3.559306151586478*^9, {3.559308155909326*^9, 3.5593081698379793`*^9}, {
   3.559310041592722*^9, 3.559310053929261*^9}, 3.559310846666932*^9, 
   3.5593109230495377`*^9, 3.559311392690226*^9, 3.559311448589919*^9, {
   3.559314304888461*^9, 3.5593143091427393`*^9}, 3.55936828921422*^9, 
   3.5595623927233667`*^9, 3.559563502415098*^9, {3.572156519002552*^9, 
   3.57215652584485*^9}, 3.572175155751285*^9, 3.5721754584789553`*^9, {
   3.572547597597624*^9, 3.572547610086575*^9}, 3.572548397365593*^9, 
   3.573898820372161*^9, 3.573898879434413*^9, 3.576559387939974*^9}]
}, Open  ]],

Cell["", "Text"],

Cell[TextData[{
 "Another way to reduce the exploration of the MC is to give estimates for \
some distances. Assume we have an over-approximation of the exact value for \
d(2,6). By using this information, we can further reduce the state space \
explotation of the MC. This is done using the ",
 StyleBox["Estimates", "Program"],
 " option as follows:"
}], "Text",
 CellChangeTimes->{{3.559562431233766*^9, 3.559562815138789*^9}, {
  3.559562848899838*^9, 3.559562862172022*^9}, {3.573898063627623*^9, 
  3.5738980836586514`*^9}, {3.573900482938878*^9, 3.573900775912985*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BDistMC", "[", 
  RowBox[{"mcPaper", ",", "1", ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "}"}], ",", " ", 
   RowBox[{"Verbose", "\[Rule]", "True"}], ",", 
   RowBox[{"Estimates", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "6"}], "}"}], "\[Rule]", 
      FractionBox["23", "163"]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.559562881433319*^9, 3.55956291088018*^9}, 
   3.572174779918579*^9, 3.572547728617991*^9, 3.573890000741136*^9, {
   3.5738900878253202`*^9, 3.5738900886011763`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Pairs to compute: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "}"}]}],
  SequenceForm["Pairs to compute: ", {{3, 4}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879459999*^9, 3.576559388069709*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Picked pair: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "}"}]}],
  SequenceForm["Picked pair: ", {{3, 4}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879459999*^9, 3.57655938807104*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{3, 4}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879459999*^9, 3.576559388072597*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"2", "3"}, {"1", "2", "3"}}]]]}]], "Print",\

 CellChangeTimes->{3.573898879459999*^9, 3.5765593880747833`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879459999*^9, 3.5765593880764227`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[Automatic, {1, 1}, 0, {1, {{0, 1}, {{1}}}, {1}}]]]], 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["1", "2"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {1}, 0, {1, {{0, 1}, {{1}}}, {
         Rational[1, 2]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["1", "2"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[SparseArray[Automatic, {1, 1}, 0, {1, {{0, 1}, {{1}}}, {1}}]], 
   MatrixForm[{"d(3,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {1}, 0, {1, {{0, 1}, {{1}}}, {
       Rational[1, 2]}}]], ";  Solution:", 
   MatrixForm[{"d(3,4)"}], "=", 
   MatrixForm[{
     Rational[1, 2]}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879459999*^9, 3.5765593880785713`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Non optimal schedule for: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], 
   "\[InvisibleSpace]", "\<\" reduced cost: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "1"}], "\[InvisibleSpace]", "\<\" for introducing \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "1"}], "}"}], "\[InvisibleSpace]", "\<\" as basic\"\>"}],
  SequenceForm[
  "Non optimal schedule for: ", {3, 4}, " reduced cost: ", -1, 
   " for introducing ", {2, 1}, " as basic"],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879459999*^9, 3.576559388080414*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{3, 4}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879459999*^9, 3.5765593880820503`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "3"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"2", "3"}}]]]}]], "Print",
 CellChangeTimes->{3.573898879459999*^9, 3.576559388083956*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"2", "3"}, {"1", "2", "3"}}]]]}]], "Print",\

 CellChangeTimes->{3.573898879459999*^9, 3.576559388085971*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879459999*^9, 3.576559388087637*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", 
        RowBox[{"-", 
         FractionBox["1", "6"]}]},
       {
        RowBox[{"-", 
         FractionBox["1", "6"]}], "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {2, 2}, 0, {
       1, {{0, 2, 4}, {{1}, {2}, {1}, {2}}}, {
        1, Rational[-1, 6], Rational[-1, 6], 1}}]]]], "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["1", "3"]},
        {
         FractionBox["1", "6"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {2}, 0, {1, {{0, 2}, {{1}, {2}}}, {
         Rational[1, 3], 
         Rational[1, 6]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["13", "35"]},
        {
         FractionBox["8", "35"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[
    Automatic, {2, 2}, 0, {
     1, {{0, 2, 4}, {{1}, {2}, {1}, {2}}}, {
      1, Rational[-1, 6], Rational[-1, 6], 1}}]], 
   MatrixForm[{"d(1,3)", "d(3,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {2}, 0, {1, {{0, 2}, {{1}, {2}}}, {
       Rational[1, 3], 
       Rational[1, 6]}}]], ";  Solution:", 
   MatrixForm[{"d(1,3)", "d(3,4)"}], "=", 
   MatrixForm[{
     Rational[13, 35], 
     Rational[8, 35]}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879459999*^9, 3.576559388089788*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Non optimal schedule for: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], 
   "\[InvisibleSpace]", "\<\" reduced cost: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["303", "163"]}], 
   "\[InvisibleSpace]", "\<\" for introducing \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], "\[InvisibleSpace]", "\<\" as basic\"\>"}],
  SequenceForm["Non optimal schedule for: ", {1, 3}, " reduced cost: ", 
   Rational[-303, 163], " for introducing ", {4, 1}, " as basic"],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879459999*^9, 3.576559388091764*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{3, 4}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879459999*^9, 3.576559388093399*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "3"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"2", "3"}}]]]}]], "Print",
 CellChangeTimes->{3.573898879459999*^9, 3.5765593880953083`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"2", "3"}, {"1", "2", "3"}}]]]}]], "Print",\

 CellChangeTimes->{3.573898879459999*^9, 3.576559388097452*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879459999*^9, 3.5765593880990963`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", 
        RowBox[{"-", 
         FractionBox["1", "6"]}]},
       {
        RowBox[{"-", 
         FractionBox["1", "6"]}], "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {2, 2}, 0, {
       1, {{0, 2, 4}, {{1}, {2}, {1}, {2}}}, {
        1, Rational[-1, 6], Rational[-1, 6], 1}}]]]], "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["23", "978"]},
        {
         FractionBox["1", "6"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {2}, 0, {1, {{0, 2}, {{1}, {2}}}, {
         Rational[23, 978], 
         Rational[1, 6]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["43", "815"]},
        {
         FractionBox["143", "815"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[
    Automatic, {2, 2}, 0, {
     1, {{0, 2, 4}, {{1}, {2}, {1}, {2}}}, {
      1, Rational[-1, 6], Rational[-1, 6], 1}}]], 
   MatrixForm[{"d(1,3)", "d(3,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {2}, 0, {1, {{0, 2}, {{1}, {2}}}, {
       Rational[23, 978], 
       Rational[1, 6]}}]], ";  Solution:", 
   MatrixForm[{"d(1,3)", "d(3,4)"}], "=", 
   MatrixForm[{
     Rational[43, 815], 
     Rational[143, 815]}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879459999*^9, 3.5765593881015377`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total solved TPs: \"\>", "\[InvisibleSpace]", "2"}],
  SequenceForm["Total solved TPs: ", 2],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879459999*^9, 3.5765593881037188`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Execution Time: \"\>", "\[InvisibleSpace]", 
   "0.02734299999999999924993332456324424129`4.457446075741445", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm[
  "Execution Time: ", 
   0.02734299999999999924993332456324424129`4.457446075741445, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.573898879459999*^9, 3.5765593881052637`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
   FractionBox["143", "815"]}], "}"}]], "Output",
 CellChangeTimes->{
  3.559562914911862*^9, 3.5595635026341057`*^9, 3.5721565329806747`*^9, 
   3.57216937908891*^9, 3.572175155818564*^9, 3.572175458537889*^9, 
   3.572547635238099*^9, {3.572547701917156*^9, 3.572547731224419*^9}, 
   3.573898820489464*^9, 3.5738988795111313`*^9, 3.576559388107049*^9}]
}, Open  ]],

Cell[TextData[{
 "Using the estimate ",
 Cell[BoxData[
  FractionBox["25", "163"]],
  CellChangeTimes->{{3.559562881433319*^9, 3.55956291088018*^9}}],
 " for the distance d(2,6) we had considerably reduced the number of steps \
for computing a good over-approximation for d(3,4)."
}], "Text",
 CellChangeTimes->{{3.559562939048815*^9, 3.559563189181788*^9}, {
  3.559563434509242*^9, 3.559563450957526*^9}, {3.5739007936880827`*^9, 
  3.573900795781292*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Craps Game", "Subsection",
 CellChangeTimes->{{3.558672880800664*^9, 3.5586728823581543`*^9}, 
   3.5595578883018208`*^9, {3.5595587555906754`*^9, 3.559558758877635*^9}}],

Cell[TextData[{
 "Here we present two different MCs modeling slightly different versions for \
the \[OpenCurlyDoubleQuote]craps game\[CloseCurlyDoubleQuote] (these are \
taken from the book ",
 ButtonBox["Principles of Model Checking, ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://books.google.de/books/about/Principles_of_model_checking.html?\
hl=de&id=nDQiAQAAIAAJ"], None},
  ButtonNote->
   "http://books.google.de/books/about/Principles_of_model_checking.html?hl=\
de&id=nDQiAQAAIAAJ"],
 "Examples 10.4 and 10.23). We compare the two MCs by means of the distance \
beteween their initial states."
}], "Text",
 CellChangeTimes->{{3.558671429012618*^9, 3.558671448608567*^9}, {
  3.559557272870656*^9, 3.55955727776505*^9}, {3.559557911234665*^9, 
  3.559557918663082*^9}, {3.5595579534041758`*^9, 3.559558154365631*^9}, {
  3.5595582892103252`*^9, 3.5595584431404953`*^9}, {3.573900922648849*^9, 
  3.573900977781*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"start", "=", "1"}], ";", 
   RowBox[{"won", "=", "2"}], ";", " ", 
   RowBox[{"lost", "=", "3"}], ";", 
   RowBox[{"other", "=", "4"}], ";"}], " ", 
  RowBox[{"(*", " ", "labels", " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"labelsGame1", "=", 
   RowBox[{"{", 
    RowBox[{
    "start", ",", "won", ",", "lost", ",", "other", ",", "other", ",", 
     "other", ",", "other", ",", "other", ",", "other"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"edgeGame1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
      FractionBox["1", "12"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "9"}], "}"}], "\[Rule]", 
      FractionBox["1", "12"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "5"}], "}"}], "\[Rule]", 
      FractionBox["1", "9"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "8"}], "}"}], "\[Rule]", 
      FractionBox["1", "9"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "6"}], "}"}], "\[Rule]", 
      FractionBox["5", "36"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "7"}], "}"}], "\[Rule]", 
      FractionBox["5", "36"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "won"}], "}"}], "\[Rule]", 
      FractionBox["2", "9"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "lost"}], "}"}], "\[Rule]", 
      FractionBox["1", "9"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"won", ",", "won"}], "}"}], "\[Rule]", "1"}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"lost", ",", "lost"}], "}"}], "\[Rule]", "1"}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"4", ",", "4"}], "}"}], "\[Rule]", 
      FractionBox["3", "4"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"4", ",", "won"}], "}"}], "\[Rule]", 
      FractionBox["1", "12"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"4", ",", "lost"}], "}"}], "\[Rule]", 
      FractionBox["1", "6"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"9", ",", "9"}], "}"}], "\[Rule]", "1"}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"5", ",", "5"}], "}"}], "\[Rule]", 
      FractionBox["13", "18"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"5", ",", "won"}], "}"}], "\[Rule]", 
      FractionBox["1", "9"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"5", ",", "lost"}], "}"}], "\[Rule]", 
      FractionBox["1", "6"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"8", ",", "8"}], "}"}], "\[Rule]", "1"}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"6", ",", "6"}], "}"}], "\[Rule]", 
      FractionBox["13", "18"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"6", ",", "won"}], "}"}], "\[Rule]", 
      FractionBox["1", "9"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"6", ",", "lost"}], "}"}], "\[Rule]", 
      FractionBox["1", "6"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"7", ",", "7"}], "}"}], "\[Rule]", "1"}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.558670584337625*^9, 3.558670587455317*^9}, {
   3.558670788498439*^9, 3.5586708486931343`*^9}, {3.5586708952750063`*^9, 
   3.558670928818719*^9}, {3.558671010672637*^9, 3.5586712567563963`*^9}, {
   3.55867131706483*^9, 3.558671419741489*^9}, {3.558671507146534*^9, 
   3.5586715462369003`*^9}, {3.55867159925712*^9, 3.558671615947254*^9}, {
   3.5586717009373913`*^9, 3.558671703545013*^9}, {3.5586717477008963`*^9, 
   3.558671751554617*^9}, {3.558671914787162*^9, 3.558672010716824*^9}, {
   3.558672448525922*^9, 3.558672450005805*^9}, {3.558672602349402*^9, 
   3.5586726055298023`*^9}, {3.559557229630104*^9, 3.559557244013598*^9}, {
   3.559557281415942*^9, 3.5595573858314743`*^9}, 3.572156721919095*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"game1", "=", 
    RowBox[{"MC", "[", 
     RowBox[{
      RowBox[{"MCtm", "[", 
       RowBox[{"edgeGame1", ",", 
        RowBox[{"Length", "@", "labelsGame1"}]}], "]"}], ",", "labelsGame1"}],
      "]"}]}], ")"}], "//", "PlotMC"}]], "Input",
 CellChangeTimes->{{3.558671668730261*^9, 3.558671692086938*^9}, {
  3.5586717735396957`*^9, 3.558671795650897*^9}, {3.55867211170418*^9, 
  3.558672140534251*^9}, {3.558674516388204*^9, 3.55867453156172*^9}, {
  3.55955722129506*^9, 3.5595572682328787`*^9}, {3.559557415900332*^9, 
  3.559557426034408*^9}, {3.572156683714962*^9, 3.572156696858766*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 4, 9, 5, 8, 6, 7, 2, 
      3}, {{{1, 2}, {1, 3}, {1, 4}, {1, 5}, {1, 6}, {1, 7}, {1, 8}, {1, 9}, {
       8, 8}, {9, 9}, {2, 2}, {2, 8}, {2, 9}, {4, 4}, {4, 8}, {4, 9}, {6, 
       6}, {6, 8}, {6, 9}, {7, 7}, {5, 5}, {3, 3}}, Null}, {
      EdgeLabels -> {
        DirectedEdge[1, 4] -> Rational[1, 12], DirectedEdge[5, 2] -> 
         Rational[1, 9], DirectedEdge[4, 4] -> Rational[3, 4], 
         DirectedEdge[6, 3] -> Rational[1, 6], DirectedEdge[1, 9] -> 
         Rational[1, 12], DirectedEdge[5, 3] -> Rational[1, 6], 
         DirectedEdge[8, 8] -> 1, DirectedEdge[3, 3] -> 1, DirectedEdge[4, 2] -> 
         Rational[1, 12], DirectedEdge[1, 5] -> Rational[1, 9], 
         DirectedEdge[1, 6] -> Rational[5, 36], DirectedEdge[1, 8] -> 
         Rational[1, 9], DirectedEdge[1, 3] -> Rational[1, 9], 
         DirectedEdge[9, 9] -> 1, DirectedEdge[6, 2] -> Rational[1, 9], 
         DirectedEdge[1, 7] -> Rational[5, 36], DirectedEdge[4, 3] -> 
         Rational[1, 6], DirectedEdge[1, 2] -> Rational[2, 9], 
         DirectedEdge[7, 7] -> 1, DirectedEdge[6, 6] -> Rational[13, 18], 
         DirectedEdge[5, 5] -> Rational[13, 18], DirectedEdge[2, 2] -> 1}, 
       VertexLabels -> {"Name"}, VertexSize -> {0.1}, VertexStyle -> {2 -> Hue[
           Rational[1, 3]], 1 -> Hue[
           Rational[1, 2]], 8 -> Hue[
           Rational[1, 5]], 7 -> Hue[
           Rational[1, 5]], 5 -> Hue[
           Rational[1, 5]], 6 -> Hue[
           Rational[1, 5]], 4 -> Hue[
           Rational[1, 5]], 9 -> Hue[
           Rational[1, 5]], 3 -> Hue[
           Rational[1, 4]]}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Arrowheads[0.021167650531286893`], 
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$1", Automatic, Center], 
           DynamicLocation["VertexID$2", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$1"], 
        InsetBox[
         FormBox[
          FractionBox["1", "12"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$1", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$1", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$2"], 
        InsetBox[
         FormBox[
          FractionBox["1", "12"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$2", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$1", Automatic, Center], 
           DynamicLocation["VertexID$4", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$3"], 
        InsetBox[
         FormBox[
          FractionBox["1", "9"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$3", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$1", Automatic, Center], 
           DynamicLocation["VertexID$5", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$4"], 
        InsetBox[
         FormBox[
          FractionBox["1", "9"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$4", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$1", Automatic, Center], 
           DynamicLocation["VertexID$6", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$5"], 
        InsetBox[
         FormBox[
          FractionBox["5", "36"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$5", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$1", Automatic, Center], 
           DynamicLocation["VertexID$7", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$6"], 
        InsetBox[
         FormBox[
          FractionBox["5", "36"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$6", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation[
            "VertexID$1", Automatic, Center], {-0.09876543209876541, 
            1.9012345679012346`}, {-0.15555555555555556`, 
            1.8444444444444446`}, {-0.21728395061728392`, 
            1.7827160493827163`}, {-0.2839506172839506, 
            1.7160493827160495`}, {-0.3555555555555555, 
            1.6444444444444444`}, {-0.4320987654320988, 
            1.567901234567901}, {-0.5135802469135802, 
            1.4864197530864198`}, {-0.6, 1.4}, {-0.6790123456790123, 
            1.3111111111111107`}, {-0.7382716049382716, 
            1.222222222222222}, {-0.7777777777777778, 
            1.1333333333333335`}, {-0.7975308641975307, 
            1.0444444444444445`}, {-0.7975308641975308, 
            0.9555555555555556}, {-0.7777777777777779, 
            0.8666666666666667}, {-0.7382716049382716, 
            0.7777777777777778}, {-0.6790123456790124, 
            0.6888888888888889}, {-0.6, 0.6}, {-0.5135802469135802, 
            0.5135802469135802}, {-0.4320987654320988, 
            0.4320987654320988}, {-0.35555555555555557`, 
            0.35555555555555557`}, {-0.2839506172839506, 
            0.2839506172839506}, {-0.2172839506172839, 
            0.2172839506172839}, {-0.15555555555555556`, 
            0.15555555555555556`}, {-0.09876543209876543, 
            0.09876543209876543}, 
            DynamicLocation["VertexID$8", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$7"], 
        InsetBox[
         FormBox[
          FractionBox["2", "9"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$7", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$1", Automatic, Center], {
            0.329054009155558, 1.8903153302814808`}, {0.5403715206000056, 
            1.8198761597999984`}, {0.7828827032888988, 1.7390390989037006`}, {
            1.0565875572222378`, 1.6478041475925873`}, {1.3614860824000223`, 
            1.5461713058666593`}, {1.6975782788222527`, 
            1.4341405737259159`}, {2.0648641464889286`, 
            1.3117119511703572`}, {2.4633436854000506`, 
            1.1788854381999831`}, {2.571036985995101, 1.1364033091950483`}, {
            2.6556029701802775`, 1.0884615613802369`}, {2.717041637955578, 
            1.0350601947555482`}, {2.755352989321003, 0.9761992093209825}, {
            2.7705370242765532`, 0.91187860507654}, {2.7625937428222276`, 
            0.8420983820222203}, {2.731523144958027, 0.7668585401580239}, {
            2.6773252306839512`, 0.6861590794839505}, {2.5999999999999996`, 
            0.6}, {2.5135802469135795`, 0.5135802469135802}, {
            2.432098765432099, 0.4320987654320988}, {2.355555555555556, 
            0.35555555555555557`}, {2.283950617283951, 0.2839506172839506}, {
            2.2172839506172837`, 0.2172839506172839}, {2.155555555555556, 
            0.15555555555555556`}, {2.0987654320987654`, 0.09876543209876543}, 
            DynamicLocation["VertexID$9", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$8"], 
        InsetBox[
         FormBox[
          FractionBox["1", "9"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$8", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$2", Automatic, Center], 
           DynamicLocation["VertexID$8", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$9"], 
        InsetBox[
         FormBox[
          FractionBox["1", "12"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$9", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$2", Automatic, Center], 
           DynamicLocation["VertexID$9", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$10"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$10", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation[
            "VertexID$2", Automatic, Center], {-0.3023544147366866, 
            0.5427248070004345}, {-0.6892969262648808, 
            0.5039167818001786}, {-0.9144098411568388, 
            0.6396648631615857}, {-0.9144098411568391, 
            1.360335136838414}, {-0.6892969262648808, 
            1.4960832181998212`}, {-0.30235441473668667`, 
            1.4572751929995653`}, 
            DynamicLocation["VertexID$2", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$11"], 
        InsetBox[
         FormBox[
          FractionBox["3", "4"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$11", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation[
            "VertexID$3", Automatic, Center], {-4.083931487908494, 
            0.561848528147617}, {-4.4642043906963735`, 
            0.3434638861364886}, {-4.7562525435071565`, 
            0.39936780675762684`}, {-4.9499320999144905`, 
            1.1740860323869609`}, {-4.718550280667864, 
            1.3608474460224516`}, {-4.28024612314391, 1.3471070690892817`}, 
            DynamicLocation["VertexID$3", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$12"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$12", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$4", Automatic, Center], 
           DynamicLocation["VertexID$8", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$13"], 
        InsetBox[
         FormBox[
          FractionBox["1", "9"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$13", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$4", Automatic, Center], 
           DynamicLocation["VertexID$9", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$14"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$14", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$4", Automatic, Center], {
            0.8904544671436203, 1.537139246820381}, {1.1366227231910004`, 
            1.8381903384348803`}, {1.3917899807074883`, 
            1.9013808182239402`}, {1.9013808182239393`, 
            1.3917899807074903`}, {1.8381903384348801`, 
            1.1366227231910024`}, {1.5371392468203815`, 0.8904544671436216}, 
            DynamicLocation["VertexID$4", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$15"], 
        InsetBox[
         FormBox[
          FractionBox["13", "18"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$15", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation[
            "VertexID$5", Automatic, Center], {-3.0500795826217137`, 
            0.5567018583916936}, {-3.4124830486086255`, 
            0.3097948712452746}, {-3.70795860433664, 
            0.3431350552313632}, {-3.960485850330494, 
            1.1007167932129256`}, {-3.7441095161397353`, 
            1.304674273838605}, {-3.3060425510623546`, 1.324590763713617}, 
            DynamicLocation["VertexID$5", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$16"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$16", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$6", Automatic, Center], 
           DynamicLocation["VertexID$8", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$17"], 
        InsetBox[
         FormBox[
          FractionBox["1", "9"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$17", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$6", Automatic, Center], 
           DynamicLocation["VertexID$9", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$18"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$18", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$6", Automatic, Center], {
            1.946890860471822, 1.4429453987203384`}, {2.242872066122747, 
            1.7665106291800918`}, {2.5381033567898434`, 
            1.8019487006858292`}, {2.957931860621041, 1.122651912040937}, {
            2.794203638866385, 0.8744374054099516}, {2.372431279501465, 
            0.7544065371435047}, 
            DynamicLocation["VertexID$6", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$19"], 
        InsetBox[
         FormBox[
          FractionBox["13", "18"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$19", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation[
            "VertexID$7", Automatic, Center], {-1.9868844330554023`, 
            0.5540749066797597}, {-2.310727639723483, 
            0.25839787010778736`}, {-2.6079485305421963`, 
            0.24961641453735728`}, {-2.965075986695432, 
            0.9638713268438279}, {-2.7797182877478597`, 
            1.1963791661565408`}, {-2.3488707344894335`, 1.278047509547822}, 
            DynamicLocation["VertexID$7", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$20"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$20", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$8", Automatic, Center], {
            0.3694220540114299, -0.25009708706604195`}, {
            0.4199332857089911, -0.6856977619202527}, {
            0.253269061236341, -0.9319504942542012}, {-0.5349807511441433, \
-0.8040351590729322}, {-0.6152203658623814, -0.5177154494284966}, \
{-0.42955217570237136`, -0.12044141853325308`}, 
            DynamicLocation["VertexID$8", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$21"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$21", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$9", Automatic, Center], {
            2.4295521757023715`, -0.12044141853325308`}, {
            2.6152203658623816`, -0.5177154494284966}, {
            2.5349807511441433`, -0.8040351590729322}, {
            1.7467309387636591`, -0.9319504942542012}, {
            1.580066714291009, -0.6856977619202527}, {
            1.63057794598857, -0.25009708706604195`}, 
            DynamicLocation["VertexID$9", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$22"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$22", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{0., 2.}, 0.05], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{0., 1.}, 0.05], 
           Hue[
            Rational[1, 5]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{-4., 1.}, 0.05], 
           Hue[
            Rational[1, 5]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["9", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{1., 1.}, 0.05], 
           Hue[
            Rational[1, 5]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{-3., 1.}, 0.05], 
           Hue[
            Rational[1, 5]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["8", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{2., 1.}, 0.05], 
           Hue[
            Rational[1, 5]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox["6", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{-2., 1.}, 0.05], 
           Hue[
            Rational[1, 5]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$7"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{0., 0.}, 0.05], 
           Hue[
            Rational[1, 3]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$8"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$8", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$8"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{2., 0.}, 0.05], 
           Hue[
            Rational[1, 4]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$9"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$9", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$9"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{5.760693309010094, 
       462.2393066909899}, {-103.12100211581675`, 85.23930669098992}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImageSize->{469.37109375, Automatic}]], "Output",
 CellChangeTimes->{
  3.558672613079369*^9, 3.5586745329923153`*^9, {3.559557410556624*^9, 
   3.559557426992676*^9}, 3.5595635031113377`*^9, {3.572156755632842*^9, 
   3.572156776916094*^9}, 3.572175155977255*^9, 3.5721754590618477`*^9, 
   3.573898820560639*^9, 3.573898879597331*^9, 3.5765593881947002`*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"labelsGame2", "=", "labelsGame1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"edgeGame2", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
      FractionBox["1", "12"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "9"}], "}"}], "\[Rule]", 
      FractionBox["1", "12"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "5"}], "}"}], "\[Rule]", 
      FractionBox["1", "9"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "8"}], "}"}], "\[Rule]", 
      FractionBox["1", "9"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "6"}], "}"}], "\[Rule]", 
      FractionBox["5", "36"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "7"}], "}"}], "\[Rule]", 
      FractionBox["5", "36"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "won"}], "}"}], "\[Rule]", 
      FractionBox["2", "9"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "lost"}], "}"}], "\[Rule]", 
      FractionBox["1", "9"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"won", ",", "won"}], "}"}], "\[Rule]", "1"}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"lost", ",", "lost"}], "}"}], "\[Rule]", "1"}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"4", ",", "4"}], "}"}], "\[Rule]", 
      FractionBox["3", "4"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"4", ",", "won"}], "}"}], "\[Rule]", 
      FractionBox["1", "12"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"4", ",", "lost"}], "}"}], "\[Rule]", 
      FractionBox["1", "6"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"9", ",", "9"}], "}"}], "\[Rule]", 
      FractionBox["3", "4"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"9", ",", "won"}], "}"}], "\[Rule]", 
      FractionBox["1", "12"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"9", ",", "lost"}], "}"}], "\[Rule]", 
      FractionBox["1", "6"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"5", ",", "5"}], "}"}], "\[Rule]", 
      FractionBox["13", "18"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"5", ",", "won"}], "}"}], "\[Rule]", 
      FractionBox["1", "9"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"5", ",", "lost"}], "}"}], "\[Rule]", 
      FractionBox["1", "6"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"8", ",", "8"}], "}"}], "\[Rule]", 
      FractionBox["13", "18"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"8", ",", "won"}], "}"}], "\[Rule]", 
      FractionBox["1", "9"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"8", ",", "lost"}], "}"}], "\[Rule]", 
      FractionBox["1", "6"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"6", ",", "6"}], "}"}], "\[Rule]", 
      FractionBox["25", "36"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"6", ",", "won"}], "}"}], "\[Rule]", 
      FractionBox["5", "36"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"6", ",", "lost"}], "}"}], "\[Rule]", 
      FractionBox["1", "6"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"7", ",", "7"}], "}"}], "\[Rule]", 
      FractionBox["25", "36"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"7", ",", "won"}], "}"}], "\[Rule]", 
      FractionBox["5", "36"]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"7", ",", "lost"}], "}"}], "\[Rule]", 
      FractionBox["1", "6"]}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{
  3.558672927762569*^9, 3.558673369832284*^9, {3.558673680998494*^9, 
   3.558673895423319*^9}, {3.559557498886681*^9, 3.559557517879985*^9}, {
   3.559557563112156*^9, 3.559557564054269*^9}, 3.57215686714359*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"game2", "=", 
    RowBox[{"MC", "[", 
     RowBox[{
      RowBox[{"MCtm", "[", 
       RowBox[{"edgeGame2", ",", 
        RowBox[{"Length", "@", "labelsGame2"}]}], "]"}], ",", "labelsGame2"}],
      "]"}]}], ")"}], "//", "PlotMC"}]], "Input",
 CellChangeTimes->{{3.558671668730261*^9, 3.558671692086938*^9}, {
  3.5586717735396957`*^9, 3.558671795650897*^9}, {3.55867211170418*^9, 
  3.558672140534251*^9}, {3.55867454180235*^9, 3.558674547241844*^9}, {
  3.55955752614192*^9, 3.559557558456512*^9}, {3.572156889014451*^9, 
  3.57215689834232*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 4, 9, 5, 8, 6, 7, 2, 
      3}, {{{1, 2}, {1, 3}, {1, 4}, {1, 5}, {1, 6}, {1, 7}, {1, 8}, {1, 9}, {
       8, 8}, {9, 9}, {2, 2}, {2, 8}, {2, 9}, {4, 4}, {4, 8}, {4, 9}, {6, 
       6}, {6, 8}, {6, 9}, {7, 7}, {7, 8}, {7, 9}, {5, 5}, {5, 8}, {5, 9}, {3,
        3}, {3, 8}, {3, 9}}, Null}, {
      EdgeLabels -> {
        DirectedEdge[3, 3] -> 1, DirectedEdge[6, 3] -> Rational[1, 6], 
         DirectedEdge[7, 2] -> Rational[5, 36], DirectedEdge[8, 2] -> 
         Rational[1, 9], DirectedEdge[2, 2] -> 1, DirectedEdge[6, 6] -> 
         Rational[25, 36], DirectedEdge[8, 3] -> Rational[1, 6], 
         DirectedEdge[6, 2] -> Rational[5, 36], DirectedEdge[9, 9] -> 
         Rational[3, 4], DirectedEdge[1, 6] -> Rational[5, 36], 
         DirectedEdge[4, 2] -> Rational[1, 12], DirectedEdge[5, 2] -> 
         Rational[1, 9], DirectedEdge[1, 5] -> Rational[1, 9], 
         DirectedEdge[7, 3] -> Rational[1, 6], DirectedEdge[1, 9] -> 
         Rational[1, 12], DirectedEdge[8, 8] -> Rational[13, 18], 
         DirectedEdge[5, 5] -> Rational[13, 18], DirectedEdge[9, 3] -> 
         Rational[1, 6], DirectedEdge[7, 7] -> Rational[25, 36], 
         DirectedEdge[1, 3] -> Rational[1, 9], DirectedEdge[1, 4] -> 
         Rational[1, 12], DirectedEdge[1, 2] -> Rational[2, 9], 
         DirectedEdge[9, 2] -> Rational[1, 12], DirectedEdge[4, 3] -> 
         Rational[1, 6], DirectedEdge[5, 3] -> Rational[1, 6], 
         DirectedEdge[1, 7] -> Rational[5, 36], DirectedEdge[4, 4] -> 
         Rational[3, 4], DirectedEdge[1, 8] -> Rational[1, 9]}, 
       VertexLabels -> {"Name"}, VertexSize -> {0.1}, VertexStyle -> {2 -> Hue[
           Rational[1, 3]], 4 -> Hue[
           Rational[1, 5]], 1 -> Hue[
           Rational[1, 2]], 9 -> Hue[
           Rational[1, 5]], 3 -> Hue[
           Rational[1, 4]], 8 -> Hue[
           Rational[1, 5]], 7 -> Hue[
           Rational[1, 5]], 5 -> Hue[
           Rational[1, 5]], 6 -> Hue[
           Rational[1, 5]]}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Arrowheads[0.023064257028112448`], 
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$1", Automatic, Center], 
           DynamicLocation["VertexID$2", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$1"], 
        InsetBox[
         FormBox[
          FractionBox["1", "12"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$1", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$1", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$2"], 
        InsetBox[
         FormBox[
          FractionBox["1", "12"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$2", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$1", Automatic, Center], 
           DynamicLocation["VertexID$4", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$3"], 
        InsetBox[
         FormBox[
          FractionBox["1", "9"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$3", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$1", Automatic, Center], 
           DynamicLocation["VertexID$5", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$4"], 
        InsetBox[
         FormBox[
          FractionBox["1", "9"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$4", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$1", Automatic, Center], 
           DynamicLocation["VertexID$6", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$5"], 
        InsetBox[
         FormBox[
          FractionBox["5", "36"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$5", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$1", Automatic, Center], 
           DynamicLocation["VertexID$7", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$6"], 
        InsetBox[
         FormBox[
          FractionBox["5", "36"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$6", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation[
            "VertexID$1", Automatic, Center], {-0.2962962962962962, 
            1.9012345679012346`}, {-0.4666666666666666, 
            1.8444444444444446`}, {-0.6518518518518517, 
            1.7827160493827163`}, {-0.8518518518518516, 
            1.7160493827160495`}, {-1.0666666666666664`, 
            1.6444444444444444`}, {-1.296296296296296, 
            1.567901234567901}, {-1.5407407407407403`, 
            1.4864197530864198`}, {-1.7999999999999996`, 
            1.4}, {-2.0370370370370363`, 
            1.3111111111111107`}, {-2.214814814814815, 
            1.222222222222222}, {-2.333333333333334, 
            1.1333333333333335`}, {-2.3925925925925924`, 
            1.0444444444444445`}, {-2.3925925925925924`, 
            0.9555555555555556}, {-2.333333333333333, 
            0.8666666666666667}, {-2.2148148148148143`, 
            0.7777777777777778}, {-2.037037037037037, 
            0.6888888888888889}, {-1.7999999999999998`, 
            0.6}, {-1.5407407407407403`, 
            0.5135802469135802}, {-1.2962962962962963`, 
            0.4320987654320988}, {-1.0666666666666667`, 
            0.35555555555555557`}, {-0.8518518518518519, 
            0.2839506172839506}, {-0.6518518518518517, 
            0.2172839506172839}, {-0.4666666666666667, 
            0.15555555555555556`}, {-0.2962962962962962, 0.09876543209876543}, 
            DynamicLocation["VertexID$8", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$7"], 
        InsetBox[
         FormBox[
          FractionBox["2", "9"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$7", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$1", Automatic, Center], {
            0.4134743712515657, 1.8966314071871087`}, {0.6636506686493563, 
            1.8340873328376612`}, {0.9427863738951519, 1.7643034065262122`}, {
            1.2508814869889529`, 1.6872796282527618`}, {1.5879360079307587`, 
            1.6030159980173104`}, {1.9539499367205697`, 
            1.5115125158198577`}, {2.348923273358386, 1.4127691816604038`}, {
            2.772856017844207, 1.3067859955389483`}, {3.0155899400250523`, 
            1.2374605396850948`}, {3.198394381165014, 1.1658335034741787`}, {
            3.321269341264092, 1.0919048869061994`}, {3.384214820322286, 
            1.0156746899811568`}, {3.3872308183395967`, 0.9371429126990515}, {
            3.330317335316023, 0.8563095550598832}, {3.2134743712515657`, 
            0.7731746170636518}, {3.036701926146225, 0.6877380987103574}, {
            2.8, 0.6}, {2.5407407407407403`, 0.5135802469135802}, {
            2.296296296296296, 0.4320987654320988}, {2.066666666666667, 
            0.35555555555555557`}, {1.8518518518518519`, 
            0.2839506172839506}, {1.6518518518518517`, 0.2172839506172839}, {
            1.4666666666666668`, 0.15555555555555556`}, {1.2962962962962963`, 
            0.09876543209876543}, 
            DynamicLocation["VertexID$9", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$8"], 
        InsetBox[
         FormBox[
          FractionBox["1", "9"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$8", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$2", Automatic, Center], 
           DynamicLocation["VertexID$8", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$9"], 
        InsetBox[
         FormBox[
          FractionBox["1", "12"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$9", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$2", Automatic, Center], 
           DynamicLocation["VertexID$9", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$10"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$10", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation[
            "VertexID$2", Automatic, Center], {-2.208357930131581, 
            0.5507278886916348}, {-2.6766926568241143`, 
            0.4179215683381623}, {-2.976164074717015, 
            0.5567583480465219}, {-2.9761640747170155`, 
            1.4432416519534779`}, {-2.6766926568241143`, 
            1.5820784316618375`}, {-2.208357930131581, 1.4492721113083649`}, 
            DynamicLocation["VertexID$2", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$11"], 
        InsetBox[
         FormBox[
          FractionBox["3", "4"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$11", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$3", Automatic, Center], 
           DynamicLocation["VertexID$8", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$12"], 
        InsetBox[
         FormBox[
          FractionBox["1", "12"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$12", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$3", Automatic, Center], 
           DynamicLocation["VertexID$9", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$13"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$13", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation[
            "VertexID$3", Automatic, Center], {-1.2083579301315808`, 
            0.5507278886916348}, {-1.6766926568241143`, 
            0.4179215683381623}, {-1.976164074717015, 
            0.5567583480465219}, {-1.9761640747170153`, 
            1.4432416519534779`}, {-1.6766926568241143`, 
            1.5820784316618375`}, {-1.208357930131581, 1.4492721113083649`}, 
            DynamicLocation["VertexID$3", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$14"], 
        InsetBox[
         FormBox[
          FractionBox["3", "4"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$14", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$4", Automatic, Center], 
           DynamicLocation["VertexID$8", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$15"], 
        InsetBox[
         FormBox[
          FractionBox["1", "9"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$15", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$4", Automatic, Center], 
           DynamicLocation["VertexID$9", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$16"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$16", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation[
            "VertexID$4", Automatic, Center], {-0.3356438022593047, 
            0.4923785565000096}, {-0.7651888973365271, 
            0.4492977463595902}, {-1.0150868680931755`, 
            0.5999917662144942}, {-1.0150868680931757`, 
            1.4000082337855053`}, {-0.7651888973365272, 
            1.5507022536404096`}, {-0.3356438022593048, 1.5076214434999904`}, 
            
            DynamicLocation["VertexID$4", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$17"], 
        InsetBox[
         FormBox[
          FractionBox["13", "18"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$17", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$5", Automatic, Center], 
           DynamicLocation["VertexID$8", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$18"], 
        InsetBox[
         FormBox[
          FractionBox["1", "9"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$18", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$5", Automatic, Center], 
           DynamicLocation["VertexID$9", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$19"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$19", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$5", Automatic, Center], {
            1.0205686334635882`, 1.49480843602917}, {1.4024307233064426`, 
            1.7967294178983455`}, {1.732236772267139, 1.7830637088605095`}, {
            2.0714792457405986`, 0.9640599284678903}, {1.8479342675745238`, 
            0.7211887192410629}, {1.3644266207063804`, 0.664661819697308}, 
            DynamicLocation["VertexID$5", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$20"], 
        InsetBox[
         FormBox[
          FractionBox["13", "18"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$20", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$6", Automatic, Center], 
           DynamicLocation["VertexID$8", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$21"], 
        InsetBox[
         FormBox[
          FractionBox["5", "36"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$21", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$6", Automatic, Center], 
           DynamicLocation["VertexID$9", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$22"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$22", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$6", Automatic, Center], {
            2.1337020850223434`, 1.47684610673557}, {2.574716205436907, 
            1.6829564668511354`}, {2.8925598727454562`, 
            1.5938824263767952`}, {3.0345587567534995`, 0.7188458756851898}, {
            2.761193463016049, 0.533831828341726}, {2.2776329140420435`, 
            0.5899043744579608}, 
            DynamicLocation["VertexID$6", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$23"], 
        InsetBox[
         FormBox[
          FractionBox["25", "36"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$23", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$7", Automatic, Center], 
           DynamicLocation["VertexID$8", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$24"], 
        InsetBox[
         FormBox[
          FractionBox["5", "36"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$24", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[{
           DynamicLocation["VertexID$7", Automatic, Center], 
           DynamicLocation["VertexID$9", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$25"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$25", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$7", Automatic, Center], {
            3.1759852853624184`, 1.4629121259851603`}, {3.6337272697650986`, 
            1.6285841232179328`}, {3.9422872833700704`, 
            1.5113258632160391`}, {4.005129216110784, 0.627072766192792}, {
            3.7162532090379545`, 0.46735603547170923`}, {3.2396822048118605`, 
            0.5666284530051409}, 
            DynamicLocation["VertexID$7", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$26"], 
        InsetBox[
         FormBox[
          FractionBox["25", "36"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$26", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$8", Automatic, Center], {
            0.46008442261224375`, -0.2226496170955845}, {
            0.5799044693499512, -0.6879025756247233}, {
            0.4385500602555439, -0.9812481980422871}, {-0.4385500602555437, \
-0.9812481980422871}, {-0.5799044693499512, -0.6879025756247232}, \
{-0.46008442261224364`, -0.2226496170955845}, 
            DynamicLocation["VertexID$8", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$27"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$27", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          BezierCurveBox[{
            DynamicLocation["VertexID$9", Automatic, Center], {
            1.4600844226122436`, -0.2226496170955845}, {
            1.5799044693499513`, -0.6879025756247233}, {
            1.4385500602555439`, -0.9812481980422871}, {
            0.5614499397444562, -0.9812481980422871}, {
            0.4200955306500488, -0.6879025756247232}, {
            0.5399155773877563, -0.2226496170955845}, 
            DynamicLocation["VertexID$9", Automatic, Center]}, SplineDegree -> 
           7]], "DynamicName", BoxID -> "EdgeLabelID$28"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$28", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{0., 2.}, 0.05], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{-2., 1.}, 0.05], 
           Hue[
            Rational[1, 5]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{-1., 1.}, 0.05], 
           Hue[
            Rational[1, 5]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["9", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{0., 1.}, 0.05], 
           Hue[
            Rational[1, 5]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{1., 1.}, 0.05], 
           Hue[
            Rational[1, 5]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["8", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{2., 1.}, 0.05], 
           Hue[
            Rational[1, 5]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox["6", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{3., 1.}, 0.05], 
           Hue[
            Rational[1, 5]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$7"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{0., 0.}, 0.05], 
           Hue[
            Rational[1, 3]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$8"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$8", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$8"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{1., 0.}, 0.05], 
           Hue[
            Rational[1, 4]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$9"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$9", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$9"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{3.760693309010094, 
       355.2393066909899}, {-92.33066204522252, 76.23930669098992}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output",
 CellChangeTimes->{
  3.558673928896667*^9, 3.558674548103462*^9, {3.559557560090495*^9, 
   3.5595575663787403`*^9}, 3.559563503343012*^9, {3.5721568845973263`*^9, 
   3.5721568996494207`*^9}, 3.572175156056134*^9, 3.5721754595484867`*^9, 
   3.5738988206441708`*^9, 3.5738988796838284`*^9, 3.576559388281125*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BDistMC", "[", 
  RowBox[{
   RowBox[{"JoinMC", "[", 
    RowBox[{"game1", ",", "game2"}], "]"}], ",", "1", ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "10"}], "}"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.559558560737713*^9, 3.559558597818318*^9}, {
   3.559558653925254*^9, 3.559558659093215*^9}, {3.559558716337626*^9, 
   3.5595587325272503`*^9}, 3.5721747799971933`*^9, 3.57389000074306*^9, {
   3.573898266484303*^9, 3.573898266840107*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "10"}], "}"}], "\[Rule]", 
   FractionBox["137", "396"]}], "}"}]], "Output",
 CellChangeTimes->{{3.559558593411542*^9, 3.559558599184648*^9}, 
   3.5595586601136227`*^9, {3.559558717404305*^9, 3.559558733204001*^9}, 
   3.559563503578313*^9, 3.572156910312615*^9, 3.5721751562066402`*^9, 
   3.572175459724844*^9, 3.573898820813589*^9, 3.573898879775538*^9, 
   3.576559388369576*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{992, 670},
WindowMargins->{{5, Automatic}, {3, Automatic}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowSelection->True,
CellLabelAutoDelete->True,
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, \
2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 244, 8, 92, "Title"],
Cell[826, 32, 266, 5, 51, "Subtitle"],
Cell[1095, 39, 216, 4, 29, "Subsubtitle"],
Cell[1314, 45, 1885, 43, 70, "Text"],
Cell[CellGroupData[{
Cell[3224, 92, 101, 1, 44, "Subsection"],
Cell[CellGroupData[{
Cell[3350, 97, 146, 3, 35, "Subsubsection"],
Cell[3499, 102, 1134, 32, 72, "Text"],
Cell[4636, 136, 462, 7, 49, "Text"],
Cell[5101, 145, 1158, 31, 72, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6296, 181, 118, 1, 35, "Subsubsection"],
Cell[6417, 184, 2924, 64, 148, "Text"],
Cell[9344, 250, 2460, 65, 46, "DisplayFormula"],
Cell[11807, 317, 928, 20, 32, "Text"],
Cell[12738, 339, 1827, 46, 49, "DisplayFormula"],
Cell[14568, 387, 566, 12, 32, "Text"],
Cell[15137, 401, 645, 17, 51, "Text"],
Cell[15785, 420, 349, 9, 32, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[16183, 435, 107, 1, 44, "Subsection"],
Cell[16293, 438, 368, 6, 30, "Text"],
Cell[16664, 446, 409, 9, 46, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17110, 460, 206, 3, 44, "Subsection"],
Cell[17319, 465, 1877, 44, 96, "Text"],
Cell[19199, 511, 622, 13, 31, "Text"],
Cell[19824, 526, 1972, 55, 195, "Input"],
Cell[21799, 583, 496, 8, 30, "Text"],
Cell[CellGroupData[{
Cell[22320, 595, 183, 4, 28, "Input"],
Cell[22506, 601, 19748, 467, 387, "Output"]
}, Open  ]],
Cell[42269, 1071, 1649, 39, 73, "Text"],
Cell[43921, 1112, 587, 11, 31, "Text"],
Cell[44511, 1125, 3345, 88, 127, "Input"],
Cell[CellGroupData[{
Cell[47881, 1217, 362, 7, 28, "Input"],
Cell[48246, 1226, 2475, 64, 198, "Output"]
}, Open  ]],
Cell[50736, 1293, 416, 9, 31, "Text"],
Cell[CellGroupData[{
Cell[51177, 1306, 227, 5, 28, "Input"],
Cell[51407, 1313, 342, 5, 28, "Output"]
}, Open  ]],
Cell[51764, 1321, 498, 12, 32, "Text"],
Cell[CellGroupData[{
Cell[52287, 1337, 2998, 87, 147, "Input"],
Cell[55288, 1426, 14949, 352, 405, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[70286, 1784, 116, 1, 44, "Subsection"],
Cell[70405, 1787, 647, 13, 51, "Text"],
Cell[CellGroupData[{
Cell[71077, 1804, 904, 21, 46, "Input"],
Cell[71984, 1827, 905, 21, 48, "Output"]
}, Open  ]],
Cell[72904, 1851, 414, 8, 31, "Text"],
Cell[CellGroupData[{
Cell[73343, 1863, 389, 9, 28, "Input"],
Cell[CellGroupData[{
Cell[73757, 1876, 369, 9, 22, "Print"],
Cell[74129, 1887, 359, 9, 22, "Print"],
Cell[74491, 1898, 464, 10, 22, "Print"],
Cell[74958, 1910, 3288, 99, 122, "Print"],
Cell[78249, 2011, 2582, 77, 72, "Print"],
Cell[80834, 2090, 331, 7, 21, "Print"],
Cell[81168, 2099, 4520, 128, 56, "Print"],
Cell[85691, 2229, 697, 15, 22, "Print"],
Cell[86391, 2246, 464, 10, 22, "Print"],
Cell[86858, 2258, 3288, 99, 122, "Print"],
Cell[90149, 2359, 329, 7, 21, "Print"],
Cell[90481, 2368, 4164, 114, 31, "Print"],
Cell[94648, 2484, 730, 15, 40, "Print"],
Cell[95381, 2501, 463, 10, 22, "Print"],
Cell[95847, 2513, 3290, 99, 122, "Print"],
Cell[99140, 2614, 331, 7, 21, "Print"],
Cell[99474, 2623, 4162, 114, 31, "Print"],
Cell[103639, 2739, 285, 6, 21, "Print"],
Cell[103927, 2747, 453, 10, 21, "Print"]
}, Open  ]],
Cell[104395, 2760, 263, 7, 48, "Output"]
}, Open  ]],
Cell[104673, 2770, 273, 6, 31, "Text"],
Cell[CellGroupData[{
Cell[104971, 2780, 420, 7, 28, "Input"],
Cell[105394, 2789, 5505, 177, 238, "Output"]
}, Open  ]],
Cell[110914, 2969, 270, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[111209, 2978, 469, 10, 28, "Input"],
Cell[111681, 2990, 2857, 65, 198, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[114587, 3061, 283, 3, 44, "Subsection"],
Cell[114873, 3066, 738, 17, 51, "Text"],
Cell[115614, 3085, 408, 7, 30, "Text"],
Cell[CellGroupData[{
Cell[116047, 3096, 1246, 22, 63, "Input"],
Cell[117296, 3120, 70144, 1704, 180, "Output"]
}, Open  ]],
Cell[187455, 4827, 437, 10, 31, "Text"],
Cell[CellGroupData[{
Cell[187917, 4841, 381, 6, 28, "Input"],
Cell[188301, 4849, 1242, 31, 63, "Output"]
}, Open  ]],
Cell[189558, 4883, 383, 7, 49, "Text"],
Cell[CellGroupData[{
Cell[189966, 4894, 540, 10, 46, "Input"],
Cell[190509, 4906, 36588, 779, 255, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[227146, 5691, 146, 2, 80, "Section"],
Cell[CellGroupData[{
Cell[227317, 5697, 491, 7, 44, "Subsection"],
Cell[227811, 5706, 522, 12, 49, "Text"],
Cell[CellGroupData[{
Cell[228358, 5722, 3666, 100, 181, "Input"],
Cell[232027, 5824, 19677, 466, 387, "Output"]
}, Open  ]],
Cell[251719, 6293, 595, 20, 32, "Text"],
Cell[CellGroupData[{
Cell[252339, 6317, 950, 16, 28, "Input"],
Cell[CellGroupData[{
Cell[253314, 6337, 346, 9, 22, "Print"],
Cell[253663, 6348, 336, 9, 22, "Print"],
Cell[254002, 6359, 442, 10, 22, "Print"],
Cell[254447, 6371, 3267, 99, 122, "Print"],
Cell[257717, 6472, 2561, 77, 72, "Print"],
Cell[260281, 6551, 310, 7, 21, "Print"],
Cell[260594, 6560, 4497, 128, 56, "Print"],
Cell[265094, 6690, 674, 15, 22, "Print"],
Cell[265771, 6707, 443, 10, 22, "Print"],
Cell[266217, 6719, 3269, 99, 122, "Print"],
Cell[269489, 6820, 308, 7, 21, "Print"],
Cell[269800, 6829, 4141, 114, 31, "Print"],
Cell[273944, 6945, 709, 15, 40, "Print"],
Cell[274656, 6962, 445, 10, 22, "Print"],
Cell[275104, 6974, 3267, 99, 122, "Print"],
Cell[278374, 7075, 308, 7, 21, "Print"],
Cell[278685, 7084, 4143, 114, 31, "Print"],
Cell[282831, 7200, 266, 6, 21, "Print"],
Cell[283100, 7208, 434, 10, 21, "Print"]
}, Open  ]],
Cell[283549, 7221, 957, 17, 48, "Output"]
}, Open  ]],
Cell[284521, 7241, 661, 11, 87, "Text"],
Cell[285185, 7254, 1207, 38, 50, "Text"],
Cell[CellGroupData[{
Cell[286417, 7296, 792, 14, 28, "Input"],
Cell[CellGroupData[{
Cell[287234, 7314, 320, 8, 22, "Print"],
Cell[287557, 7324, 308, 8, 22, "Print"],
Cell[287868, 7334, 417, 9, 22, "Print"],
Cell[288288, 7345, 2533, 76, 72, "Print"],
Cell[290824, 7423, 280, 6, 21, "Print"],
Cell[291107, 7431, 4049, 110, 31, "Print"],
Cell[295159, 7543, 645, 14, 22, "Print"],
Cell[295807, 7559, 415, 9, 22, "Print"],
Cell[296225, 7570, 2918, 89, 122, "Print"],
Cell[299146, 7661, 2533, 76, 72, "Print"],
Cell[301682, 7739, 279, 6, 21, "Print"],
Cell[301964, 7747, 4581, 130, 56, "Print"],
Cell[306548, 7879, 646, 14, 22, "Print"],
Cell[307197, 7895, 415, 9, 22, "Print"],
Cell[307615, 7906, 2891, 88, 122, "Print"],
Cell[310509, 7996, 3239, 98, 122, "Print"],
Cell[313751, 8096, 3260, 98, 98, "Print"],
Cell[317014, 8196, 2532, 76, 72, "Print"],
Cell[319549, 8274, 282, 6, 21, "Print"],
Cell[319834, 8282, 5565, 158, 106, "Print"],
Cell[325402, 8442, 646, 14, 22, "Print"],
Cell[326051, 8458, 415, 9, 22, "Print"],
Cell[326469, 8469, 2890, 88, 122, "Print"],
Cell[329362, 8559, 3266, 99, 122, "Print"],
Cell[332631, 8660, 3262, 98, 98, "Print"],
Cell[335896, 8760, 2533, 76, 72, "Print"],
Cell[338432, 8838, 280, 6, 21, "Print"],
Cell[338715, 8846, 5692, 163, 106, "Print"],
Cell[344410, 9011, 687, 14, 40, "Print"],
Cell[345100, 9027, 417, 9, 22, "Print"],
Cell[345520, 9038, 2891, 88, 122, "Print"],
Cell[348414, 9128, 3239, 98, 122, "Print"],
Cell[351656, 9228, 3262, 98, 98, "Print"],
Cell[354921, 9328, 2532, 76, 72, "Print"],
Cell[357456, 9406, 280, 6, 21, "Print"],
Cell[357739, 9414, 5502, 157, 106, "Print"],
Cell[363244, 9573, 236, 5, 21, "Print"],
Cell[363483, 9580, 406, 9, 21, "Print"]
}, Open  ]],
Cell[363904, 9592, 755, 14, 48, "Output"]
}, Open  ]],
Cell[364674, 9609, 647, 11, 68, "Text"],
Cell[CellGroupData[{
Cell[365346, 9624, 831, 18, 28, "Input"],
Cell[366180, 9644, 1073, 24, 48, "Output"]
}, Open  ]],
Cell[367268, 9671, 16, 0, 30, "Text"],
Cell[367287, 9673, 576, 10, 69, "Text"],
Cell[CellGroupData[{
Cell[367888, 9687, 605, 15, 49, "Input"],
Cell[CellGroupData[{
Cell[368518, 9706, 318, 8, 22, "Print"],
Cell[368839, 9716, 307, 8, 22, "Print"],
Cell[369149, 9726, 415, 9, 22, "Print"],
Cell[369567, 9737, 2535, 76, 72, "Print"],
Cell[372105, 9815, 282, 6, 21, "Print"],
Cell[372390, 9823, 4051, 110, 31, "Print"],
Cell[376444, 9935, 646, 14, 22, "Print"],
Cell[377093, 9951, 417, 9, 22, "Print"],
Cell[377513, 9962, 2918, 89, 122, "Print"],
Cell[380434, 10053, 2533, 76, 72, "Print"],
Cell[382970, 10131, 280, 6, 21, "Print"],
Cell[383253, 10139, 4579, 130, 56, "Print"],
Cell[387835, 10271, 687, 14, 40, "Print"],
Cell[388525, 10287, 415, 9, 22, "Print"],
Cell[388943, 10298, 2893, 88, 122, "Print"],
Cell[391839, 10388, 2533, 76, 72, "Print"],
Cell[394375, 10466, 282, 6, 21, "Print"],
Cell[394660, 10474, 4598, 130, 56, "Print"],
Cell[399261, 10606, 238, 5, 21, "Print"],
Cell[399502, 10613, 408, 9, 21, "Print"]
}, Open  ]],
Cell[399925, 10625, 460, 10, 48, "Output"]
}, Open  ]],
Cell[400400, 10638, 458, 10, 58, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[400895, 10653, 180, 2, 44, "Subsection"],
Cell[401078, 10657, 938, 19, 49, "Text"],
Cell[402019, 10678, 3939, 112, 162, "Input"],
Cell[CellGroupData[{
Cell[405983, 10794, 649, 14, 28, "Input"],
Cell[406635, 10810, 22645, 511, 204, "Output"]
}, Open  ]],
Cell[429295, 11324, 3855, 120, 184, "Input"],
Cell[CellGroupData[{
Cell[433175, 11448, 600, 14, 28, "Input"],
Cell[433778, 11464, 25753, 584, 179, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[459568, 12053, 499, 11, 28, "Input"],
Cell[460070, 12066, 463, 10, 82, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
